package edu.uoc.integra.business.functions;

import org.hibernate.Session;

import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.interfaces.IBAuthManager;
import edu.uoc.integra.business.objects.BOConfig;
import edu.uoc.integra.business.objects.BOUser;
import edu.uoc.integra.business.objects.transfers.TOUser;



public class IBAuthManagerImpl extends IBCommonManagerImpl implements IBAuthManager {

	//************************************************************//
	// CONSTRUCTOR.                                               //
	//************************************************************//
	/**
	 * <p><code>Construye un nuevo objeto <code>IBAuthManagerImpl</code>
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	public IBAuthManagerImpl() throws ExceptionControl {
		
		// Constructor de la superclase.
		super();
	}
	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera acceder al sistema.</p>
	 * 
	 * @param login    <code>String</code> nombre del usuario.
	 * @param password <code>String</code> contrase&ntilde;a de acceso.
	 * 
	 * @return <code>TOUser</code> Informaci&oacute;n del usuario.
	 * 
	 */
	@Override
	public TOUser signin(String login, String password) throws ExceptionControl {
		
		   //valor por defecto en caso de no encontrar el par&aacute;metro
		   int maxIntentos = 3;
		   
		// Comprobamos que los par&aacute;metros no vengan vac&iacute;os.
		   if ((login == null) || (password == null)) throw (new ExceptionControl(ExceptionControl.MSG_AUTH_PARAM_NULL));
			
		// Abrimos la sesi&oacute;n de Hibernate.
		   Session session = this.sessionFactory.openSession();
				
		   try
			{
			   
			 //Comprobamos que el usuario est&aacute; registrado 
			   Object objBOUser = existRegister(session, Table.USER, "login", login);
			  
			// Comprobamos que no sea null y adem&aacute;s de tipo BOUser.
				if ((objBOUser != null) && (objBOUser instanceof BOUser))
			   	{

					// Cast del usuario.
					BOUser boUser = (BOUser) objBOUser;
					
					// Comprobamos si la cuenta de usuario est&aacute; bloqueada
					if (!boUser.getLocked())
						{
						// Comprobamos si la contrase&ntilde;a es correcta
						   if (boUser.getPassword().equals(password.trim())){
							   
							// Establecemos el n&uacute;mero de intentos a 0
								boUser.setIntentos(0);
								
							// Guardamos la informaci&oacute;n actualizada
								session.saveOrUpdate(boUser);
								
							// Commit
								session.flush();
								
							// retornamos la informaci&oacute;n del usuario en un objeto TOUser
								return boUser.getTOUser();
							   
						   }else{
							   
						   //Recuperamos configuraci&oacute;n de intentos
							   Object objBOConfig = existRegister(session, Table.CONFIG, "name", "login_attempts");
							  
						   //Comprobamos si existe el par&aacute;metro login_attemts
							   if ((objBOConfig != null) && (objBOConfig instanceof BOConfig)){
								   
								// Cast del objeto a BOConfig.
								   BOConfig boConfig = (BOConfig) objBOConfig;
								   
								   try{
									// Informamos el n&uacute;mero m&aacute;ximo de intentos 
									   maxIntentos = Integer.parseInt(boConfig.getValue().trim());
								   }catch (Exception e) {
									 //formato no corrceto
									   maxIntentos = 3;
								   }
							   }
							   
							//Incrementamos  el n&uacute;mero de intentos
							   int intentos = boUser.getIntentos() + 1;
							   boUser.setIntentos(intentos);
							   
							   if(intentos >= maxIntentos){
								   boUser.setLocked(true);
							   }
								   
							// Guardamos la informaci&oacute;n actualizada
							   session.saveOrUpdate(boUser);
								
							// Commit
							   session.flush();
						   }
						}
					
						if(boUser.getLocked()){
							
							// El usuario est&aacute; bloqueado
							throw (new ExceptionControl(ExceptionControl.MSG_USER_LOCKED));
						}
						else
						{
							
							// Password Incorrecta
							throw (new ExceptionControl(ExceptionControl.MSG_USER_PASSWORD_INVALID));
							
						}
				}
				
				//Usuario no registrado
				throw (new ExceptionControl(ExceptionControl.MSG_USER_NOT_REGISTER));
			}
			finally
			{
				
				// Cerramos la sesi&oacute;n de Hibernate
				closeSession(session);
			}
	}

	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera salir del sistema.</p>
	 * 
	 */
	@Override
	public void signout() throws ExceptionControl {
		
	  // No es necesario realizar ninguna acci&oacute;n
	}

	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera recordar su contrase&ntilde;a.
	 *  Se enviara los datos al email recibido por par&aacute;metro.</p>
	 * 
	 * @param email <code>String</code> email del usuario.
	 * 
	 */
	@Override
	public void forgotPassword(String email) throws ExceptionControl {
		   
		// Comprobamos que los par&aacute;metros no vengan vac&iacute;os.
		   if (email == null) throw (new ExceptionControl(ExceptionControl.MSG_AUTH_PARAM_NULL));
		
		// Abrimos una sesi&oacute;n de Hibernate.
		   Session session = sessionFactory.openSession();
		   	
		   try
			{
			// Comprobamos que el usuario est&aacute; registrado 
			   Object objBOUser =existRegister(session, Table.USER, "email", email);
			   
			// Obtenemos la configuraci&oacute;n del Correo
			   Object objBOConfigHOST   = existRegister(session, Table.CONFIG, "name", ParamEmail.HOST.toString());
			   Object objBOConfigPORT   = existRegister(session, Table.CONFIG, "name", ParamEmail.PORT.toString());
			   Object objBOConfigTLS    = existRegister(session, Table.CONFIG, "name", ParamEmail.TLS.toString());
			   Object objBOConfigAUTH   = existRegister(session, Table.CONFIG, "name", ParamEmail.AUTH.toString());
			   Object objBOConfigSOCKETP = existRegister(session, Table.CONFIG, "name", ParamEmail.SOCKET_PORT.toString());
			   Object objBOConfigSOCKETC = existRegister(session, Table.CONFIG, "name", ParamEmail.SOCKET_CLASS.toString());
			   Object objBOConfigUSER   = existRegister(session, Table.CONFIG, "name", ParamEmail.USER.toString());
			   Object objBOConfigPASSWD = existRegister(session, Table.CONFIG, "name", ParamEmail.PASSWD.toString());
			   Object objBOConfigFROM   = existRegister(session, Table.CONFIG, "name", ParamEmail.FROM.toString());
			   
			// Comprobamos que las clases no son nulas y correctas.
			   if ((objBOUser != null) && (objBOUser instanceof BOUser)
					   && (objBOConfigHOST != null) && (objBOConfigHOST instanceof BOConfig)
					   && (objBOConfigPORT != null) && (objBOConfigPORT instanceof BOConfig)
					   && (objBOConfigTLS != null) && (objBOConfigTLS instanceof BOConfig)
					   && (objBOConfigAUTH != null) && (objBOConfigAUTH instanceof BOConfig)
					   && (objBOConfigSOCKETP != null) && (objBOConfigSOCKETP instanceof BOConfig)
					   && (objBOConfigSOCKETC != null) && (objBOConfigSOCKETC instanceof BOConfig)
					   && (objBOConfigUSER != null) && (objBOConfigUSER instanceof BOConfig)
					   && (objBOConfigPASSWD != null) && (objBOConfigPASSWD instanceof BOConfig)
					   && (objBOConfigFROM != null) && (objBOConfigFROM instanceof BOConfig))
					{
	  			    
				     // Realizamos el cast de los objetos
				   		BOUser boUser = (BOUser) objBOUser;
						BOConfig configHOST = (BOConfig) objBOConfigHOST;
						BOConfig configPORT = (BOConfig) objBOConfigPORT;
						BOConfig configTLS = (BOConfig) objBOConfigTLS;
						BOConfig configAUTH = (BOConfig) objBOConfigAUTH;
						BOConfig configSOCKETP = (BOConfig) objBOConfigSOCKETP;
						BOConfig configSOCKETC = (BOConfig) objBOConfigSOCKETC;
						BOConfig configUSER = (BOConfig) objBOConfigUSER;
						BOConfig configPASSWD = (BOConfig) objBOConfigPASSWD;
						BOConfig configFROM = (BOConfig) objBOConfigFROM;
						
						String subjectMensaje = "Recordatorio Datos de Registro Integra";
						
						String bodyMensaje = "Sus datos de registro son: \n\n"
						           + "  Usuario   : " + boUser.getLogin() +"\n"
						           + "  Clave     : " + boUser.getPassword();
						
					 // Enviamos el Correo
						edu.uoc.integra.lib.utils.Validations.sendEmail(configHOST.getValue(), configPORT.getValue(), configTLS.getValue(), 
								  configAUTH.getValue(), configSOCKETP.getValue(), configSOCKETC.getValue(), configUSER.getValue(), configPASSWD.getValue(), 
								  configFROM.getValue(), email, subjectMensaje, bodyMensaje);
						
					}else{
						
						if(!((objBOUser != null) && (objBOUser instanceof BOUser)))
							//Email no registrado
							throw (new ExceptionControl(ExceptionControl.MSG_USER_EMAIL_REGISTER_NOT));
						else
							//Configuraci&oacute;n no cargada
							throw (new ExceptionControl(ExceptionControl.MSG_CONFIGURATION_NOT_LOAD));
					}
			}
			catch (Exception ex)
			{
				// Propagamos la excepci&oacute;n
				throw (new ExceptionControl(ex.getMessage()));
			}
			finally
			{
				// Cerramos la sesi&oacute;n de Hibernate.
				closeSession(session);
			}
	}

}
