package edu.uoc.integra.business.functions;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.hibernate.Session;

import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.interfaces.IBConfigManager;
import edu.uoc.integra.business.objects.BOConfig;
import edu.uoc.integra.business.objects.transfers.TOConfig;


/**
 * <p>Implementa las funcionalidades ofrecidas por la interfaz <code>IBConfigManager</code> </p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 * @see IBConfigManager
 */
public class IBConfigManagerImpl extends IBCommonManagerImpl implements IBConfigManager
{
	
	//************************************************************//
	// CONSTRUCTOR.                                               //
	//************************************************************//
	/**
	 * <p><code>Construye un nuevo objeto <code>IBConfigManagerImpl</code>
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	public IBConfigManagerImpl() 
			throws ExceptionControl	{
		
		super();
		
	}
	
	//************************************************************//
	// METODOS                                                    //
	//************************************************************//
	
	/**
	 * <p>Modifica el valor de un par&aacute;metro determinado de email</p>
	 * 
	 * @param param <code>String</code> par&aacute;metro a modificar
	 * @param value <code>String</code> nuevo valor del par&aacute;metro
	 * 
	 * @return <code>TOConfig</code> representa el par&aacute;metro modificado
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	@Override
	public TOConfig modifyConfigEmail(String param, String value)
			throws ExceptionControl {
		
		// Abrimos una sesi&oacute;n de Hibernate.
		Session session = this.sessionFactory.openSession();
		
		try
		{
			// Comprobamos si existe el Par&aacute;metro definido
			Object objConfig = existRegister(session, Table.CONFIG, "name", param);
					
			// Comprobamos que no es nulo y es de tipo BOConfig
			if ((objConfig != null) && (objConfig instanceof BOConfig)){
				
				// Parseamos objConfig a BOConfig
				BOConfig boConfig = (BOConfig) objConfig;
				
				//Actualizamos el valor del par&aacute;metro
				boConfig.setValue(value);
				
				// Grabamos la modificaci&oacute;n
				session.saveOrUpdate(boConfig);
				
				// Realizamos Commit;
				session.flush();
				
				// Retornamos el objeto actualizado
				return boConfig.getTOConfig();
			}
			
			// No Existe el par&aacute;metro
			throw (new ExceptionControl(ExceptionControl.MSG_CONFIGURATION_NOT_LOAD));
			
		}finally{
			
			// Cerramos sesi&oacute;n de Hibernate.
			session.close();
		}
	}

	
	/**
	 * <p>OBtiene los par&aacute;metros de Configuraci&oacute;n de Email</p>
	 * 
	 * @return <code>List<TOConfig></code> representa el conjunto de par&aacute;metros de email
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	@Override
	public List<TOConfig> listConfigEmail() throws ExceptionControl {
		
		// Abrimos una sesi&oacute;n de Hibernate.
		Session session = this.sessionFactory.openSession();
		
		try
		{
			// Obtenemos la lista de todos los par&aacute;metros registrados
			List<Object> listObject = getRegisters(session, Table.CONFIG);
			
			// Construimos la lista con los par&aacute;metros de tipo email
			List<TOConfig> configs = new ArrayList<TOConfig>();
			
			// Recorremos todos los par&aacute;metros.
			for (Object objConfig : listObject)
			{
				// Comprobamos que el objeto es de tipo BOConfig.
				if (objConfig instanceof BOConfig)
				{
					// Parseamos objConfig a BOConfig
					BOConfig boConfig = (BOConfig) objConfig;
					
					// Si es de tipo email lo a&ntilde;adimos a lista
					if(boConfig.getType().equals(TypeParam.EMAIL.toString())){
					 
						// A&ntilde;adimos a la lista 
						configs.add(boConfig.getTOConfig());
						
					}
						
				}
			}
			
			// Ordenamos la lista
			Collections.sort(configs);
			
			// Retornamos la lista de parametros de email
			return configs;
				
		}finally{
			
		 // Cerramos sesi&oacute;n de Hibernate.
			session.close();
		}
		
	}

	/**
	 * <p>Modifica el valor de un par&aacute;metro determinado de user</p>
	 * 
	 * @param param <code>String</code> par&aacute;metro a modificar
	 * @param value <code>String</code> nuevo valor del par&aacute;metro
	 * 
	 * @return <code>TOConfig</code> representa el par&aacute;metro modificado
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	@Override
	public TOConfig modifyConfigUser(String param, String value)
			throws ExceptionControl {
	 
		// Abrimos una sesi&oacute;n de Hibernate.
		Session session = this.sessionFactory.openSession();
		
		try
		{
			// Comprobamos si existe el Par&aacute;metro definido
			Object objConfig = existRegister(session, Table.CONFIG, "name", param);
					
			// Comprobamos que no es nulo y es de tipo BOConfig
			if ((objConfig != null) && (objConfig instanceof BOConfig)){
				
				// Parseamos objConfig a BOConfig
				BOConfig boConfig = (BOConfig) objConfig;
				
				//Actualizamos el valor del par&aacute;metro
				boConfig.setValue(value);
				
				// Grabamos la modificaci&oacute;n
				session.saveOrUpdate(boConfig);
				
				// Realizamos Commit;
				session.flush();
				
				// Retornamos el objeto actualizado
				return boConfig.getTOConfig();
			}
			
			// No Existe el par&aacute;metro
			throw (new ExceptionControl(ExceptionControl.MSG_CONFIGURATION_NOT_LOAD));
			
		}finally{
			
			// Cerramos sesi&oacute;n de Hibernate.
			session.close();
		}
	}

	/**
	 * <p>OBtiene los par&aacute;metros de Configuraci&oacute;n de Config</p>
	 * 
	 * @return <code>List<TOConfig></code> representa el conjunto de par&aacute;metros de user
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	@Override
	public List<TOConfig> listConfigUser() throws ExceptionControl {
		
		// Abrimos una sesi&oacute;n de Hibernate.
		Session session = this.sessionFactory.openSession();
		
		try
		{
		    // Obtenemos la lista de todos los par&aacute;metros registrados
			List<Object> listObject = getRegisters(session, Table.CONFIG);
			
			// Construimos la lista con los par&aacute;metros de tipo email
			List<TOConfig> configs = new ArrayList<TOConfig>();
			
			// Recorremos todos los par&aacute;metros.
			for (Object objConfig : listObject)
			{
				// Comprobamos que el objeto es de tipo BOConfig.
				if (objConfig instanceof BOConfig)
				{
					// Parseamos objConfig a BOConfig
					BOConfig boConfig = (BOConfig) objConfig;
					
					// Si es de tipo email lo a&ntilde;adimos a lista
					if(boConfig.getType().equals(TypeParam.USER.toString())){
					 
						// A&ntilde;adimos a la lista 
						configs.add(boConfig.getTOConfig());
						
					}
						
				}
			}
			
			// Ordenamos la lista
			Collections.sort(configs);
			
			// Retornamos la lista de parametros de email
			return configs;
				
		}finally{
			
		 // Cerramos sesi&oacute;n de Hibernate.
			session.close();
		}
	}

	
	/**
	 * <p>Modifica el valor de un par&aacute;metro determinado de projecto</p>
	 * 
	 * @param param <code>String</code> par&aacute;metro a modificar
	 * @param value <code>String</code> nuevo valor del par&aacute;metro
	 * 
	 * @return <code>TOConfig</code> representa el par&aacute;metro modificado
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	@Override
	public TOConfig modifyConfigProject(String param, String value)
			throws ExceptionControl {

		// Abrimos una sesi&oacute;n de Hibernate.
		Session session = this.sessionFactory.openSession();
		
		try
		{
			// Comprobamos si existe el Par&aacute;metro definido
			Object objConfig = existRegister(session, Table.CONFIG, "name", param);
					
			// Comprobamos que no es nulo y es de tipo BOConfig
			if ((objConfig != null) && (objConfig instanceof BOConfig)){
				
				// Parseamos objConfig a BOConfig
				BOConfig boConfig = (BOConfig) objConfig;
				
				//Actualizamos el valor del par&aacute;metro
				boConfig.setValue(value);
				
				// Grabamos la modificaci&oacute;n
				session.saveOrUpdate(boConfig);
				
				// Realizamos Commit;
				session.flush();
				
				// Retornamos el objeto actualizado
				return boConfig.getTOConfig();
			}
			
			// No Existe el par&aacute;metro
			throw (new ExceptionControl(ExceptionControl.MSG_CONFIGURATION_NOT_LOAD));
			
		}finally{
			
			// Cerramos sesi&oacute;n de Hibernate.
			session.close();
		}
	}

	/**
	 * <p>OBtiene los par&aacute;metros de Configuraci&oacute;n de Projecto</p>
	 * 
	 * @return <code>List<TOConfig></code> representa el conjunto de par&aacute;metros de projecto
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	@Override
	public List<TOConfig> listConfigProject() throws ExceptionControl {
		
		// Abrimos una sesi&oacute;n de Hibernate.
		Session session = this.sessionFactory.openSession();
		
		try
		{
		    // Obtenemos la lista de todos los par&aacute;metros registrados
			List<Object> listObject = getRegisters(session, Table.CONFIG);
			
			// Construimos la lista con los par&aacute;metros de tipo email
			List<TOConfig> configs = new ArrayList<TOConfig>();
			
			// Recorremos todos los par&aacute;metros.
			for (Object objConfig : listObject)
			{
				// Comprobamos que el objeto es de tipo BOConfig.
				if (objConfig instanceof BOConfig)
				{
					// Parseamos objConfig a BOConfig
					BOConfig boConfig = (BOConfig) objConfig;
					
					// Si es de tipo email lo a&ntilde;adimos a lista
					if(boConfig.getType().equals(TypeParam.PROJECT.toString())){
					 
						// A&ntilde;adimos a la lista 
						configs.add(boConfig.getTOConfig());
						
					}
						
				}
			}
			
			// Ordenamos la lista
			Collections.sort(configs);
			
			// Retornamos la lista de parametros de email
			return configs;
				
		}finally{
			
		 // Cerramos sesi&oacute;n de Hibernate.
			session.close();
		}
	}

	/**
	 * <p>OBtiene los par&aacute;metros de Configuraci&oacute;n del Sistema</p>
	 * 
	 * @return <code>List<TOConfig></code> representa el conjunto de par&aacute;metros del sistema
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	@Override
	public List<TOConfig> listConfig() throws ExceptionControl {

	 // Abrimos una sesi&oacute;n de Hibernate.
		Session session = this.sessionFactory.openSession();
		
		try
		{
		    // Obtenemos la lista de todos los par&aacute;metros registrados
			List<Object> listObject = getRegisters(session, Table.CONFIG);
			
			// Construimos la lista con los par&aacute;metros de tipo email
			List<TOConfig> configs = new ArrayList<TOConfig>();
			
			// Recorremos todos los par&aacute;metros.
			for (Object objConfig : listObject)
			{
				// Comprobamos que el objeto es de tipo BOConfig.
				if (objConfig instanceof BOConfig)
				{
					// Parseamos objConfig a BOConfig
					BOConfig boConfig = (BOConfig) objConfig;
					
					// A&ntilde;adimos a la lista 
					configs.add(boConfig.getTOConfig());
						
						
				}
			}
			
			// Ordenamos la lista
			Collections.sort(configs);
			
			// Retornamos la lista de parametros de email
			return configs;
				
		}finally{
			
		 // Cerramos sesi&oacute;n de Hibernate.
			session.close();
		}
	}

	/**
	 * <p>Consulta la informaci&oacute; de un determinado par&aacute;metro de Configuraci&oacute;n del Sistema</p>
	 * 
	 * @return <code>TOConfig</code> representa la informaci&oacute; de un par&aacute;metro del sistema
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	@Override
	public TOConfig getConfig(int idConfig) throws ExceptionControl {
		 
		
	 // Abrimos la sesi&oacute;n de Hibernate.
		Session session = this.sessionFactory.openSession();
				
		try
		{
			// Comprobamos que el usuario est&aacute; registrado
			Object objBOConfig = existRegister(session, Table.CONFIG, "id", idConfig);
					
			// Comprobamos que no es nulo y adem&aacute;s es de tipo BOConfig.
			if ((objBOConfig != null) && (objBOConfig instanceof BOConfig))
			{
				 // Realizamos el cast del objeto
				 BOConfig boConfig = (BOConfig) objBOConfig;
				
				 //Retornamos la informaci&oacute;n del objeto en un objeto TOConfig
				return boConfig.getTOConfig();
						
			}
					
			// Identificador no V&aacute;lido
			throw (new ExceptionControl(ExceptionControl.MSG_CONFIG_ID_INVALID));
		}
		finally
		{
			// Cerramos la sesi&oacute;n de Hibernate.
			closeSession(session);
		}
	}
	
}
