package edu.uoc.integra.business.functions;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import org.hibernate.Session;

import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.interfaces.IBInfoManager;
import edu.uoc.integra.business.objects.BOInform;
import edu.uoc.integra.business.objects.BOProject;
import edu.uoc.integra.business.objects.BORol;
import edu.uoc.integra.business.objects.BOState;
import edu.uoc.integra.business.objects.BOUserRol;
import edu.uoc.integra.business.objects.BOWorkFlow;
import edu.uoc.integra.business.objects.transfers.TOInform;
import edu.uoc.integra.business.objects.transfers.TOInformC;
import edu.uoc.integra.business.objects.transfers.TOInformR;
import edu.uoc.integra.business.objects.transfers.TOProject;
import edu.uoc.integra.business.objects.transfers.TORol;
import edu.uoc.integra.business.objects.transfers.TOState;
import edu.uoc.integra.business.objects.transfers.TOUserRol;
import edu.uoc.integra.business.objects.transfers.TOWorkFlow;



public class IBInfoManagerImpl extends IBCommonManagerImpl implements IBInfoManager {

	//************************************************************//
	// CONSTRUCTOR.                                               //
	//************************************************************//
	/**
	 * <p><code>Construye un nuevo objeto <code>IBAuthManagerImpl</code>
	 * @return 
	 * 
	 * @throws ExceptionControl para los posibles excepciones que se produzcan
	 */
	public IBInfoManagerImpl() throws ExceptionControl {
		
		// Constructor de la superclase.
		super();
	}

	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera generar un informe completo 
	 * de un proyecto definido en  el sistema.</p>
	 * 
	 * @param project <code>TOProject</code> informaci&oacute;n del proyecto
	 * 
	 * @return <code>TOInformC</code> Informaci&oacute;n del informe completo.
	 * 
	 */
	@Override
	public TOInformC informComp(TOProject project) throws ExceptionControl {
		
		// Abrimos una sesi&oacute;n de Hibernate.
		Session session = sessionFactory.openSession();
		
		try
		{
			// Comprobamos si "id"  del proyecto  se encuentra registrado.
			Object objProject = existRegister(session, Table.PROJECT, "id", project.getId());
			
			if (objProject == null)
			{
				// Lanzamos Excepci&oacute;n
				throw (new ExceptionControl(ExceptionControl.MSG_PROJECT_ID_INVALID));
			}
			
			//Casteamos datos del Proyecto
			TOProject toProject = (TOProject) objProject;
			
			//Informamos los datos del projecto
			TOInformC informe = new TOInformC(toProject);
			
			//Obtenemos los roles del Proyecto
			List<Object> list = getRegisters(session, Table.ROL, "idproject", project.getId());
			
			// Construimos la lista con los objetos que ser&aacute;n retornados.
			List<TORol> rols = new ArrayList<TORol>();
						
			// Recorremos todos los roles recuperados.
			for (Object objBORol : list)
			{
				// Comprobamos que el objeto es de tipo BORol.
				if (objBORol instanceof BORol)
				{
					// Realizamos el cast del objeto
					BORol boRol = (BORol) objBORol;
					// A&ntilde;adimos a la lista el TORol equivalente a BORol.
					rols.add(boRol.getTORol());
				}
			}
						
			// Una vez tenemos todos los roles los ordenamos por "name"
			Collections.sort(rols);
			
			// Guardamos los roles en el informe
			informe.setRols(rols);
			
			// Obtenemos la lista de todos los estados registrados para un proyecto.
			list = getRegisters(session, Table.STATE, "idproject", project.getId());
			
			// Construimos la lista con los objetos que ser&aacute;n retornados.
			List<TOState> states = new ArrayList<TOState>();
						
			// Recorremos todos los estados recuperados.
			for (Object objBOState : list)
			{
				// Comprobamos que el objeto es de tipo BOState.
				if (objBOState instanceof BOState)
				{
			 	 // Realizamos el cast del objeto
					BOState boState = (BOState) objBOState;
				// A&ntilde;adimos a la lista el TOState equivalente a BOState.
					states.add(boState.getTOState());
				}
			}
			
			// Una vez tenemos todos los estados los ordenamos por "name"
			Collections.sort(states);
			
			// Guardamos los states en el informe
			informe.setStates(states);
			
			// Obtenemos la lista de todos los workflows registrados para un proyecto.
			list = getRegisters(session, Table.WORKFLOW, "idproject", project.getId());
			
			// Construimos la lista con los objetos que ser&aacute;n retornados.
			List<TOWorkFlow> workflows = new ArrayList<TOWorkFlow>();
						
			// Recorremos todos los estados recuperados.
			for (Object objBOWorkFlow : list)
			{
				// Comprobamos que el objeto es de tipo BOWorkFlow.
				if (objBOWorkFlow instanceof BOWorkFlow)
				{
					// Realizamos el cast del objeto
					BOWorkFlow boWorkflow = (BOWorkFlow) objBOWorkFlow;
								
					// A&ntilde;adimos a la lista el TOWorkFlow equivalente a BOWorkFlow.
					workflows.add(boWorkflow.getTOWorkFlowStateNext());
				}
			}
						
			// Una vez tenemos todos los estados los ordenamos 
			Collections.sort(workflows);

			// Guardamos los workflows en el informe
			informe.setWorkFlows(workflows);
			
			// Obtenemos la lista de todos los estados registrados para un proyecto.
			list = getRegisters(session, Table.USERROL, "idproject", project.getId());
			
			// Construimos la lista con los objetos que ser&aacute;n retornados.
			List<TOUserRol> userrols = new ArrayList<TOUserRol>();
						
			// Recorremos todos los usuarios-roles recuperados.
			for (Object objBOUserRol : list)
			{
				// Comprobamos que el objeto es de tipo BOUserRol.
				if (objBOUserRol instanceof BOUserRol)
				{
					// Realizamos el cast del objeto
					BOUserRol boUserRol = (BOUserRol) objBOUserRol;
								
					// A&ntilde;adimos a la lista el TOBoUserRol equivalente a BOUserRol.
					userrols.add(boUserRol.getTOUserRol());
				}
			}
						
			// Una vez tenemos todos los estados los ordenamos 
			Collections.sort(userrols);
			
			// Guardamos los userrols en el informe
			informe.setUsers(userrols);
			
			// Retornamos el informe
			return informe;
		}
		catch (Exception e)
		{
			System.out.println("Se ha producido un error:" + e.getMessage());
			// Lanzamos Excepci&oacute;n
			throw new ExceptionControl(e.getMessage());
		}
		finally
		{
			// Cerramos la sesi&oacute;n de Hibernate
			closeSession(session);
		}
	}

	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera generar un informe resumen 
	 * de un proyecto definido en  el sistema.</p>
	 * 
	 * @param project <code>TOProject</code> informaci&oacute;n del proyecto
	 * 
	 * @return <code>TOInformR</code> Informaci&oacute;n del informe resumen.
	 * 
	 */
	@Override
	public TOInformR informResu(TOProject project) throws ExceptionControl {
		
		// Abrimos una sesi&oacute;n de Hibernate.
		Session session = sessionFactory.openSession();
		
		try
		{
			// Comprobamos si "id"  del proyecto  se encuentra registrado.
			Object objProject = existRegister(session, Table.PROJECT, "id", project.getId());
			
			if (objProject == null)
			{
				// Lanzamos Excepci&oacute;n
				throw (new ExceptionControl(ExceptionControl.MSG_PROJECT_ID_INVALID));
			}
			
			//Casteamos datos del Proyecto
			BOProject boProject = (BOProject) objProject;
			
			//Informamos los datos del projecto
			TOInformR informe = new TOInformR(boProject.getTOProject());
			
			//Obtenemos los roles del Proyecto
			List<Object> list = getRegisters(session, Table.ROL, "idproject", project.getId());
			
			// Construimos la lista con los objetos que ser&aacute;n retornados.
			List<TORol> rols = new ArrayList<TORol>();
						
			// Recorremos todos los roles recuperados.
			for (Object objBORol : list)
			{
				// Comprobamos que el objeto es de tipo BORol.
				if (objBORol instanceof BORol)
				{
					// Realizamos el cast del objeto
					BORol boRol = (BORol) objBORol;
					// A&ntilde;adimos a la lista el TORol equivalente a BORol.
					rols.add(boRol.getTORol());
				}
			}
						
			// Una vez tenemos todos los roles los ordenamos por "name"
			Collections.sort(rols);
			
			// Guardamos los roles en el informe
			informe.setRols(rols);
			
			// Obtenemos la lista de todos los estados registrados para un proyecto.
			list = getRegisters(session, Table.STATE, "idproject", project.getId());
			
			// Construimos la lista con los objetos que ser&aacute;n retornados.
			List<TOState> states = new ArrayList<TOState>();
						
			// Recorremos todos los estados recuperados.
			for (Object objBOState : list)
			{
				// Comprobamos que el objeto es de tipo BOState.
				if (objBOState instanceof BOState)
				{
			 	 // Realizamos el cast del objeto
					BOState boState = (BOState) objBOState;
				// A&ntilde;adimos a la lista el TOState equivalente a BOState.
					states.add(boState.getTOState());
				}
			}
			
			// Una vez tenemos todos los estados los ordenamos por "name"
			Collections.sort(states);
			
			// Guardamos los states en el informe
			informe.setStates(states);
			
			// Obtenemos la lista de todos los workflows registrados para un proyecto.
			list = getRegisters(session, Table.WORKFLOW, "idproject", project.getId());
			
			// Construimos la lista con los objetos que ser&aacute;n retornados.
			List<TOWorkFlow> workflows = new ArrayList<TOWorkFlow>();
						
			// Recorremos todos los estados recuperados.
			for (Object objBOWorkFlow : list)
			{
				// Comprobamos que el objeto es de tipo BOWorkFlow.
				if (objBOWorkFlow instanceof BOWorkFlow)
				{
					// Realizamos el cast del objeto
					BOWorkFlow boWorkflow = (BOWorkFlow) objBOWorkFlow;
								
					// A&ntilde;adimos a la lista el TOWorkFlow equivalente a BOWorkFlow.
					workflows.add(boWorkflow.getTOWorkFlowStateNext());
				}
			}
						
			// Una vez tenemos todos los estados los ordenamos 
			Collections.sort(workflows);

			// Guardamos los workflows en el informe
			informe.setWorkFlows(workflows);
			
			// Obtenemos la lista de todos los estados registrados para un proyecto.
			list = getRegisters(session, Table.USERROL, "idproject", project.getId());
			
			// Construimos la lista con los objetos que ser&aacute;n retornados.
			List<TOUserRol> userrols = new ArrayList<TOUserRol>();
						
			// Recorremos todos los usuarios-roles recuperados.
			for (Object objBOUserRol : list)
			{
				// Comprobamos que el objeto es de tipo BOUserRol.
				if (objBOUserRol instanceof BOUserRol)
				{
					// Realizamos el cast del objeto
					BOUserRol boUserRol = (BOUserRol) objBOUserRol;
								
					// A&ntilde;adimos a la lista el TOBoUserRol equivalente a BOUserRol.
					userrols.add(boUserRol.getTOUserRol());
				}
			}
						
			// Una vez tenemos todos los estados los ordenamos 
			Collections.sort(userrols);
			
			// Guardamos los userrols en el informe
			informe.setUsers(userrols);
			
			// Retornamos el informe
			return informe;
		}
		catch (Exception e)
		{
			System.out.println("Se ha producido un error:" + e.getMessage());
			// Lanzamos Excepci&oacute;n
			throw new ExceptionControl(e.getMessage());
		}
		finally
		{
			// Cerramos la sesi&oacute;n de Hibernate
			closeSession(session);
		}
	}

	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera generar un informe evoluci&oacute;n 
	 * de un proyecto definido en  el sistema.</p>
	 * 
	 * @param project <code>TOProject</code> informaci&oacute;n del proyecto
	 * 
	 * @return <code>TOInformE</code> Informaci&oacute;n del informe evoluci&oacute;n.
	 * 
	 */
	@Override
	public TOInformR informEvo(TOProject project) throws ExceptionControl {
		// TODO Auto-generated method stub
		return null;
	}

	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera obtener una lista
	 * de los informes disponibles</p>
	 * 
	 * 
	 * @return <code>List&lt;TOInform&gt;</code> Lista que contiene los informes definidos en el sistema.
	 * 
	 */
	@Override
	public List<TOInform> listInform() throws ExceptionControl {

		// Abrimos una sesi&oacute;n de Hibernate.
		Session session = sessionFactory.openSession();
		
		try
		{
									
			// Obtenemos la lista de todos los usuarios registrados.
			List<Object> list = getRegisters(session, Table.INFORM);
			
			// Construimos la lista con los objetos que ser&aacute;n retornados.
			List<TOInform> informs = new ArrayList<TOInform>();
			
			// Recorremos todos los usuarios.
			for (Object objBOInform : list)
			{
				// Comprobamos que el objeto es de tipo BOInform.
				if (objBOInform instanceof BOInform)
				{
					// Realizamos el cast del objeto
					BOInform boInform = (BOInform) objBOInform;
					
					// A&ntilde;adimos a la lista el TOInform equivalente a BOInform.
					informs.add(boInform.getTOInform());
				}
			}
			
			// Una vez tenemos todos los informes los ordenamos por "id"
			Collections.sort(informs);
			
			// Retornamos la lista de informes.
			return informs;
		}
		catch (Exception e)
		{
			// Lanzamos Excepci&oacute;n
			throw new ExceptionControl(e.getMessage());
		}
		finally
		{
			// Cerramos la sesi&oacute;n de Hibernate
			closeSession(session);
		}
	}

	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera obtener informaci&oacute;n de un determinado informe</p>
	 * 
	 * @param idInform <code>int</code> identificador del informe que se solicita informaci&oacute;n.
	 * 
	 * @return <code>TOInform</code> Contiene informaci&oacute;n del informe.
	 * 
	 */
	@Override
	public TOInform getInform(int idInform) throws ExceptionControl {
		
		   
		 // Abrimos una sesi&oacute;n de Hibernate.
			Session session = sessionFactory.openSession();
				
			try
			{
				// Comprobamos si "id"  del informe.
				Object objInform = existRegister(session, Table.INFORM, "id", idInform);
					
				if (objInform == null)
				{
					// Lanzamos Excepci&oacute;n
					throw (new ExceptionControl(ExceptionControl.MSG_INFORM_ID_INVALID));
				}
					
				//Casteamos datos del Proyecto
				BOInform boInforme = (BOInform) objInform;
					
				// Retornamos el informe
				return boInforme.getTOInform();
			}
			catch (Exception e)
			{
				System.out.println("Se ha producido un error:" + e.getMessage());
				// Lanzamos Excepci&oacute;n
				throw new ExceptionControl(e.getMessage());
			}
			finally
			{
				// Cerramos la sesi&oacute;n de Hibernate
				closeSession(session);
			}
	}


}
