package edu.uoc.integra.business.interfaces;

import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.objects.transfers.TOUser;

/**
 * <p>Interfaz que define todas las funcionalidades que est&aacute;n relacionadas
 * con la gesti&oacute;n de autorizaci&oacute;n al sistema. Estas funcionalidades son presentadas a la
 * la capa de presentaci&oacute;n desde la capa de negocio</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public interface IBAuthManager {
	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera acceder al sistema.</p>
	 * 
	 * @param login <code>String</code> nombre del usuario.
	 * @param password <code>String</code> contrase&ntilde;a de acceso.
	 * 
	 * @return <code>TOUser</code> Informaci&oacute;n del usuario.
	 * 
	 */
	public abstract TOUser signin(String login, String password) throws ExceptionControl;
	
	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera salir del sistema.</p>
	 * 
	 */
	public abstract void signout()  throws ExceptionControl;
	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera recordar su contrase&ntilde;a.
	 *  Se enviara los datos al email recibido por par&aacute;metro.</p>
	 * 
	 * @param email <code>String</code> email del usuario.
	 * 
	 */
	public abstract void forgotPassword(String email)  throws ExceptionControl;

}
