package edu.uoc.integra.business.interfaces;

import java.util.List;

import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.objects.transfers.TOConfig;


/**
 * <p>Interfaz que define todas las funcionalidades que est&aacute;n relacionadas
 * con la gesti&oacute;n de par&aacute;metros del sistema. Estas funcionalidades son presentadas a la
 * la capa de presentaci&oacute;n desde la capa de negocio</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public interface IBConfigManager
{
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere modificar  la informaci&oacute;n de
	 * un par&aacute;metro de tipo email a partir de la informaci&oacute;n recibida por par&aacute;metro </p>
	 * 
	 * @param param <code>String</code> par&aacute;metro de email.
	 * @param value <code>String</code> valor del par&aacute;metro del email.

	 * @return <code>TOConfig</code> informaci&oacute;n actualizada del email.
	 * 
	 */
	public abstract TOConfig modifyConfigEmail(String param,String value)  throws ExceptionControl; 
	
	/**
	 * <p>Este m&eacute;todo es llamado cada vez que se quiere consultar la lista de
	 * par&aacute;metros de email definidos en el sistema.</p>
	 * 
	 * @return <code>List&lt;TOConfig&gt;</code> lista de par&aacute;metros email
	 * 
	 */
	public abstract List<TOConfig> listConfigEmail()  throws ExceptionControl;
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere modificar  la informaci&oacute;n de
	 * un par&aacute;metro de tipo usuario a partir de la informaci&oacute;n recibida por par&aacute;metro </p>
	 * 
	 * @param param <code>String</code> par&aacute;metro de usuario.
	 * @param value <code>String</code> valor del par&aacute;metro de usuario.

	 * @return <code>TOConfig</code> informaci&oacute;n actualizada de usuario.
	 * 
	 */
	public abstract TOConfig modifyConfigUser(String param,String value)  throws ExceptionControl; 
	
	/**
	 * <p>Este m&eacute;todo es llamado cada vez que se quiere consultar la lista de
	 * par&aacute;metros de usuarios definidos en el sistema.</p>
	 * 
	 * @return <code>List&lt;TOConfig&gt;</code> lista de par&aacute;metros de usuarios
	 * 
	 */
	public abstract List<TOConfig> listConfigUser()  throws ExceptionControl;
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere modificar  la informaci&oacute;n de
	 * un par&aacute;metro de tipo proyecto a partir de la informaci&oacute;n recibida por par&aacute;metro </p>
	 * 
	 * @param param <code>String</code> par&aacute;metro de proyecto.
	 * @param value <code>String</code> valor del par&aacute;metro del proyecto.

	 * @return <code>TOConfig</code> informaci&oacute;n actualizada del proyecto.
	 * 
	 */
	public abstract TOConfig modifyConfigProject(String param,String value)  throws ExceptionControl; 
	
	/**
	 * <p>Este m&eacute;todo es llamado cada vez que se quiere consultar la lista de
	 * par&aacute;metros del Proyecto definidos en el sistema.</p>
	 * 
	 * @return <code>List&lt;TOConfig&gt;</code> lista de par&aacute;metros del Proyecto
	 * 
	 */
	public abstract List<TOConfig> listConfigProject()  throws ExceptionControl;

	/**
	 * <p>Este m&eacute;todo es llamado cada vez que se quiere consultar la lista de
	 * par&aacute;metros definidos en el sistema.</p>
	 * 
	 * @return <code>List&lt;TOConfig&gt;</code> lista de par&aacute;metros del sistema
	 * 
	 */
	public abstract List<TOConfig> listConfig()  throws ExceptionControl;
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar  la informaci&oacute;n de
	 * un pat&aacute;metro a partir de la informaci&oacute;n recibida por par&aacute;metro </p>
	 * 
	 * @param idParam <code>int</code> identificador del par&aacute;metro.
	 * 
	 * @return <code>TOConfig</code> contiene la informaci&oacute;n del par&aacute;metro cuyo
	 * <i>id</i> es igual al que se ha recibido como par&aacute;metro.
	 * 
	 */
	public abstract TOConfig getConfig(int idConfig) throws ExceptionControl;
	
}
