package edu.uoc.integra.business.interfaces;

import java.util.List;
import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.objects.transfers.TOInform;
import edu.uoc.integra.business.objects.transfers.TOInformC;
import edu.uoc.integra.business.objects.transfers.TOInformR;
import edu.uoc.integra.business.objects.transfers.TOProject;

/**
 * <p>Interfaz que define todas las funcionalidades que est&aacute;n relacionadas
 * con la generaci&oacuten de informes en  el sistema. Estas funcionalidades son presentadas a la
 * la capa de presentaci&oacute;n desde la capa de negocio</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public interface IBInfoManager {
	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera generar un informe completo 
	 * de un proyecto definido en  el sistema.</p>
	 * 
	 * @param project <code>TOProject</code> informaci&oacute;n del proyecto
	 * 
	 * @return <code>TOInformC</code> Informaci&oacute;n del informe completo.
	 * 
	 */
	public abstract TOInformC informComp(TOProject project) throws ExceptionControl;
	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera generar un informe resumen 
	 * de un proyecto definido en  el sistema.</p>
	 * 
	 * @param project <code>TOProject</code> informaci&oacute;n del proyecto
	 * 
	 * @return <code>TOInformR</code> Informaci&oacute;n del informe resumen.
	 * 
	 */
	public abstract TOInformR informResu(TOProject project) throws ExceptionControl;
	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera generar un informe evoluci&oacute;n 
	 * de un proyecto definido en  el sistema.</p>
	 * 
	 * @param project <code>TOProject</code> informaci&oacute;n del proyecto
	 * 
	 * @return <code>TOInformE</code> Informaci&oacute;n del informe evoluci&oacute;n.
	 * 
	 */
	public abstract TOInformR informEvo(TOProject project) throws ExceptionControl;
	
	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera obtener una lista
	 * de los informes disponibles</p>
	 * 
	 * 
	 * @return <code>List&lt;TOInform&gt;</code> Lista que contiene los informes definidos en el sistema.
	 * 
	 */
	public abstract List<TOInform> listInform() throws ExceptionControl;

	/**
	 * <p>Este m&eacute;todo es invocado cada vez que un usuario quiera obtener informaci&oacute;n de un determinado informe</p>
	 * 
	 * @param idInform <code>int</code> identificador del informe que se solicita informaci&oacute;n.
	 * 
	 * @return <code>TOInform</code> Contiene informaci&oacute;n del informe.
	 * 
	 */
	public abstract TOInform getInform(int idInform) throws ExceptionControl;

}
