package edu.uoc.integra.business.objects;

import java.io.Serializable;
import java.util.Date;

import edu.uoc.integra.business.objects.transfers.TOArtefact;

/**
 * <p>Clase que contiene la informaci&oacute;n de los artefactos.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BOArtefact implements Serializable 
{
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del artefacto. </p> */
	protected int id;
	/** <p>Secuencial del artefacto.</p> */
	protected int sec;
	/** <p>Nombre del artefacto.</p> */
	protected String name;
	/** <p>Descripci&oacuten; corta.</p> */
	protected String descShort;
	/** <p>Descripci&oacute;n larga.</p> */
	protected String descript;	
	/** <p>Prioridad del artefacto.</p> */
	protected String priory;
	/** <p>Fecha Inicio.</p> */
	protected Date  fecini;
	/** <p>Fecha Fin.</p> */
	protected Date  fecfin;
	/** <p>Estado Actual.</p> */
	protected BOState idState;
	/** <p>Esfuerzo Actual.</p> */
	protected float effort;
	/** <p>Usuario Actual.</p> */
	protected BOUserRol idUser;
	/** <p>Fecha de Alta.</p> */
	protected Date timestampA;
	/** <p>Usuario Alta.</p> */
	protected BOUser idUserA;
	/** <p>Proyecto.</p> */
	protected BOProject idProject;

	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BOArtefact</code></p>
	 */
	public BOArtefact()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>BOArtefact</code> a partir de los par&aacute;metros recibidos por par&aacute;metro.</p>
	 * 
	 * @param sec <code>int</code> secuencia de la ultima historia.
	 * @param name <code>String</code> Nombre del artefacto.
	 * @param descShort <code>String</code> Descripci&oacuten; corta.
	 * @param descript <code>String</code> Descripci&oacute;n larga.
	 * @param priory <code>String</code> Prioridad del artefacto.
	 * @param fecini <code>Date</code> Fecha Inicio.
	 * @param fecfin <code>Date</code> Fecha Fin.
	 * @param idState <code>TOState</code> Estado Actual.
	 * @param effort  <code>float</code> Esfuerzo Actual.
	 * @param idUser <code>TOUserRol</code> Usuario Actual
	 * @param idUserA <code>TOUser</code> Usuario Alta
	 * @param timestampA <code>Date</code> TimeStamp Alta
	 * @param idProject <code>TOProject</code> Proyecto
	 * 
	 */
	public BOArtefact( int sec, String name,  String descShort, String descript, String priory,
			Date fecini, Date fecfin, BOState idState,float effort, BOUserRol idUser,
			BOUser idUserA, Date timestampA, BOProject idProject )
	{
		
		super();
		
		try 
			{
			// Asignamos los valores a los atributos
			//BeanUtils.copyProperties(this, to);
				this.sec=sec;
				this.name=name;
				this.descShort=descShort;
				this.descript=descript;
				this.priory=priory;
				this.fecini=fecini;
				this.fecfin=fecfin;
				this.idState=idState;
				this.effort=effort;
				this.idUser=idUser;
				this.idUserA=idUserA;
				this.idProject=idProject;
			} 
			catch (Exception ex)
			{
				//No es necesario recoger ninguna excepci&oacute;n
			}

	}
	
	/**
	 * <p>Construye un objeto <code>BOArtefact</code> a partir del atributo recibido por par&aacute;metro.</p>
	 * 
	 * @param id <code>int</code> identificador del artefacto.
	 */
	public BOArtefact(int id)
	{
		super();
		
		//Identificador de artefacto
		this.id = id;
	}

	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	// sec
	public int getSec() {
		return sec;
	}

	public void setSec(int sec) {
		this.sec = sec;
	}

	// name
	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	// descShort
	public String getDescShort() {
		return descShort;
	}

	public void setDescShort(String descShort) {
		this.descShort = descShort;
	}

	// descript
	public String getDescript() {
		return descript;
	}

	public void setDescript(String descript) {
		this.descript = descript;
	}

	// priory
	public String getPriory() {
		return priory;
	}

	public void setPriory(String priory) {
		this.priory = priory;
	}

	// fecini
	public Date getFecini() {
		return fecini;
	}

	public void setFecini(Date fecini) {
		this.fecini = fecini;
	}

	// fecfin
	public Date getFecfin() {
		return fecfin;
	}

	public void setFecfin(Date fecfin) {
		this.fecfin = fecfin;
	}

	// idState
	public BOState getIdState() {
		return idState;
	}

	public void setIdState(BOState idState) {
		this.idState = idState;
	}

	// effort
	public float getEffort() {
		return effort;
	}

	public void setEffort(float effort) {
		this.effort = effort;
	}

	// idUser
	public BOUserRol getIdUser() {
		return idUser;
	}

	public void setIdUser(BOUserRol idUser) {
		this.idUser = idUser;
	}

	// timestampA
	public Date getTimestampA() {
		return timestampA;
	}

	public void setTimestampA(Date timestampA) {
		this.timestampA = timestampA;
	}

	// idUserA
	public BOUser getIdUserA() {
		return idUserA;
	}

	public void setIdUserA(BOUser idUserA) {
		this.idUserA = idUserA;
	}

	// idProject
	public BOProject getIdProject() {
		return idProject;
	}

	public void setIdProject(BOProject idProject) {
		this.idProject = idProject;
	}
		
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	
	/**
	 * <p>A partir de un objeto <code>BOArtefact</code> generamos un objeto <code>TOArtefact</code>.</p>
	 * 
	 * @return <code>TOArtefact</code> generado a partir del objeto <code>BOArtefact</code>.
	 */
	public TOArtefact getTOArtefact()
	{
		try
		{
			// Instanciamos un nuevo objeto
			TOArtefact artefact = new TOArtefact();
			
			// Copiamos la informaci&oacute;n de un objeto a otro
			//BeanUtils.copyProperties(artefact, this);
			artefact.setId(this.id);
			artefact.setSec(this.sec);
			artefact.setName(this.name);
			artefact.setDescShort(this.descShort);
			artefact.setDescript(this.descript);
			artefact.setPriory(this.priory);
			artefact.setFecini(this.fecini);
			artefact.setFecfin(this.fecfin);
			artefact.setEffort(this.effort);
			
			
			artefact.setIdState(this.idState.getId());
			artefact.setNameState(this.idState.getName());
			
			artefact.setIdUser(this.idUser.getIduser().getId());
			artefact.setNameUser(this.idUser.getIduser().getName());
			
			artefact.setIdUserA(this.idUserA.getId());
			artefact.setNameUserA(this.idUserA.getName());
			
			artefact.setIdProject(this.idProject.getId());
			artefact.setNameProject(this.idProject.getName());
			
			artefact.setTimestampA(this.timestampA);
			
			// Retornamos el objeto.
			return artefact;
		}
		catch (Exception ex)
		{
			// En caso de error retornamos null 
			return null;
		}
	}
	
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BOArtefact
		if ((obj == null) || (!(obj instanceof BOArtefact)))
		{
			// Retornamos que no son iguales.
			return false;
		}
		
		BOArtefact objArtefact = (BOArtefact) obj;
		
		// Comparamos el identificador de ambos objetos
		return (this.id == objArtefact.getId());
	}

	
}
