package edu.uoc.integra.business.objects;

import java.io.Serializable;
import java.util.Date;

import edu.uoc.integra.business.objects.transfers.TOArtefactU;

/**
 * <p>Clase que contiene la informaci&oacute;n de los usuarios asignados a un artefacto.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BOArtefactU implements Serializable 
{
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del artefactoU. </p> */
	protected int id;
	/** <p>Fecha Inicio.</p> */
	protected Date  fecini;
	/** <p>Fecha Fin.</p> */
	protected Date  fecfin;
	/** <p>Usuario-Rol asignado.</p> */
	protected BOUserRol iduserrol;
	/** <p>Artefacto asignado.</p> */
	protected BOArtefact idartefact;
	/** <p>Usuario asignado.</p> */
	protected BOUser iduser;
	/** <p>Rol asignado.</p> */
	protected BORol idrol;
	/** <p>Proyecto asignado.</p> */
	protected BOProject idproject;

	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BOArtefactU</code></p>
	 */
	public BOArtefactU()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>BOArtefactU</code> a partir de los par&aacute;metros recibidos por par&aacute;metro.</p>
	 * 
	 * @param fecini <code>Date</code> Fecha Inicio.
	 * @param fecfin <code>Date</code> Fecha Fin.
	 * @param iduserrol <code>BOUserRol</code> Usuario-Rol
	 * @param idartefact <code>BOArtefact</code> artefacto
	 * @param iduser <code>BOUser</code> usuario
	 * @param idrol <code>BORol</code> rol
	 * @param idproject <code>BOProject</code> proyecto
	 * 
	 */
	public BOArtefactU(Date fecini, Date fecfin, BOUserRol iduserrol
			, BOArtefact idartefact, BOUser iduser, BORol idrol, BOProject idproject )
	{
		
		super();
		
		try 
			{
			// Asignamos los valores a los atributos
			//BeanUtils.copyProperties(this, to);
				this.fecini=fecini;
				this.fecfin=fecfin;
				this.setIduserrol(iduserrol);
				this.setIdartefact(idartefact);
				this.setIduser(iduser);
				this.setIdrol(idrol);
				this.setIdproject(idproject);
				
				System.out.println("fecini:" + this.fecini);
				System.out.println("fecfin:" + this.fecfin);
				System.out.println("userrol:" + this.iduserrol.getId());
				
				System.out.println("user:" +this.iduser.getId());
				System.out.println("rol:" +this.idrol.getId());
				System.out.println("project:" +this.idproject.getId());
				
				System.out.println("artefact:" + this.idartefact.getId());
				
			} 
			catch (Exception ex)
			{
				//No es necesario recoger ninguna excepci&oacute;n
			}

	}
	
	/**
	 * <p>Construye un objeto <code>BOArtefactU</code> a partir del atributo recibido por par&aacute;metro.</p>
	 * 
	 * @param id <code>int</code> identificador del artefactoU.
	 */
	public BOArtefactU(int id)
	{
		super();
		
		//Identificador de artefacto
		this.id = id;
	}

	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//
	
	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	// fecini
	public Date getFecini() {
		return fecini;
	}

	public void setFecini(Date fecini) {
		this.fecini = fecini;
	}

	// fecfin
	public Date getFecfin() {
		return fecfin;
	}

	public void setFecfin(Date fecfin) {
		this.fecfin = fecfin;
	}
	
	// iduserrol
	public BOUserRol getIduserrol() {
		return iduserrol;
	}

	public void setIduserrol(BOUserRol iduserrol) {
		this.iduserrol = iduserrol;
	}

	// idartefact
	public BOArtefact getIdartefact() {
		return idartefact;
	}

	public void setIdartefact(BOArtefact idartefact) {
		this.idartefact = idartefact;
	}

	// iduser
	public BOUser getIduser() {
		return iduser;
	}

	public void setIduser(BOUser iduser) {
		this.iduser = iduser;
	}

	// idrol
	public BORol getIdrol() {
		return idrol;
	}

	public void setIdrol(BORol idrol) {
		this.idrol = idrol;
	}

	// idproject
	public BOProject getIdproject() {
		return idproject;
	}

	public void setIdproject(BOProject idproject) {
		this.idproject = idproject;
	}
	
		
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	
	/**
	 * <p>A partir de un objeto <code>BOArtefactU</code> generamos un objeto <code>TOArtefactU</code>.</p>
	 * 
	 * @return <code>TOArtefactU</code> generado a partir del objeto <code>BOArtefactU</code>.
	 */
	public TOArtefactU getTOArtefact()
	{
		try
		{
			// Instanciamos un nuevo objeto
			TOArtefactU artefactu = new TOArtefactU();
			
			// Copiamos la informaci&oacute;n de un objeto a otro
			//BeanUtils.copyProperties(artefact, this);
			artefactu.setId(this.id);
			artefactu.setFecini(this.fecini);
			artefactu.setFecfin(this.fecfin);
			artefactu.setIduserrol(iduserrol.getId());
			artefactu.setIdartefact(idartefact.getId());
			artefactu.setNameArtefact(idartefact.getName());
			artefactu.setDescShort(idartefact.getDescShort());
			artefactu.setIduser(iduser.getId());
			artefactu.setNameUser(iduser.getName());
			artefactu.setIdrol(idrol.getId());
			artefactu.setNameRol(idrol.getName());
			artefactu.setIdproject(idproject.getId());
			artefactu.setNameProject(idproject.getName());
			
			// Retornamos el objeto.
			return artefactu;
		}
		catch (Exception ex)
		{
			// En caso de error retornamos null 
			return null;
		}
	}
	
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BOArtefactU
		if ((obj == null) || (!(obj instanceof BOArtefactU)))
		{
			// Retornamos que no son iguales.
			return false;
		}
		
		BOArtefactU objArtefactU = (BOArtefactU) obj;
		
		// Comparamos el identificador de ambos objetos
		return (this.id == objArtefactU.getId());
	}
	
}