package edu.uoc.integra.business.objects;

import java.io.Serializable;

import org.apache.commons.beanutils.BeanUtils;

import edu.uoc.integra.business.objects.transfers.TOConfig;

/**
 * <p>Clase que contiene los par&aacute;metros de configuraci&oacute;n.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BOConfig implements Serializable
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del Par&aacute;metro. </p> */
	protected int id;
	/** <p>Nombre del Par&aacute;metro.</p> */
	protected String name;
	/** <p>Valor del Par&aacute;metro.</p> */
	protected String value;
	/** <p>Tipo de Par&aacute;metro: User, Project. Email.</p> */
	protected String type;	
	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BOConfig</code></p>
	 */
	public BOConfig()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>BOConfig</code> a partir del objeto <code>TOConfig</code> recibido por par&aacute;metro.</p>
	 * 
	 * @param to <code>TOConfig</code> contiene los valores para asignar a los atributos de <code>BOConfig</code>.
	 */
	public BOConfig(TOConfig to)
	{
		
		super();
		
		if (to != null)
		{
			try 
			{
				// Asignamos los valores a los atributos
				BeanUtils.copyProperties(this, to);
			} 
			catch (Exception ex)
			{
				//No es necesario recoger ninguna excepci&oacute;n
			}
		}
	}
	
	/**
	 * <p>Construye un objeto <code>BOConfig</code> a partir del atributo recibido por par&aacute;metro.</p>
	 * 
	 * @param id <code>int</code> identificador del par&aacute;metro.
	 */
	public BOConfig(int id)
	{
		super();
		
		//Identificador de par&aacute;metro
		this.id = id;
		
	}		

	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	// name 
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	
	// value 
	public String getValue()
	{
		return value;
	}
	public void setValue(String value)
	{
		this.value = value;
	}
		
	// type 
	public String getType()
	{
		return type;
	}
	public void setType(String type)
	{
		this.type = type;
	}
	
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	/**
	 * <p>A partir de un objeto <code>BOConfig</code> generamos un objeto <code>TOConfig</code>.</p>
	 * 
	 * @return <code>TOConfig</code> generado a partir del objeto <code>BOConfig</code>.
	 */
	public TOConfig getTOConfig()
	{
			
		try
		{
			// Instanciamos un nuevo objeto
			TOConfig config = new TOConfig();
			// Copiamos la informaci&oacute;n de un objeto a otro
			BeanUtils.copyProperties(config, this);
			// Retornamos el objeto.
			return config;
		}
		catch (Exception ex)
		{
			// En caso de error retornamos null 
			return null;
		}
	}
		
		
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BOConfig
		if ((obj == null) || (!(obj instanceof BOConfig)))
		{
			// Retornamos que no son iguales.
			return false;
		}
			
		BOConfig objParam = (BOConfig) obj;
			
		// Comparamos el identificador de ambos objetos
		return (this.id == objParam.getId());
	}	
	
	
}
