package edu.uoc.integra.business.objects;

import java.io.Serializable;

import edu.uoc.integra.business.objects.transfers.TOInform;

/**
 * <p>Clase que contiene los tipos  de informes.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BOInform implements Serializable
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del Informe. </p> */
	protected int id;
	
	/** <p>Nombre del Informe.</p> */
	protected String name;

	/** <p>Descripci&ocuate del Informe.</p> */
	protected String descript;
	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BOInform</code></p>
	 */
	public BOInform()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>BOInform</code> a partir de los par&aacute;metro recibidos.</p>
	 * 
	 * @param name     <code>String</code> nombre      del informe.
	 * @param descript <code>String</code> descripci&oacute;n del informe. 
	 * 
	 */
	public BOInform(String name, String descript)
	{
		super();
		
		this.name = name;
		this.descript = descript;
	}
	
	
	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
			
	// name 
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	
	// descript 
	public String getDescript()
	{
		return descript;
	}
	public void setDescript(String descript)
	{
		this.descript = descript;
	}
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	/**
	 * <p>A partir de un objeto <code>BOInform</code> generamos un objeto <code>TOInform</code>.</p>
	 * 
	 * @return <code>TOInform</code> generado a partir del objeto <code>BOInform</code>.
	 */
	public TOInform getTOInform()
	{
			
		try
		{
			// Instanciamos un nuevo objeto
			TOInform toInform = new TOInform(this.id
					, this.name
					, this.descript);
			
			// Retornamos el objeto.
			return toInform;
		}
		catch (Exception ex)
		{
			// En caso de error retornamos null 
			return null;
		}
	}
		
		
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BOInform
		if ((obj == null) || (!(obj instanceof BOInform)))
		{
			// Retornamos que no son iguales.
			return false;
		}
			
		BOInform objInform = (BOInform) obj;
			
		// Comparamos el identificador de ambos objetos
		return (this.id == objInform.getId());
	}
}
