package edu.uoc.integra.business.objects;

import java.io.Serializable;
import java.util.Date;

import org.apache.commons.beanutils.BeanUtils;

import edu.uoc.integra.business.objects.transfers.TOProject;

/**
 * <p>Clase que contiene la definici&oacute;n de un Proyecto.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BOProject implements Serializable
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del Proyecto. </p> */
	protected int id;
	/** <p>C&oacute;digo del Proyecto.</p> */
	protected String prefix_code;
	/** <p>Nombre del Proyecto.</p> */
	protected String name;
	/** <p>Descripci&oacute;n del Proyecto</p> */
	protected String descript;	
	/** <p>Comienzo Estimado     del Proyecto</p> */
	protected Date fecopen;
	/** <p>Finalizaci&oacute;n Estimada del Proyecto</p> */
	protected Date fecclose;	


	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BOProject</code>.</p>
	 */
	public BOProject()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>BOProject</code> a partir del objeto <code>TOProject</code> recibido por par&aacute;metro.</p>
	 * 
	 * @param toProject <code>TOProject</code> contiene los valores para asignar a los atributos de <code>BOProject</code>.
	 */
	public BOProject(TOProject toProject)
	{
		
		super();
		
		if (toProject != null)
		{
			try 
			{
				// Asignamos los valores a los atributos
				//BeanUtils.copyProperties(this, toProject);
				this.prefix_code = toProject.getPrefix_code();
				this.name = toProject.getName();
				this.descript = toProject.getDescript();
				this.fecopen = toProject.getFecopen();
				this.fecclose = toProject.getFecclose();
				
			} 
			catch (Exception ex)
			{
				//No es necesario recoger ninguna excepci&oacute;n
			}
		}
	}
	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	// prefix_code
	public String getPrefix_code()
	{
		return prefix_code;
	}
	public void setPrefix_code(String prefix_code)
	{
		this.prefix_code = prefix_code;
	}
	
	// name 
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	
	// descript 
	public String getDescript()
	{
		return descript;
	}
	public void setDescript(String descript)
	{
		this.descript = descript;
	}
	
	// fecopen 
	public Date getFecopen()
	{
		return fecopen;
	}
	public void setFecopen(Date fecopen)
	{
		this.fecopen = fecopen;
	}

	// fecclose 
	public Date getFecclose()
	{
		return fecclose;
	}
	public void setFecclose(Date fecclose)
	{
		this.fecclose = fecclose;
	}

	
	
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	/**
	 * <p>A partir de un objeto <code>BOProject</code> generamos un objeto <code>TOProject</code>.</p>
	 * 
	 * @return <code>TOProject</code> generado a partir del objeto <code>BOProject</code>.
	 */
	public TOProject getTOProject()
	{
			
		try
		{
			// Instanciamos un nuevo objeto
			TOProject project = new TOProject();
			
			// Copiamos la informaci&oacute;n de un objeto a otro
			BeanUtils.copyProperties(project, this);
			
			// Retornamos el objeto.
			return project;
		}
		catch (Exception ex)
		{
			// En caso de error retornamos null 
			return null;
		}
	}
		
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BOProject
		if ((obj == null) || (!(obj instanceof BOProject)))
		{
			// Retornamos que no son iguales.
			return false;
		}
			
		BOProject objProject = (BOProject) obj;
			
		// Comparamos el identificador de ambos objetos
		return (this.id == objProject.getId());
	}	
	
}
