package edu.uoc.integra.business.objects;

import java.io.Serializable;

import edu.uoc.integra.business.objects.transfers.TORol;

/**
 * <p>Clase que contiene los par&aacute;metros de un rol.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BORol implements Serializable
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del Rol. </p> */
	protected int id;
	
	/** <p>Projecto al que pertenece el Rol.</p> */
	private BOProject idproject;
	
	/** <p>Nombre del Rol.</p> */
	protected String name;
	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BORol</code></p>
	 */
	public BORol()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>BORol</code> a partir de los par&aacute;metro recibidos.</p>
	 * 
	 * @param idproject <code>BOProject</code> el Proyecto al que pertenece el rol.
	 * @param name <code>String</code> nombre del rol.
	 */
	public BORol(BOProject idproject, String name)
	{
		super();
		
		this.idproject = idproject;
		this.name = name;
	}
	
	
	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
		
	// idproject 
	public BOProject getIdproject()
	{
		return idproject;
	}
	public void setIdproject(BOProject idproject)
	{
		this.idproject = idproject;
	}
			
	// name 
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	/**
	 * <p>A partir de un objeto <code>BORol</code> generamos un objeto <code>TORol</code>.</p>
	 * 
	 * @return <code>TORol</code> generado a partir del objeto <code>BORol</code>.
	 */
	public TORol getTORol()
	{
			
		try
		{
			// Instanciamos un nuevo objeto
			TORol toRol = new TORol(this.id
					, this.idproject.getId()
					, this.idproject.getPrefix_code()
					, this.idproject.getName(), this.name );
			
			// Retornamos el objeto.
			return toRol;
		}
		catch (Exception ex)
		{
			// En caso de error retornamos null 
			return null;
		}
	}
		
		
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BORol
		if ((obj == null) || (!(obj instanceof BORol)))
		{
			// Retornamos que no son iguales.
			return false;
		}
			
		BORol objRol = (BORol) obj;
			
		// Comparamos el identificador de ambos objetos
		return (this.id == objRol.getId());
	}
}
