package edu.uoc.integra.business.objects;

import java.io.Serializable;
import java.util.Date;

import org.apache.commons.beanutils.BeanUtils;

import edu.uoc.integra.business.objects.transfers.TOUser;

/**
 * <p>Clase que contiene la informaci&oacute;n de los usuarios.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BOUser implements Serializable 
{
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del usuario. </p> */
	protected int id;
	/** <p>Nombre de usuario.</p> */
	protected String login;
	/** <p>Contrase&ntilde;a de acceso.</p> */
	protected String password;
	/** <p>Nombre real del usuario.</p> */
	protected String name;
	/** <p>Empresa del usuario.</p> */
	protected String company;	
	/** <p>Direcci&oacute;n de correo electr&oacute;nico.</p> */
	protected String email;
	/** <p>intentos actuales de login.</p> */
	protected int  intentos;
	/** <p>Usuario Bloqueado: s&iacute; o no.</p> */
	protected boolean locked;
	/** <p>Tipo de Autorizaci&oacute;n: Administrador, Avanzado, Normal.</p> */
	protected String type;
	/** <p>Ultimo acceso al sistema.</p> */
	protected Date last_login;
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BOUser</code></p>
	 */
	public BOUser()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>BOUser</code> a partir del objeto <code>TOUser</code> recibido por par&aacute;metro.</p>
	 * 
	 * @param to <code>TOUser</code> contiene los valores para asignar a los atributos de <code>BOUser</code>.
	 */
	public BOUser(TOUser to)
	{
		
		super();
		
		if (to != null)
		{
			try 
			{
				// Asignamos los valores a los atributos
				BeanUtils.copyProperties(this, to);
			} 
			catch (Exception ex)
			{
				//No es necesario recoger ninguna excepci&oacute;n
			}
		}
	}
	
	/**
	 * <p>Construye un objeto <code>BOUser</code> a partir del atributo recibido por par&aacute;metro.</p>
	 * 
	 * @param id <code>int</code> identificador del usuario.
	 */
	public BOUser(int id)
	{
		super();
		
		//Identificador de usuario
		this.id = id;
	}

	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	//login
	public String getLogin()
	{
		return login;
	}
	public void setLogin(String login)
	{
		this.login = login;
	}
	
	//password
	public String getPassword()
	{
		return password;
	}
	public void setPassword(String password)
	{
		this.password = password;
	}
	
	//name
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	
	//company
	public String getCompany()
	{
		return company;
	}
	public void setCompany(String company)
	{
		this.company = company;
	}
	
	//email
	public String getEmail()
	{
		return email;
	}
	public void setEmail(String email)
	{
		this.email = email;
	}
	
	//intentos
	public int getIntentos()
	{
		return intentos;
	}
	public void setIntentos(int intentos)
	{
		this.intentos = intentos;
	}
	
	//locked
	public boolean getLocked()
	{
		return locked;
	}
	public void setLocked(boolean locked)
	{
		this.locked = locked;
	}
	
	//type
	public String getType()
	{
		return type;
	}
	public void setType(String type)
	{
		this.type = type;
	}
		
	//last_login
	public Date getLast_login()
	{
		return last_login;
	}
	public void setLast_login(Date last_login)
	{
		this.last_login = last_login;
	}
	
		
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	
	/**
	 * <p>A partir de un objeto <code>BOUser</code> generamos un objeto <code>TOUser</code>.</p>
	 * 
	 * @return <code>TOUser</code> generado a partir del objeto <code>BOUser</code>.
	 */
	public TOUser getTOUser()
	{
		
		try
		{
			// Instanciamos un nuevo objeto
			TOUser user = new TOUser();
			
			// Copiamos la informaci&oacute;n de un objeto a otro
			BeanUtils.copyProperties(user, this);
			
			// Retornamos el objeto.
			return user;
		}
		
		catch (Exception ex)
		{
			// En caso de error retornamos null 
			return null;
		}
	}
	
	
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BOUser
		if ((obj == null) || (!(obj instanceof BOUser)))
		{
			// Retornamos que no son iguales.
			return false;
		}
		
		BOUser objParam = (BOUser) obj;
		
		// Comparamos el identificador de ambos objetos
		return (this.id == objParam.getId());
	}

	
	
}
