package edu.uoc.integra.business.objects;

import java.io.Serializable;

import edu.uoc.integra.business.objects.transfers.TOProject;
import edu.uoc.integra.business.objects.transfers.TORol;
import edu.uoc.integra.business.objects.transfers.TOUser;
import edu.uoc.integra.business.objects.transfers.TOUserRol;


/**
 * <p>Clase que contiene la definici&oacute;n de los usuarios con los roles que desempenan en un proyecto</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BOUserRol implements Serializable
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del BOUser_Rol. </p> */
	protected int id;
	
	/** <p>User.</p> */
	private BOUser iduser;
	/** <p>Rol.</p> */
	protected BORol idrol;
	/** <p>Proyecto.</p> */
	protected BOProject idproject;
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BOBOUser_Rol</code></p>
	 */
	public BOUserRol()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>BOUser_Rol</code> a partir de los par&aacute;metro recibidos.</p>
	 * 
	 * @param iduser     <code>BOUser</code> usuario.
	 * @param idrol      <code>BORol</code> rol.
	 * @param idproject  <code>BOproject</code> proyecto. 
	 */
	public BOUserRol(BOUser iduser, BORol idrol, BOProject idproject)
	{
		super();
		
		this.iduser     = iduser;
		this.idrol      = idrol;
		this.idproject  = idproject;
		
	}
	
	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
		
	// iduser
	public BOUser getIduser() {
		return iduser;
	}
	public void setIduser(BOUser iduser) {
		this.iduser = iduser;
	}	
	
	// idrol
	public BORol getIdrol() {
		return idrol;
	}
	public void setIdrol(BORol idrol) {
		this.idrol = idrol;
	}	
	
	// idproject
	public BOProject getIdproject() {
		return idproject;
	}
	public void setIdproject(BOProject idproject) {
		this.idproject = idproject;
	}	
	
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	
	/**
	 * <p>Retorna un objeto <code>TOUserRol</code> con la informaci&oacute;n de este objeto</p>
	 * 
	 * @return <code>TOUserRol</code> contiene la informaci&oacute;n del usuario-rol-proyecto
	 */
	public TOUserRol getTOUserRol()
	{
		try
		{
			TOUserRol toUserRol = new TOUserRol(this.id
					, this.idproject.getId()
					, this.idproject.getPrefix_code()
					, this.idproject.getName()
					, this.iduser.getId()
					, this.iduser.getName()
					, this.idrol.getId()
					, this.idrol.getName());
			
			// Retornamos el objeto.
			return toUserRol;
		}
		catch (Exception ex)
		{
			// En caso de error retornamos null 
			return null;
		}
	}
	
	/**
	 * <p>Retorna un objeto <code>TOUser</code> con la informaci&oacute;n del usuario asignado a
	 * este objeto</p>
	 * 
	 * @return <code>TOUser</code> contiene la informaci&oacute;n del usuario
	 */
	public TOUser getTOUser()
	{
		return(this.iduser.getTOUser());
	}
	
	/**
	 * <p>Retorna un objeto <code>TORol</code> con la informaci&oacute;n del rol asignado a
	 * este objeto</p>
	 * 
	 * @return <code>TORol</code> contiene la informaci&oacute;n del rol
	 */
	public TORol getTORol()
	{
		return(this.idrol.getTORol());
	}
	
	/**
	 * <p>Retorna un objeto <code>TOProject</code> con la informaci&oacute;n del projecto asignado a
	 * este objeto</p>
	 * 
	 * @return <code>TOProject</code> contiene la informaci&oacute;n del projecto
	 */
	public TOProject getTOproject()
	{
		return(this.idproject.getTOProject());
	}
		
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BOUser_Rol
		if ((obj == null) || (!(obj instanceof BOUserRol)))
		{
			// Retornamos que no son iguales.
			return false;
		}
			
		BOUserRol objBOUser_Rol = (BOUserRol) obj;
			
		// Comparamos el identificador de ambos objetos
		return (this.id == objBOUser_Rol.getId());
	}
	
}