package edu.uoc.integra.business.objects;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collections;
import java.util.List;
import java.util.Set;

import edu.uoc.integra.business.objects.transfers.TOState;
import edu.uoc.integra.business.objects.transfers.TOWorkFlow;


/**
 * <p>Clase que contiene la definici&oacute;n de un workflow.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BOWorkFlow implements Serializable
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del WorkFlow. </p> */
	protected int id;
	/** <p>Projecto al que pertenece el WorkFlow.</p> */
	private BOProject idproject;
	/** <p>Rol </p> */
	protected BORol idrol;
	/** <p>State.</p> */
	protected BOState idstate;
	
	/** <p>Pr&oacute;ximos Estados asignados al WorkSpace.</p> */
	protected Set<BOWorkFlow_State> idstate_next;
	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BOWorkFlow</code></p>
	 */
	public BOWorkFlow()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>BOWorkFlow</code> a partir de los par&aacute;metro recibidos.</p>
	 * 
	 * @param idproject <code>BOProject</code> Proyecto al que pertenece el estado.
	 * @param idrol <code>BORol</code> rol actual.
	 * @param idstate <code>BOState</code> estado actual.
	 */
	public BOWorkFlow(BOProject idproject, BORol idrol, BOState idstate)
	{
		super();
		
		this.idproject = idproject;
		this.idrol = idrol;
		this.idstate = idstate;
		
	}
	
	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
		public int getId()
		{
			return id;
		}
		public void setId(int id)
		{
			this.id = id;
		}
		
		// idproject 
		public BOProject getIdproject()
		{
			return idproject;
		}
		public void setIdproject(BOProject idproject)
		{
			this.idproject = idproject;
		}
			
		// idrol 
		public BORol getIdrol()
		{
			return idrol;
		}
		public void setIdrol(BORol idrol)
		{
			this.idrol = idrol;
		}

		// idstate 
		public BOState getIdstate()
		{
			return idstate;
		}
		public void setIdstate(BOState idstate)
		{
			this.idstate = idstate;
		}

		// idstate_next 
		public Set<BOWorkFlow_State> getIdstate_next()
		{
			return idstate_next;
		}
		public void setIdstate_next( Set<BOWorkFlow_State> idstate_next)
		{
			this.idstate_next = idstate_next;
		}
	
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	
	/**
	 * <p>Retorna un objeto <code>TOWorkFlow</code>.</p>
	 * 
	 * @return <code>TOWorkFlow</code> contiene un resumen de la  informaci&oacute;n de un workflow
	 */
	public TOWorkFlow getTOWorkFlow()
	{
		// Creamos un objeto TOWorkFlow y lo retornamos.
		return (new TOWorkFlow(this.id
				, this.idproject.getId(), this.idproject.getPrefix_code(), this.idproject.getName()
				, this.idrol.getId(), this.idrol.getName()
				, this.idstate.getId(), this.idstate.getName()));
	}
		
	/** 
	 * <p>Retorna un objeto <code>TOWorkFlow</code>.</p>
	 * 
	 * @return <code>TOWorkFlow</code> contiene detalle de los estados a los que puede ir el workflow.
	 */
	public TOWorkFlow getTOWorkFlowStateNext()
	{
		// Definimos un toState de trabajo
		   TOState toState = null;

		// Definimos una lista TOState para almacenar los estados
		   List<TOState> states = new ArrayList<TOState>();
			
		// Recorremos el conjunto de estados pr&oacute;ximos del WorkSpace
		   for (BOWorkFlow_State boWorkFlow_State : this.idstate_next)
			{
			   toState = boWorkFlow_State.getTOState();	
			   states.add(toState);
			}
		   
		// Ordenamos la lista de Estados.
		   Collections.sort(states);
		   
		   TOWorkFlow toWorkFlow = new TOWorkFlow(this.id
					, this.idproject.getId(), this.idproject.getPrefix_code(), this.idproject.getName()
					, this.idrol.getId(), this.idrol.getName()
					, this.idstate.getId(), this.idstate.getName()
					, states);
			
		// Retornamos el objeto toWorkFlow 
		   return toWorkFlow;
		}	
		
		
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BOWorkFlow
		if ((obj == null) || (!(obj instanceof BOWorkFlow)))
		{
			// Retornamos que no son iguales.
			return false;
		}
			
		BOWorkFlow objWorkFlow = (BOWorkFlow) obj;
			
		// Comparamos el identificador de ambos objetos
		return (this.id == objWorkFlow.getId());
	}	
	
	
}