package edu.uoc.integra.business.objects;

import java.io.Serializable;

import edu.uoc.integra.business.objects.transfers.TOState;

/**
 * <p>Clase que contiene la definici&oacute;n de los estados a los que puede encaminarse un artefacto
 *  en un determinado workflow.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class BOWorkFlow_State implements Serializable
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del WorkFlow_State. </p> */
	protected int id;
	
	/** <p>WorkFlow.</p> */
	private BOWorkFlow idworkflow;
	/** <p>Estado.</p> */
	protected BOState idstate;
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>BOWorkFlow_State</code></p>
	 */
	public BOWorkFlow_State()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>WorkFlow_State</code> a partir de los par&aacute;metro recibidos.</p>
	 * 
	 * @param idworkflow <code>BOWorkFlow</code> WorkFlow.
	 * @param idstate <code>BOState</code> Estado.
	 */
	public BOWorkFlow_State(BOWorkFlow idworkflow, BOState idstate)
	{
		super();
		
		this.idworkflow = idworkflow;
		this.idstate = idstate;
	}
	
	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
		
	// idworkflow 
	public BOWorkFlow getIdworkflow()
	{
		return idworkflow;
	}
	public void setIdworkflow(BOWorkFlow idworkflow)
	{
		this.idworkflow = idworkflow;
	}

	// idstate 
	public BOState getIdstate()
	{
		return idstate;
	}
	public void setIdstate(BOState idstate)
	{
		this.idstate = idstate;
	}
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//
	
	/**
	 * <p>Retorna un objeto <code>TOState</code> con la informaci&oacute;n del estado asignado a
	 * este objeto</p>
	 * 
	 * @return <code>TOState</code> contiene la informaci&oacute;n del estado
	 */
	public TOState getTOState()
	{
		return(this.idstate.getTOState());
	}
	
	
		
	@Override
	public boolean equals(Object obj)
	{
		// Si el objeto recibido es nulo o no es del tipo BOWorkFlow
		if ((obj == null) || (!(obj instanceof BOWorkFlow_State)))
		{
			// Retornamos que no son iguales.
			return false;
		}
			
		BOWorkFlow_State objWorkFlow_State = (BOWorkFlow_State) obj;
			
		// Comparamos el identificador de ambos objetos
		return (this.id == objWorkFlow_State.getId());
	}	
	
	
}