package edu.uoc.integra.business.objects.transfers;

import java.io.Serializable;
import java.util.Date;

/**
 * <p>Clase que comunica la informaci&oacute;n de los artefactos entre las
 * diferentes capas que forman la Arquitectura del Sistema.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public class TOArtefact implements Serializable, Comparable<TOArtefact> 
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del artefacto. </p> */
	protected int id;
	
	/** <p>Secuencial del artefacto.</p> */
	protected int sec;
	
	/** <p>Nombre del artefacto.</p> */
	protected String name;
	/** <p>Descripci&oacuten; corta.</p> */
	protected String descShort;
	/** <p>Descripci&oacute;n larga.</p> */
	protected String descript;	
	/** <p>Prioridad del artefacto.</p> */
	protected String priory;
	/** <p>Fecha Inicio.</p> */
	protected Date  fecini;
	/** <p>Fecha Fin.</p> */
	protected Date  fecfin;
	
	/** <p>Estado Actual.</p> */
	protected int idState;
	protected String nameState;
	
	/** <p>Esfuerzo Actual.</p> */
	protected float effort;
	
	/** <p>Usuario Actual.</p> */
	protected int idUser;
	protected String nameUser;
	
	/** <p>Fecha de Alta.</p> */
	protected Date timestampA;
	
	/** <p>Usuario Alta.</p> */
	protected int idUserA;
	protected String nameUserA;
	
	/** <p>Proyecto.</p> */
	protected int idProject;
	protected String nameProject;
	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>TOArtefact</code></p>
	 */
	public TOArtefact()
	{
		super();
		
	}
	
	/**
	 * <p>Construye un objeto <code>TOArtefact</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 * 
	 * @param name <code>String</code> Nombre del artefacto.
	 * @param descShort <code>String</code> Descripci&oacuten; corta.
	 * @param descript <code>String</code> Descripci&oacute;n larga.
	 * @param priory <code>String</code> Prioridad del artefacto.
	 * @param fecini <code>Date</code> Fecha Inicio.
	 * @param fecfin <code>Date</code> Fecha Fin.
	 * @param idState <code>TOState</code> Estado Actual.
	 * @param effort  <code>float</code> Esfuerzo Actual.
	 * @param idUser <code>TOUserRol</code> Usuario Actual
	 * @param idUserA <code>TOUser</code> Usuario Alta
	 * @param timestampA <code>Date</code> TimeStamp Alta
	 * @param idProject <code>TOProject</code> Proyecto
	 * 
	 */
	public TOArtefact(String name, String descShort, String descript, String priory, Date fecini, Date fecfin,
			TOState idState, float effort, TOUserRol idUser, TOUser idUserA, Date timestampA, TOProject idProject)
	{
		super();
		
		//inicialmente no hay historia del artefacto
		this.setSec(0); 
		
		this.name = name;
		this.descShort=descShort;
		this.descript=descript;
		this.priory=priory;
		this.fecini=fecini;
		this.fecfin=fecfin;
		this.idState=idState.getId();
		this.nameState=idState.getName();
		this.effort=effort;
		this.idUser=idUser.getId();
		this.nameUser=idUser.getNameUser();
		this.idUserA=idUserA.getId();
		this.nameUserA=idUserA.getName();
		this.timestampA=timestampA;
		this.idProject=idProject.getId();
		this.nameProject=idProject.getName();
		
	}
	

	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public int getSec() {
		return sec;
	}

	public void setSec(int sec) {
		this.sec = sec;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}
	
	public String getDescShort() {
		return descShort;
	}

	public void setDescShort(String descShort) {
		this.descShort = descShort;
	}

	public String getDescript() {
		return descript;
	}

	public void setDescript(String descript) {
		this.descript = descript;
	}

	public String getPriory() {
		return priory;
	}

	public void setPriory(String priory) {
		this.priory = priory;
	}

	public Date getFecini() {
		return fecini;
	}

	public void setFecini(Date fecini) {
		this.fecini = fecini;
	}

	public Date getFecfin() {
		return fecfin;
	}

	public void setFecfin(Date fecfin) {
		this.fecfin = fecfin;
	}

	public int getIdState() {
		return idState;
	}

	public void setIdState(int idState) {
		this.idState = idState;
	}

	public String getNameState() {
		return nameState;
	}

	public void setNameState(String nameState) {
		this.nameState = nameState;
	}

	public float getEffort() {
		return effort;
	}

	public void setEffort(float effort) {
		this.effort = effort;
	}

	public int getIdUser() {
		return idUser;
	}

	public void setIdUser(int idUser) {
		this.idUser = idUser;
	}

	public String getNameUser() {
		return nameUser;
	}

	public void setNameUser(String nameUser) {
		this.nameUser = nameUser;
	}

	public Date getTimestampA() {
		return timestampA;
	}

	public void setTimestampA(Date timestampA) {
		this.timestampA = timestampA;
	}

	public int getIdUserA() {
		return idUserA;
	}

	public void setIdUserA(int idUserA) {
		this.idUserA = idUserA;
	}

	public String getNameUserA() {
		return nameUserA;
	}

	public void setNameUserA(String nameUserA) {
		this.nameUserA = nameUserA;
	}

	public int getIdProject() {
		return idProject;
	}

	public void setIdProject(int idProject) {
		this.idProject = idProject;
	}

	public String getNameProject() {
		return nameProject;
	}

	public void setNameProject(String nameProject) {
		this.nameProject = nameProject;
	}
	
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//

	@Override
	public int compareTo(TOArtefact o) 
	{
		if (o == null)
		{
			// Si el par&aacute;metro es nulo este objeto es mayor 
			return 1;
		}
		
		
				
		return this.name.toLowerCase().compareTo(o.getName().toLowerCase());
				
		
	}

	

	
}
