package edu.uoc.integra.business.objects.transfers;

import java.io.Serializable;
import java.util.Date;

/**
 * <p>Clase que comunica la informaci&oacute;n de la asignaci&oacuten; de los usuarios con sus roles
 * a un artefacto con las diferentes capas que forman la Arquitectura del Sistema.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public class TOArtefactU implements Serializable, Comparable<TOArtefactU> 
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del artefactoU. </p> */
	protected int id;
	
	/** <p>Fecha Inicio.</p> */
	protected Date  fecini;
	
	/** <p>Fecha Fin.</p> */
	protected Date  fecfin;
	
	/** <p>userrol.</p> */
	protected int iduserrol;
	
	/** <p>artefact.</p> */
	protected int idartefact;
	protected String nameArtefact;
	protected String descShort;
	
	/** <p>user.</p> */
	protected int iduser;
	protected String nameUser;

	/** <p>rol.</p> */
	protected int idrol;
	protected String nameRol;
	
	/** <p>Proyecto.</p> */
	protected int idproject;
	protected String nameProject;
	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>TOArtefactU</code></p>
	 */
	public TOArtefactU()
	{
		super();
		
	}
	
	/**
	 * <p>Construye un objeto <code>TOArtefactU</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 * 
	 * @param fecini <code>Date</code> Fecha Inicio.
	 * @param fecfin <code>Date</code> Fecha Fin.
	 * @param iduserrol <code>TOUserRol</code> usuario-rol.
	 * @param idartefact <code>TOArtefact</code> artefacto
	 * @param idproject <code>TOProject</code> Proyecto
	 * 
	 */
	public TOArtefactU(Date fecini, Date fecfin,TOUserRol iduserrol, TOArtefact idartefact, TOProject idproject)
	{
		super();
		
		this.fecini=fecini;
		this.setFecfin(fecfin);
		this.setIduserrol(iduserrol.getId());
		this.setIdartefact(idartefact.getId());
		this.setNameArtefact(idartefact.getName());
		this.setDescShort(idartefact.getDescShort());
		this.setIduser(iduserrol.getIduser());
		this.setNameUser(iduserrol.getNameUser());
		this.setIdrol(iduserrol.getIdrol());
		this.setNameRol(iduserrol.getNameRol());
		this.setIdproject(idproject.getId());
		this.setNameProject(idproject.getName());
	}
	

	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//
	
	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}
	
	public Date getFecini() {
		return fecini;
	}

	public void setFecini(Date fecini) {
		this.fecini = fecini;
	}

	public Date getFecfin() {
		return fecfin;
	}

	public void setFecfin(Date fecfin) {
		this.fecfin = fecfin;
	}
	
	public int getIduserrol() {
		return iduserrol;
	}

	public void setIduserrol(int iduserrol) {
		this.iduserrol = iduserrol;
	}

	public int getIdartefact() {
		return idartefact;
	}

	public void setIdartefact(int idartefact) {
		this.idartefact = idartefact;
	}

	public String getNameArtefact() {
		return nameArtefact;
	}

	public void setNameArtefact(String nameArtefact) {
		this.nameArtefact = nameArtefact;
	}

	public String getDescShort() {
		return descShort;
	}

	public void setDescShort(String descShort) {
		this.descShort = descShort;
	}

	public int getIduser() {
		return iduser;
	}

	public void setIduser(int iduser) {
		this.iduser = iduser;
	}

	public String getNameUser() {
		return nameUser;
	}

	public void setNameUser(String nameUser) {
		this.nameUser = nameUser;
	}

	public int getIdrol() {
		return idrol;
	}

	public void setIdrol(int idrol) {
		this.idrol = idrol;
	}

	public String getNameRol() {
		return nameRol;
	}

	public void setNameRol(String nameRol) {
		this.nameRol = nameRol;
	}

	public int getIdproject() {
		return idproject;
	}

	public void setIdproject(int idproject) {
		this.idproject = idproject;
	}

	public String getNameProject() {
		return nameProject;
	}

	public void setNameProject(String nameProject) {
		this.nameProject = nameProject;
	}
	
	
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//

	@Override
	public int compareTo(TOArtefactU o) 
	{
		if (o == null)
		{
			// Si el par&aacute;metro es nulo este objeto es mayor 
			return 1;
		}
		
				
		return this.fecini.compareTo(o.getFecini());
				
		
	}
	
}
