package edu.uoc.integra.business.objects.transfers;

import java.io.Serializable;

/**
 * <p>Clase que comunica la informaci&oacute;n de la congiguracion entre las
 * diferentes capas que forman la Arquitectura del Sistema.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public class TOConfig implements Serializable, Comparable<TOConfig> 
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
		
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del Par&aacute;metro. </p> */
	protected int id;
	/** <p>Nombre del Par&aacute;metro.</p> */
	protected String name;
	/** <p>Valor del Par&aacute;metro.</p> */
	protected String value;
	/** <p>Tipo de Par&aacute;metro: User, Project. Email.</p> */
	protected String type;	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>TOConfig</code></p>
	 */
	public TOConfig()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>TOConfig</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 *  	
	 * @param id <code>int</code> Identificador del Par&aacute;metro.
	 * @param name <code>String</code> Nombre del Par&aacute;metro.
	 * @param value <code>String</code> Valor del Par&aacute;metro.
	 * @param type <code>String</code> Tipo de Par&aacute;metro: User, Project. Email.
	 */
	public TOConfig(int id, String name, String value, String type) 
	{
		// Constructor de la superclase.
		super();
		
		// Asignamos los valores a los atributos.
		this.id = id;
		this.name  = name;
		this.value = value;
		this.type  = type;
	}



	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	// name 
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	
	// value 
	public String getValue()
	{
		return value;
	}
	public void setValue(String value)
	{
		this.value = value;
	}
		
	// type 
	public String getType()
	{
		return type;
	}
	public void setType(String type)
	{
		this.type = type;
	}

	@Override
	public int compareTo(TOConfig o) 
	{
		// Comprobamos que el par&aacute;metro no es nulo.
		if (o == null)
		{
			// Si el par&aacute;metro es null vamos a suponer que "this" es mayor.
			return 1;
		}

		// Comprobamos si el atributo "type" tiene el valor "null"
		if (this.type == null)
		{
			// En el caso de que el tipo sea nulo vamos a suponer que "this" es menor.
			return -1;
		}
		
		// Comprobamos si el atributo "name" tiene el valor "null"
		if (this.name == null)
		{
			// Comparamos el tipo del parametro
			return this.type.toLowerCase().compareTo(o.getType().toLowerCase());
		}

		// Si tienen el mismo tipo comparamos el nombre del atributo
		if(this.type.toLowerCase().compareTo((o.getName().toLowerCase())) == 0){
			// Comparamos el nombre del parametro
			return this.name.toLowerCase().compareTo(o.getName().toLowerCase());
		}
		
		// Comparamos el tipo 
		return this.type.toLowerCase().compareTo(o.getType().toLowerCase());

	}
	
		
}
