package edu.uoc.integra.business.objects.transfers;

import java.io.Serializable;

/**
 * <p>Clase que comunica la informaci&oacute;n de un informe entre las
 * diferentes capas que forman la Arquitectura del Sistema.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public class TOInform implements Serializable, Comparable<TOInform> 
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
		
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del Informe. </p> */
	protected int id;
	
	/** <p>Nombre del Informe.</p> */
	protected String name;

	/** <p>Descripci&oacute; del Informe.</p> */
	protected String descript;
	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>TOInform</code></p>
	 */
	public TOInform()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>TOInform</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 *  	
	 * @param id    <code>int</code> Identificador del informe  
	 * @param name <code>String</code> Nombre del Informe.
	 * @param descript <code>String</code> Descripci&oacuten; del Informe.
	 * 
	 */
	public TOInform(int id, String name, String descript) 
	{
		// Constructor de la superclase.
		super();
		
		// Asignamos los valores a los atributos.
		this.id=id;
		this.name= name;
		this.descript= descript;
	}

	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//
	
	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	// name 
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}

	// descript 
	public String getDescript()
	{
		return descript;
	}
	public void setDescript(String descript)
	{
		this.descript = descript;
	}
	
	@Override
	public int compareTo(TOInform o) 
	{
		// Comprobamos que el par&aacute;metro no es nulo.
		if (o == null)
		{
			// Si el par&aacute;metro es null vamos a suponer que "this" es mayor.
			return 1;
		}

		// Comprobamos si el atributo "name" tiene el valor "null"
		if (this.name == null)
		{
			// En el caso de que el tipo sea nulo vamos a suponer que "this" es menor.
			return -1;
		}
		
		// Comparamos el nombre 
		return this.name.toLowerCase().compareTo(o.getName().toLowerCase());
	}
		
}
