package edu.uoc.integra.business.objects.transfers;

import java.io.Serializable;
import java.util.Date;

/**
 * <p>Clase que comunica la informaci&oacute;n de un proyecto entre las
 * diferentes capas que forman la Arquitectura del Sistema.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public class TOProject implements Serializable, Comparable<TOProject> 
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
		
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del Proyecto. </p> */
	protected int id;
	/** <p>C&oacute;digo del Proyecto.</p> */
	protected String prefix_code;
	/** <p>Nombre del Proyecto.</p> */
	protected String name;
	/** <p>Descripci&oacute;n del Proyecto</p> */
	protected String descript;	
	/** <p>Comienzo Estimado  del Proyecto</p> */
	protected Date fecopen;
	/** <p>Finalizaci&oacute;n Estimada del Proyecto</p> */
	protected Date fecclose;	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>TOProject</code></p>
	 */
	public TOProject()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>TOProject</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 *  	
	 * @param prefix_code <code>String</code> C&oacute;digo del Proyecto
	 * @param name <code>String</code> Nombre del Proyecto.
	 * @param descript <code>String</code> Descripci&oacute;n del Proyecto
	 * @param fecopen <code>Date</code> Comienzo Estimado del Proyecto
	 * @param fecclose <code>Date</code> Finalizaci&oacute;n Estimada del Proyecto 
	 * 
	 */
	public TOProject(String prefix_code, String name, String descript, Date fecopen, Date fecclose) 
	{
		// Constructor de la superclase.
		super();
		
		// Asignamos los valores a los atributos.
		this.prefix_code=prefix_code;
		this.name  = name;
		this.descript = descript;
		this.fecopen =fecopen;
		this.fecclose =fecclose;
	}



	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//
	
	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	//prefix_code
	public String getPrefix_code()
	{
		return prefix_code;
	}
	public void setPrefix_code(String prefix_code)
	{
		this.prefix_code = prefix_code;
	}
		
	// name 
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	
	// descript 
	public String getDescript()
	{
		return descript;
	}
	public void setDescript(String descript)
	{
		this.descript = descript;
	}
	
	// fecopen 
	public Date getFecopen()
	{
		return fecopen;
	}
	public void setFecopen(Date fecopen)
	{
		this.fecopen = fecopen;
	}
	
	// fecclose 
	public Date getFecclose()
	{
		return fecclose;
	}
	public void setFecclose(Date fecclose)
	{
		this.fecclose = fecclose;
	}
	

	/**
	 * <p>Compara el objeto <code>TOProject</code> con el objeto recibido por par&aacute;metro.</p>
	 *  	
	 * @param o <code>TOProject</code> Objeto de tipo proyecto
	 * 
	 * @return int resultado de la comparaci&oacute;n. 
	 *         <p> 1 el objeto recibido es mayor a este.</p>
	 *         <p> 0 los objetos son iguales.</p>
	 *         <p>-1 el objeto recibido es menor a este.</p>
	 * 
	 */
	@Override
	public int compareTo(TOProject o) 
	{
		// Comprobamos que el par&aacute;metro no es nulo.
		if (o == null)
		{
			// Si el par&aacute;metro es null vamos a suponer que "this" es mayor.
			return 1;
		}

		// Comprobamos si el atributo "prefix_code" tiene el valor "null"
		if (this.prefix_code == null)
		{
			// En el caso de que el tipo sea nulo vamos a suponer que "this" es menor.
			return -1;
		}
		
		
		// Comparamos el tipo 
		return this.prefix_code.toLowerCase().compareTo(o.getPrefix_code().toLowerCase());

	}
	
		
}
