package edu.uoc.integra.business.objects.transfers;

import java.io.Serializable;

/**
 * <p>Clase que comunica la informaci&oacute;n de un rol entre las
 * diferentes capas que forman la Arquitectura del Sistema.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public class TORol implements Serializable, Comparable<TORol> 
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
		
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del Rol. </p> */
	protected int id;
	
	/** <p>Identificador del Proyecto.</p> */
	protected int idproject;

	/** <p>C&oacute;digo del Proyecto.</p> */
	protected String codeProject;
	
	/** <p>Nombre del Proyecto.</p> */
	protected String nameProject;
	
	/** <p>Nombre del Rol.</p> */
	protected String name;
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>TORol</code></p>
	 */
	public TORol()
	{
		super();
	}
	
	/**
	 * <p>Construye un objeto <code>TORol</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 *  	
	 * @param id        <code>int</code> Identificador del Rol  
	 * @param idproject <code>int</code> Identificador del Proyecto
	 * @param codeProject <code>String</code> C&oacute;digo del Proyecto 
	 * @param nameProject <code>String</code> Nombre del Proyecto 
	 * @param nameRol <code>String</code> Nombre del Rol.
	 * 
	 */
	public TORol(int id, int idproject,String codeProject, String nameProject, String nameRol) 
	{
		// Constructor de la superclase.
		super();
		
		// Asignamos los valores a los atributos.
		this.id=id;
		this.idproject  =idproject;
		this.codeProject=codeProject;
		this.nameProject=nameProject;
		this.name       = nameRol;
	}

	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//
	
	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	// idproject 
	public int getIdproject()
	{
		return idproject;
	}
	public void setIdproject(int idproject)
	{
		this.idproject = idproject;
	}
	
	// codeProject 
	public String getCodeProject()
	{
		return codeProject;
	}
	public void setCodeProject(String codeProject)
	{
		this.codeProject = codeProject;
	}
	
	// nameProject 
	public String getNameProject()
	{
		return nameProject;
	}
	public void setNameProject(String nameProject)
	{
		this.nameProject = nameProject;
	}
	
	// name 
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}

	@Override
	public int compareTo(TORol o) 
	{
		// Comprobamos que el par&aacute;metro no es nulo.
		if (o == null)
		{
			// Si el par&aacute;metro es null vamos a suponer que "this" es mayor.
			return 1;
		}

		// Comprobamos si el atributo "name" tiene el valor "null"
		if (this.name == null)
		{
			// En el caso de que el tipo sea nulo vamos a suponer que "this" es menor.
			return -1;
		}
		
		// Comparamos el nombre 
		return this.name.toLowerCase().compareTo(o.getName().toLowerCase());

	}
		
}
