package edu.uoc.integra.business.objects.transfers;

import java.io.Serializable;
import java.util.Date;

/**
 * <p>Clase que comunica la informaci&oacute;n de los usuarios entre las
 * diferentes capas que forman la Arquitectura del Sistema.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public class TOUser implements Serializable, Comparable<TOUser> 
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	/** <p>Ordenamos por el atributo login.</p> */
	public static final int ORDER_BY_LOGIN    = 1;
	public static final int ORDER_BY_NAME     = 2;
	public static final int ORDER_BY_COMPANY  = 3;
	
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del usuario. </p> */
	protected int id;
	/** <p>Nombre de usuario.</p> */
	protected String login;
	/** <p>Contrase&ntilde;a de acceso.</p> */
	protected String password;
	/** <p>Nombre real del usuario.</p> */
	protected String name;
	/** <p>Empresa del usuario.</p> */
	protected String company;	
	/** <p>Direcci&oacute;n de correo electr&oacute;nico.</p> */
	protected String email;
	/** <p>intentos actuales de login.</p> */
	protected int  intentos;
	/** <p>Usuario Bloqueado: s&iacute; o no.</p> */
	protected boolean locked;
	/** <p>Tipo de Autorizaci&oacute;n: Administrador, Avanzado, Normal.</p> */
	protected String type;
	/** <p>Ultimo acceso al sistema.</p> */
	protected Date last_login;
	
	/** <p>Indica el tipo de ordenaci&oacute;n.</p> */
	private int orderBy;
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	/**
	 * <p>Construye un objeto <code>TOUser</code></p>
	 */
	public TOUser()
	{
		super();
		
		// Orden por defecto
		this.orderBy = ORDER_BY_LOGIN;
	}
	
	/**
	 * <p>Construye un objeto <code>TOUser</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 * 
	 * @param login <code>String</code> Nombre de usuario.
	 * @param password <code>String</code> Contrase&ntilde;a de acceso.
	 * @param name <code>String</code> Nombre real del usuario.
	 * @param company <code>String</code> Empresa del usuario.
	 * @param email <code>String</code> Direcci&oacute;n de correo electr&oacute;nico.
	 * @param intentos <code>int</code> Intentos actuales de login.
	 * @param locked <code>boolean</code> Usuario Bloqueado: s&iacute; o no.
	 * @param type <code>String</code> Tipo de Autorizaci&oacute;n.
	 * 
	 */
	public TOUser(String login, String password, String name, String company, String email, 
			int intentos, boolean locked, String type)
	{

		super();
		
		this.login = login;
		this.password = password;
		this.name = name;
		this.company = company;
		this.email = email;
		this.intentos = intentos;
		this.locked = locked;
		this.type = type;
				
		// Orden por defecto
		this.orderBy = ORDER_BY_LOGIN;
	}
	

	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	//login
	public String getLogin()
	{
		return login;
	}
	public void setLogin(String login)
	{
		this.login = login;
	}
	
	//password
	public String getPassword()
	{
		return password;
	}
	public void setPassword(String password)
	{
		this.password = password;
	}
	
	//name
	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}
	
	//company
	public String getCompany()
	{
		return company;
	}
	public void setCompany(String company)
	{
		this.company = company;
	}
	
	//email
	public String getEmail()
	{
		return email;
	}
	public void setEmail(String email)
	{
		this.email = email;
	}
	
	//intentos
	public int getIntentos()
	{
		return intentos;
	}
	public void setIntentos(int intentos)
	{
		this.intentos = intentos;
	}
	
	//locked
	public boolean getLocked()
	{
		return locked;
	}
	public void setLocked(boolean locked)
	{
		this.locked = locked;
	}
	
	//type
	public String getType()
	{
		return type;
	}
	public void setType(String type)
	{
		this.type = type;
	}
	
	//last_login
	public Date getLast_login()
	{
		return last_login;
	}
	public void setLast_login(Date last_login)
	{
		this.last_login = last_login;
	}

	//OrderBy
	public int getOrderBy()
	{
		return orderBy;
	}
	public void setOrderBy(int orderBy)
	{
		this.orderBy = orderBy;
	}
	
	
	//************************************************************//	
	// OTROS METODOS                                              //
	//************************************************************//

	@Override
	public int compareTo(TOUser o) 
	{
		if (o == null)
		{
			// Si el par&aacute;metro es nulo este objeto es mayor 
			return 1;
		}
		
		//Ordenamos seg&uacute;n tipo de campo
		switch (this.orderBy)
		{
			case ORDER_BY_NAME :
				
				return this.name.toLowerCase().compareTo(o.getName().toLowerCase());
				
			case ORDER_BY_COMPANY :
				
				return this.company.toLowerCase().compareTo(o.getCompany().toLowerCase());
						
			default:
				// Por defecto login
				return this.login.toLowerCase().compareTo(o.getLogin().toLowerCase());
		}
	}

	
}
