package edu.uoc.integra.business.objects.transfers;

import java.io.Serializable;

/**
 * <p>Clase que comunica la informaci&oacute;n de un Usuario-Rol entre las
 * diferentes capas que forman la Arquitectura del Sistema.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public class TOUserRol implements Serializable, Comparable<TOUserRol> 
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
		
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del UserRol. </p> */
	protected int id;
	
	/** <p>Identificador del User.</p> */
	protected int iduser;
	/** <p>Nombre del User.</p> */
	protected String nameUser;
	
	/** <p>Identificador del Rol.</p> */
	protected int idrol;
	/** <p>Nombre del Rol.</p> */
	protected String nameRol;
	
	/** <p>Identificador del Proyecto.</p> */
	protected int idproject;
	/** <p>C&oacute;digo del Proyecto.</p> */
	protected String codeProject;
	/** <p>Nombre del Proyecto.</p> */
	protected String nameProject;
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	
	/**
	 * <p>Construye un objeto <code>TOUserRol</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 *  	
	 * @param id <code>int</code> Identificador del UserRol.
	 * @param idproject <code>int</code> Identificador del Projecto
	 * @param codeProject <code>String</code> C&oacute;digo del Proyecto 
	 * @param nameProject <code>String</code> Nombre del Projecto
	 * @param iduser <code>int</code> Identificador del usuario 
	 * @param nameUser <code>String</code> Nombre del usuario
	 * @param idrol <code>int</code> Identificador del rol 
	 * @param nameRol <code>String</code> Nombre del rol 
	 * 
	 */
	public TOUserRol(int id, int idproject, String codeProject, String nameProject
			, int iduser, String nameUser, int idrol, String nameRol) 
	{
		// Constructor de la superclase.
		super();
		
		// Asignamos los valores a los atributos.
		this.id = id;
		
		this.idproject=idproject;
		this.codeProject=codeProject;
		this.nameProject=nameProject;
		
		this.iduser=iduser;
		this.nameUser=nameUser;
		
		this.idrol=idrol;
		this.nameRol=nameRol;
	}
	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//
	//************************************************************//	

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	// idproject 
	public int getIdproject()
	{
		return idproject;
	}
	public void setIdproject(int idproject)
	{
		this.idproject = idproject;
	}
	
	// codeProject 
	public String getCodeProject()
	{
		return codeProject;
	}
	public void setCodeProject(String codeProject)
	{
		this.codeProject = codeProject;
	}

	// nameProject 
	public String getNameProject()
	{
		return nameProject;
	}
	public void setNameProject(String nameProject)
	{
		this.nameProject = nameProject;
	}
	
	// idrol 
	public int getIdrol()
	{
		return idrol;
	}
	public void setIdrol(int idrol)
	{
		this.idrol = idrol;
	}
	
	// nameRol 
	public String getNameRol()
	{
		return nameRol;
	}
	public void setNameRol(String nameRol)
	{
		this.nameRol = nameRol;
	}

	// iduser 
	public int getIduser()
	{
		return iduser;
	}
	public void setIduser(int iduser)
	{
		this.iduser = iduser;
	}
	
	// nameUser 
	public String getNameUser()
	{
		return nameUser;
	}
	public void setNameUser(String nameUser)
	{
		this.nameUser = nameUser;
	}
	
	@Override
	public int compareTo(TOUserRol o) 
	{
		// Comprobamos que el par&aacute;metro no es nulo.
		if (o == null)
		{
			// Si el par&aacute;metro es null vamos a suponer que "this" es mayor.
			return 1;
		}

		if(this.idproject < o.getIdproject()) return -1;
		if(this.idproject > o.getIdproject()) return  1;
		
		if(this.iduser < o.getIdrol()) return -1;
		if(this.iduser > o.getIdrol()) return  1;
		
		if(this.idrol < o.getIdrol()) return -1;
		if(this.idrol > o.getIdrol()) return  1;
		
		return 0;
	}
		
}