package edu.uoc.integra.business.objects.transfers;

import java.io.Serializable;
import java.util.List;

/**
 * <p>Clase que comunica la informaci&oacute;n de un WorkFlow entre las
 * diferentes capas que forman la Arquitectura del Sistema.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0 
 */
public class TOWorkFlow implements Serializable, Comparable<TOWorkFlow> 
{
	
	//************************************************************//
	// CONSTANTES.                                                //
	//************************************************************//
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
		
	//************************************************************//
	// ATRIBUTOS.                                                 //
	//************************************************************//
	/** <p>Identificador del WorkFlow. </p> */
	protected int id;
	
	/** <p>Identificador del Proyecto.</p> */
	protected int idproject;
	/** <p>C&oacute;digo del Proyecto.</p> */
	protected String codeProject;
	/** <p>Nombre del Proyecto.</p> */
	protected String nameProject;
	
	/** <p>Identificador del Rol.</p> */
	protected int idrol;
	/** <p>Nombre del Rol.</p> */
	protected String nameRol;
	
	/** <p>Identificador del State.</p> */
	protected int idstate;
	/** <p>Nombre del State.</p> */
	protected String nameState;
	
	/** <p>Identificador de los pr&oacute;ximos States.</p> */
	private List<TOState> idstate_next;
	
	
	//************************************************************//	
	// CONSTRUCTORES.                                             //
	//************************************************************//
	
	/**
	 * <p>Construye un objeto <code>TOWorkFlow</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 *  	
	 * @param id <code>int</code> Identificador del WorkFlow.
	 * @param idproject <code>int</code> Identificador del Projecto
	 * @param codeProject <code>String</code> C&oacute;digo del Proyecto 
	 * @param nameProject <code>String</code> Nombre del Projecto
	 * @param idrol <code>int</code> Identificador del rol actual de un artefacto en un Projecto.
	 * @param nameRol <code>String</code> Nombre del rol actual de un artefacto en un Projecto.
	 * @param idstate <code>int</code> Identificador del estado actual de un artefacto en un Projecto.
	 * @param nameState <code>String</code> Nombre del estado actual  de un artefacto en un Projecto.
	 * 
	 */
	public TOWorkFlow(int id, int idproject, String codeProject, String nameProject
			, int idrol, String nameRol, int idstate, String nameState) 
	{
		// Constructor de la superclase.
		super();
		
		// Asignamos los valores a los atributos.
		this.id = id;
		
		this.idproject=idproject;
		this.codeProject=codeProject;
		this.nameProject=nameProject;
		
		this.idrol=idrol;
		this.nameRol=nameRol;
		
		this.idstate=idstate;
		this.nameState=nameState;
	}

	/**
	 * <p>Construye un objeto <code>TOWorkFlow</code> con la informaci&oacute;n que recibe por par&aacute;metro.</p>
	 *  	
	 * @param id <code>int</code> Identificador del WorkFlow.
	 * @param idproject <code>int</code> Identificador del Projecto
	 * @param codeProject <code>String</code> C&oacute;digo del Projecto 
	 * @param nameProject <code>String</code> Nombre del Projecto
	 * @param idrol <code>int</code> Identificador del rol actual de un artefacto en un Projecto.
	 * @param nameRol <code>String</code> Nombre del rol actual de un artefacto en un Projecto.
	 * @param idstate <code>int</code> Identificador del estado actual de un artefacto en un Projecto.
	 * @param nameState <code>String</code> Nombre del estado actual  de un artefacto en un Projecto.
	 * @param idstate_next <code>List<TOState></code> Conjunto de estados hacia los que puede avanzar un artefacto
	 * 
	 */
	public TOWorkFlow(int id, int idproject, String codeProject, String nameProject
			, int idrol, String nameRol, int idstate, String nameState, List<TOState> idstate_next) 
	{
		// Constructor de la superclase.
		super();
		
		// Asignamos los valores a los atributos.
		this.id = id;
		
		this.idproject=idproject;
		this.codeProject=codeProject;
		this.nameProject=nameProject;
		
		this.idrol=idrol;
		this.nameRol=nameRol;
		
		this.idstate=idstate;
		this.nameState=nameState;
		
		this.idstate_next=idstate_next;
	}
	
	//************************************************************//	
	// GETTERS Y SETTERS.                                         //
	//************************************************************//
	//************************************************************//	

	// id 
	public int getId()
	{
		return id;
	}
	public void setId(int id)
	{
		this.id = id;
	}
	
	// idproject 
	public int getIdproject()
	{
		return idproject;
	}
	public void setIdproject(int idproject)
	{
		this.idproject = idproject;
	}
	
	// codeProject 
	public String getCodeProject()
	{
		return codeProject;
	}
	public void setCodeProject(String codeProject)
	{
		this.codeProject = codeProject;
	}

	// nameProject 
	public String getNameProject()
	{
		return nameProject;
	}
	public void setNameProject(String nameProject)
	{
		this.nameProject = nameProject;
	}
	
	// idrol 
	public int getIdrol()
	{
		return idrol;
	}
	public void setIdrol(int idrol)
	{
		this.idrol = idrol;
	}
	
	// nameRol 
	public String getNameRol()
	{
		return nameRol;
	}
	public void setNameRol(String nameRol)
	{
		this.nameRol = nameRol;
	}

	// idstate 
	public int getIdstate()
	{
		return idstate;
	}
	public void setIdstate(int idstate)
	{
		this.idstate = idstate;
	}

	// nameState 
	public String getNameState()
	{
		return nameState;
	}
	public void setNameState(String nameState)
	{
		this.nameState = nameState;
	}
	
	// idstate_next 
	public List<TOState> getIdstate_next()
	{
		return idstate_next;
	}
	public void setIdstate_next(List<TOState> idstate_next)
	{
		this.idstate_next = idstate_next;
	}
	
	@Override
	public int compareTo(TOWorkFlow o) 
	{
		// Comprobamos que el par&aacute;metro no es nulo.
		if (o == null)
		{
			// Si el par&aacute;metro es null vamos a suponer que "this" es mayor.
			return 1;
		}

		if(this.idproject < o.getIdproject()) return -1;
		if(this.idproject > o.getIdproject()) return  1;
		
		if(this.idrol < o.getIdrol()) return -1;
		if(this.idrol > o.getIdrol()) return  1;
		
		if(this.idstate < o.getIdstate()) return -1;
		if(this.idstate > o.getIdstate()) return 1;
		
		return 0;
	}
		
}
