package edu.uoc.integra.struts.actions;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.action.ActionMessage;

import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.interfaces.IBAuthManager;
import edu.uoc.integra.business.objects.transfers.TOUser;
import edu.uoc.integra.struts.forms.AFAuth;


/**
 * <p>Esta clase es la encargada de manejar las acciones relacionadas con la <i>Gesti&oacute;n de las Autorizaciones</i> de la aplicaci&oacute;n.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class DAAuth extends DACommom {

	
	//Vistas
	  /** <p>Acceder usuario al sistema.</p> */
      public static final String VIEW_AUTH_SIGNIN  = "?page=SignIn";
	  /** <p>Abandonar usuario el sistema.</p> */
	  public static final String VIEW_AUTH_SIGNOUT = "?page=SignOut";
	  /** <p>Recuperar los datos de un usuario registrado.</p> */
	  public static final String VIEW_AUTH_FORGOT_PASSWORD = "?page=ForgotPassword";
	  
	//Acciones
	  public static final String ACTION_SIGNIN          = "signin";
	  public static final String ACTION_SIGNOUT         = "signout";
	  public static final String ACTION_FORGOT_PASSWORD = "forgotPassword";
	  
	  
	  
	  /**
		 * <p>Este m&eacute;todo es llamado cada vez que un usuario quiera ACCEDER al sistema</p> 
		 *   
		 * @param mapping  <code>ActionMapping</code> Mapeos de Struts.
		 * @param formAuth <code>ActionForm</code> formulario de usuario 
		 * @param request  <code>HttpServletRequest</code> petici&oacute;n.
		 * @param response <code>HttpServletResponse</code> respuesta.
		 * 
		 * @return <code>ActionForward</code> Retornamos la siguiente vista a mostrar.		 
		 */
		public ActionForward signin(ActionMapping mapping, ActionForm formAuth,
				HttpServletRequest request, HttpServletResponse response)
		{
			// Vista actual
		    String view_act = VIEW_AUTH_SIGNIN;
		    
		    // Verificamos que el formulario recibido es de tipo AFAuth
			if (formAuth instanceof AFAuth)
			{
				//Realizamos el Cast del formulario al tipo AFAuth.
				AFAuth afAuth = (AFAuth) formAuth;
				
				// Realizamos las validaciones del formulario para la acci&oacute;n
				ActionErrors errors = afAuth.validateSignin();
				
				//Vemos si se han producido errores
				if (errors.size() > 0)
				{
					// Grabamos los errores.
					addErrors(request, errors);
					
				}
				//No hay Errores 
				else
				{
					try
					{
						
						// Obtenemos una instancia de IBAuthManager.
						IBAuthManager ibAuthManager = createIBAuthManager();
						
						// invocamos al m&eacute;todo obtener contrase&ntilde;a    
						TOUser toUser = ibAuthManager.signin(afAuth.getLogin(), afAuth.getPassword());
						
						// Ponemos los datos del usuario en session
						request.getSession().setAttribute(SESSION_USER,toUser);
						
					}
					catch (ExceptionControl ec)
					{
						
						// Indicamos que se ha producido un error
						request.setAttribute(SUCESS, false);
						
						// Creamos un ActionErrors para guardar el error.
						ActionErrors ae = new ActionErrors();
						
						// A&ntilde;adimos el mensaje de error.
						ae.add("errorInfo", new ActionMessage(ec.getMessage()));
						
						// Guardamos los errores.
						addErrors(request, ae);
						
					}
					catch (Exception ex)
					{
						
						// Nombre de la Clase
						request.setAttribute("infoClass", "DAAuth");
						// Nombre de la excepci&oacute;n
						request.setAttribute("type", ex.getClass().getName());
						// Descripci&oacute;n de la excepci&oacute;n
						request.setAttribute("message", ex.getMessage());
						// Nombre de la Transacci&oacute;n
						request.setAttribute("action", ACTION_SIGNIN);
						// Escribimos por la salida est&aacute;ndar la Traza.
						ex.printStackTrace();
						
						view_act = VIEW_GLOBAL_ERROR;
					}
				}
			}
			
			// Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
			// Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));
		}
		
		/**
		 * <p>Este m&eacute;todo es llamado cada vez que un usuario quiera abandonar el sistema</p> 
		 *   
		 * @param mapping  <code>ActionMapping</code> Mapeos de Struts.
		 * @param formAuth <code>ActionForm</code> formulario de usuario 
		 * @param request  <code>HttpServletRequest</code> petici&oacute;n.
		 * @param response <code>HttpServletResponse</code> respuesta.
		 * 
		 * @return <code>ActionForward</code> Retornamos la siguiente vista a mostrar.		 
		 */
		public ActionForward signout(ActionMapping mapping, ActionForm formAuth, 
				HttpServletRequest request, HttpServletResponse response)
		{
			
			// Vista actual
		    String view_act = VIEW_AUTH_SIGNOUT;
			
			// Eliminamos los datos de la sesi&oacute;n del usuario
			request.getSession().removeAttribute(SESSION_USER);

			// Eliminamos los datos de los filtros
			request.getSession().removeAttribute(SESSION_FILTER_USER);
			request.getSession().removeAttribute(SESSION_FILTER_PROJECT);
			
			// Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
		    // Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));
		}
	  
	  /**
		 * <p>Este m&eacute;todo es llamado cada vez que un usuario quiera recordar sus datos
		 * de acceso al sistema</p> 
		 *   
		 * @param mapping  <code>ActionMapping</code> Mapeos de Struts.
		 * @param formAuth <code>ActionForm</code> formulario de usuario 
		 * @param request  <code>HttpServletRequest</code> petici&oacute;n.
		 * @param response <code>HttpServletResponse</code> respuesta.
		 * 
		 * @return <code>ActionForward</code> Retornamos la siguiente vista a mostrar. 
		 */
	  public ActionForward forgotPassword(ActionMapping mapping, ActionForm formAuth, 
			HttpServletRequest request, HttpServletResponse response)
	  {
		 
		    //Vista actual
		    String view_act = VIEW_AUTH_FORGOT_PASSWORD;
			  
		    // Verificamos que el formulario recibido es de tipo AFAuth
			if (formAuth instanceof AFAuth)
			{
				
				//Realizamos el Cast del formulario al tipo AFAuth.
				AFAuth afAuth = (AFAuth) formAuth;
				
				// Realizamos las validaciones del formulario para la acci&oacute;n
				ActionErrors errors = afAuth.validateForgotPassword();
		
				//Vemos si se han producido errores
				if (errors.size() > 0)
				{
					// Grabamos los errores.
					addErrors(request, errors);
				}
				//No hay Errores
				else
				{
					try
					{
						// Obtenemos una instancia de IBAuthManager.
						IBAuthManager ibAuthManager = createIBAuthManager();
						
						// invocamos al m&eacute;todo obtener contrase&ntilde;a
						ibAuthManager.forgotPassword(afAuth.getEmail());
						
						// indicamos que la operaci&oacute;n ha finalizado correctamente
						request.setAttribute(SUCESS, true);
						
					}
					catch (Exception ex)
					{
						
						//Error controlado
						if(ex.getMessage().startsWith("errors.")){
							
							ActionErrors errorsEx = afAuth.generarError("Email", ex.getMessage());
							
							// Grabamos los errores.
							addErrors(request, errorsEx);
							
						}else{
							// Nombre de la Clase
							request.setAttribute("infoClass", "DAAuth");
							// Nombre de la excepci&oacute;n
							request.setAttribute("type", ex.getClass().getName());
							// Descripci&oacute;n de la excepci&oacute;n
							request.setAttribute("message", ex.getMessage());
							// Nombre de la Transacci&oacute;n
							request.setAttribute("action", ACTION_FORGOT_PASSWORD);
							// Escribimos por la salida est&aacute;ndar la Traza.
							ex.printStackTrace();
							
							//Ponemos como vista la de Error General
							view_act = VIEW_GLOBAL_ERROR;
						}
					}
				}
			}
			
		 // Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
		 // Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));
	  }
	  
}
