package edu.uoc.integra.struts.actions;

import javax.servlet.http.HttpServletRequest;

import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import org.apache.struts.actions.DispatchAction;

import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.functions.IBCommonManagerImpl.TypeAutoriz;
import edu.uoc.integra.business.interfaces.IBAuthManager;
import edu.uoc.integra.business.interfaces.IBConfigManager;
import edu.uoc.integra.business.interfaces.IBInfoManager;
import edu.uoc.integra.business.interfaces.IBProjectManager;
import edu.uoc.integra.business.interfaces.IBUserManager;
import edu.uoc.integra.business.objects.transfers.TOUser;


/**
 * <p>Esta clase ofrece una serie de m&eacute;todos que ser&aacute;n heredados por todas las "actions" que 
 * forman la aplicaci&oacute;n.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public abstract class DACommom extends DispatchAction
{
	
	/** <p>Entrada Inicial de la Aplicaci&oacute;n.</p> */
	public static final String VIEW_GLOBAL_INDEX = "Index";
	/** <p>Error General de la Aplicaci&oacute;n.</p> */
    public static final String VIEW_GLOBAL_ERROR = "?page=ErrorGeneral";

  //Atributos
	public static final String SUCESS  = "sucess";
	public static final String FAIL    = "fail";
	
	/** <p>Datos de sessi&oacute;n</p> */
	public static final String SESSION_USER = "userInfo";
	/** <p>Datos de sessi&oacute;n</p> */
	public static final String SESSION_FILTER_PROJECT = "filterProject";
	/** <p>Datos de sessi&oacute;n</p> */
	public static final String SESSION_FILTER_USER = "filterUser";
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para obtener una instancia de un objeto que implemente la interfaz <code>IBConfigManager</code>.</p>
	 * 
	 * @return <code>IBConfigManager</code> objeto que implementa esta interfaz.
	 * 
	 * @throws ClassNotFoundException No se encuentra la clase que implementa la interfaz.
	 * @throws IllegalAccessException No se tiene acceso al constructor de esa clase.
	 * @throws InstantiationException No se puede construir un objeto de la clase.
	 */
	protected IBConfigManager createIBConfigManager() throws InstantiationException, 
			IllegalAccessException, ClassNotFoundException
	{
		// Recuperamos el nombre de la clase que implementa la interfaz.
		String className = (String) getServlet().getServletContext().getAttribute("IBConfigManager");
		// Retornamos una nueva intancia de esta clase.
		return (IBConfigManager) Class.forName(className).newInstance();
	}
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para obtener una instancia de un objeto que implemente la interfaz <code>IBAuthManager</code>.</p>
	 * 
	 * @return <code>IBAuthManager</code> objeto que implementa esta interfaz.
	 * 
	 * @throws ClassNotFoundException No se encuentra la clase que implementa la interfaz.
	 * @throws IllegalAccessException No se tiene acceso al constructor de esa clase.
	 * @throws InstantiationException No se puede construir un objeto de la clase.
	 */
	protected IBAuthManager createIBAuthManager() throws InstantiationException, 
			IllegalAccessException, ClassNotFoundException
	{
		
		// Recuperamos el nombre de la clase que implementa la interfaz.
		String className = (String) getServlet().getServletContext().getAttribute("IBAuthManager");
		
		// Retornamos una nueva intancia de esta clase.
		return (IBAuthManager) Class.forName(className).newInstance();
	}
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para obtener una instancia de un objeto que implemente la interfaz <code>IBUserManager</code>.</p>
	 * 
	 * @return <code>IBUserManager</code> objeto que implementa esta interfaz.
	 * 
	 * @throws ClassNotFoundException No se encuentra la clase que implementa la interfaz.
	 * @throws IllegalAccessException No se tiene acceso al constructor de esa clase.
	 * @throws InstantiationException No se puede construir un objeto de la clase.
	 */
	protected IBUserManager createIBUserManager() throws InstantiationException, 
			IllegalAccessException, ClassNotFoundException
	{
		// Recuperamos el nombre de la clase que implementa la interfaz.
		String className = (String) getServlet().getServletContext().getAttribute("IBUserManager");
		// Retornamos una nueva intancia de esta clase.
		return (IBUserManager) Class.forName(className).newInstance();
	}

	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para obtener una instancia de un objeto que implemente la interfaz <code>IBProjectManager</code>.</p>
	 * 
	 * @return <code>IBProjectManager</code> objeto que implementa esta interfaz.
	 * 
	 * @throws ClassNotFoundException No se encuentra la clase que implementa la interfaz.
	 * @throws IllegalAccessException No se tiene acceso al constructor de esa clase.
	 * @throws InstantiationException No se puede construir un objeto de la clase.
	 */
	protected IBProjectManager createIBProjectManager() throws InstantiationException, 
			IllegalAccessException, ClassNotFoundException
	{
		// Recuperamos el nombre de la clase que implementa la interfaz.
		String className = (String) getServlet().getServletContext().getAttribute("IBProjectManager");
		// Retornamos una nueva intancia de esta clase.
		return (IBProjectManager) Class.forName(className).newInstance();
	}
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para obtener una instancia de un objeto que implemente la interfaz <code>IBInfoManager</code>.</p>
	 * 
	 * @return <code>IBInfoManager</code> objeto que implementa esta interfaz.
	 * 
	 * @throws ClassNotFoundException No se encuentra la clase que implementa la interfaz.
	 * @throws IllegalAccessException No se tiene acceso al constructor de esa clase.
	 * @throws InstantiationException No se puede construir un objeto de la clase.
	 */
	protected IBInfoManager createIBInfoManager() throws InstantiationException, 
			IllegalAccessException, ClassNotFoundException
	{
		// Recuperamos el nombre de la clase que implementa la interfaz.
		String className = (String) getServlet().getServletContext().getAttribute("IBInfoManager");
		// Retornamos una nueva intancia de esta clase.
		return (IBInfoManager) Class.forName(className).newInstance();
	}
	
	/**
	 * <p>Este m&eacute;todo ser&aacute; llamado cada vez que se produzca una excepci&oacute;n no controlada en la aplicaci&oacute;n.
	 * Se encargar&aacute; de determinar la siguiente vista que tiene que mostrar</p>
	 * 
	 * @param pclass <code>Class</code> clase que ha provocado la excepci&oacute;n.
	 * @param ex <code>Exception</code> informaci&oacute;n de la excepci&oacute;n.
	 * @param transaction <code>String</code> acci&oacute;n que se estaba ejecutando.
	 * @param mapping <code>ActionMapping</code> mapeo de struct.
	 * @param request <code>HttpServletRequest</code> petici&oacute;n que ha producido la excepci&oacute;n.
	 * 
	 * @return <code>ActionForward</code> siguiente vista a mostrar.
	 */
	@SuppressWarnings("rawtypes")
	protected ActionForward processException(Class zClass, Exception ex, String transaction,
			ActionMapping mapping, HttpServletRequest request)
	{
		// Nombre de la Clase
		request.setAttribute("zClass", zClass.getName());
		// Nombre de la excepci&oacute;n
		request.setAttribute("type", ex.getClass().getName());
		// Descripci&oacute;n de la excepci&oacute;n
		request.setAttribute("message", ex.getMessage());
		// Nombre de la Transacci&oacute;n
		request.setAttribute("transaction", transaction);
		// Siguiente vista.
		ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
		// Escribimos por la salida est&aacute;ndar la Traza.
		ex.printStackTrace();
		// Retornamos la siguiente vista a mostrar.
		return (new ActionForward(next.getPath() + "?page=error"));		
	}
	
	/**
	 * <p>Retorna el identificador del Usuario que est&aacute; guardado en la HttpSession.</p>
	 * 
	 * @param request <code>HttpServletRequest</code> asociada a una petici&oacute;n de usuario.
	 * 
	 * @return <code>int</code> el identificador del usuario.
	 * 
	 * @throws ExceptionControl en el caso de que no encontremos el identificador
	 */
	protected int getUserId(HttpServletRequest request) throws ExceptionControl 
	{
		// Recuperamos de la sesi&oacute;n el objeto con los datos del usuario.
		Object objTOUser = request.getSession().getAttribute(SESSION_USER);
		
		
		// Comprobamos que no es nulo y es de tipo TOUser.
		if ((objTOUser != null) && (objTOUser instanceof TOUser))
		{
			// Realizamos el cast del objeto
			TOUser user = (TOUser) objTOUser;
			
			// Retornamos el identificador del usuario.
			return (user.getId());
		}
		else
		{
			// No hemos encontrado el Id del usuario.
			throw (new ExceptionControl(ExceptionControl.MSG_USER_ID_INVALID));
		}
	}
	
	/**
	 * <p>M&eacute;todo que verifica si una petici&oacute;n HTTP es iniciada por un usuario que ha iniciado sesi&oacute;n 
	 * y adem&aacute;s es un Administrador.</p>
	 * 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n HTTP.
	 * 
	 * @return <code>true</code> si ha iniciado sesi&oacute;n y es administrador.
	 */
	protected boolean isAdmin(HttpServletRequest request)
	{
		// Recuperamos de la sesi&oacute;n el objeto con los datos del usuario.
		Object objTOUser = request.getSession().getAttribute(SESSION_USER);
		
		// Comprobamos que no es nulo y es de tipo TOUser.
		if ((objTOUser != null) && (objTOUser instanceof TOUser))
		{
			// Realizamos el cast del objeto
			TOUser user = (TOUser) objTOUser;
			
			// Comprobamos si se trata de un administrador.
			return (user.getType().equals(TypeAutoriz.ADMINISTRADOR.toString()));
		}
		
		// En este punto consideramos que no es un administrador.
		return false;
	}
	
	/**
	 * <p>M&eacute;todo que verifica si una petici&oacute;n HTTP es iniciada por un usuario que ha iniciado sesi&oacute;n 
	 * y adem&aacute;s es un usuario avanzado.</p>
	 * 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n HTTP.
	 * 
	 * @return <code>true</code> si ha iniciado sesi&oacute;n y es un usuario avanzado.
	 */
	protected boolean isAvanzado(HttpServletRequest request)
	{
		// Recuperamos de la sesi&oacute;n el objeto con los datos del usuario.
		Object objTOUser = request.getSession().getAttribute(SESSION_USER);
		
		// Comprobamos que no es nulo y es de tipo TOUser.
		if ((objTOUser != null) && (objTOUser instanceof TOUser))
		{
			// Realizamos el cast del objeto
			TOUser user = (TOUser) objTOUser;
			
			// Comprobamos si se trata de un usuario avanzado.
			return (user.getType().equals(TypeAutoriz.AVANZADO.toString()));
		}
		
		// En este punto consideramos que no es un usuario avanzado.
		return false;
	}

	/**
	 * <p>M&eacute;todo que verifica si una petici&oacute;n HTTP es iniciada por un usuario que ha iniciado sesi&oacute;n 
	 * y adem&aacute;s es un usuario normal.</p>
	 * 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n HTTP.
	 * 
	 * @return <code>true</code> si ha iniciado sesi&oacute;n y es un usuario normal.
	 */
	protected boolean isNormal(HttpServletRequest request)
	{
		// Recuperamos de la sesi&oacute;n el objeto con los datos del usuario.
		Object objTOUser = request.getSession().getAttribute(SESSION_USER);
		
		// Comprobamos que no es nulo y es de tipo TOUser.
		if ((objTOUser != null) && (objTOUser instanceof TOUser))
		{
			// Realizamos el cast del objeto
			TOUser user = (TOUser) objTOUser;
			
			// Comprobamos si se trata de un usuario normal.
			return (user.getType().equals(TypeAutoriz.NORMAL.toString()));
		}
		
		// En este punto consideramos que no es un usuario normal.
		return false;
	}

	
	
	
}
