package edu.uoc.integra.struts.actions;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.functions.IBCommonManagerImpl.TypeParam;
import edu.uoc.integra.business.interfaces.IBConfigManager;
import edu.uoc.integra.business.objects.transfers.TOConfig;
import edu.uoc.integra.lib.utils.Validations;
import edu.uoc.integra.struts.forms.AFConfig;

/**
 * <p>Esta clase gestionar&aacute; las funcionalidades relacionadas con la
 * configuraci&oacute;n de los par&aacute;metros de la aplicaci&oacute;n.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class DAConfig extends DACommom
{
	//Vistas
	public static final String VIEW_ADMIN_LIST_CONFIG    = "?opt=admin&page=ConfigList";
	public static final String VIEW_ADMIN_CONFIG_INFO    = "?opt=admin&page=ConfigInfo";
	public static final String VIEW_ADMIN_CONFIG_MODIF   = "?opt=admin&page=ConfigModif";
		
	//Acciones
	public static final String ACTION_GET_CONFIG         = "getConfig";
	public static final String ACTION_LIST_CONFIG        = "listConfig";
	public static final String ACTION_MODIF_CONFIG       = "modifyConfig";
	
	//Objetos
	public static final String SUCESS 	         = "sucess";
	public static final String FAIL 	         = "fail";
	public static final String CONFIG 	         = "config";
	public static final String LIST_CONFIG_EMAIL = "listConfigEmail";
	public static final String LIST_CONFIG_USER  = "listConfigUser";
	public static final String LIST_CONFIG_PROY  = "listConfigProy";
	
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar los datos de un Par&aacute;metro
	 * registrado en el sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formConfig <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward getConfig(ActionMapping mapping, ActionForm formConfig,
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
				
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que existe el par&aacute;metro "id" y  es num&eacute;rico.
		// Verificamos que el formulario recibido es de tipo AFConfig
		if (isAdmin(request) 
			&& Validations.isInteger(request.getParameter("id"))
			&& (formConfig instanceof AFConfig)){
			
			try
			{
				// Convertimos el identificador a integer
				int idConfig = Integer.parseInt(request.getParameter("id"));
				
				// Obtenemos una instancia de IBConfigManager.
				IBConfigManager ibConfigManager = createIBConfigManager();
				
				// Invocamos al m&eacute;todo para obtener los datos del Formulario
				TOConfig toConfig = ibConfigManager.getConfig(idConfig);
				
				//Realizamos el Cast del formulario al tipo AFConfig
				AFConfig AFConfig = (AFConfig) formConfig;
				
				// Copiamos la informaci&oacute;n del par&aacute;metro al formulario.
				AFConfig.copyProperties(toConfig);
				
				view_act = VIEW_ADMIN_CONFIG_INFO;
				
			}
			catch (Exception ex)
			{
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAConfig");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_GET_CONFIG);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();
				
				view_act = VIEW_GLOBAL_ERROR;			

			}
		}else{
			
			//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
			
		}
		
		
		 // Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
		  // Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));	
	}
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar los datos de un par&aacute;metro
	 * registrado en el sistema para su modificaci&oacute;n.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formConfig <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward getConfigModif(ActionMapping mapping, ActionForm formConfig,
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
				
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que existe el par&aacute;metro "id" y  es num&eacute;rico.
		// Verificamos que el formulario recibido es de tipo AFConfig
		if (isAdmin(request) 
			&& Validations.isInteger(request.getParameter("id"))
			&& (formConfig instanceof AFConfig)){
			
			try
			{
				// Convertimos el identificador a integer
				int idConfig = Integer.parseInt(request.getParameter("id"));
				
				// Obtenemos una instancia de IBConfigManager.
				IBConfigManager ibConfigManager = createIBConfigManager();
				
				// Invocamos al m&eacute;todo para obtener los datos del Formulario
				TOConfig toConfig = ibConfigManager.getConfig(idConfig);
				
				//Realizamos el Cast del formulario al tipo AFConfig
				AFConfig AFConfig = (AFConfig) formConfig;
				
				// Copiamos la informaci&oacute;n del usuario en el formulario.
				AFConfig.copyProperties(toConfig);
				
				view_act = VIEW_ADMIN_CONFIG_MODIF;
				
			}
			catch (Exception ex)
			{
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAConfig");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_GET_CONFIG);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();
				
				view_act = VIEW_GLOBAL_ERROR;			

			}
		}else{
			
			//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
			
		}
		
		 // Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
		   // Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));	
	}
		
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere modificar el valor de un par&aacute;metro
	 * en el sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formConfig <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward modifyConfig(ActionMapping mapping, ActionForm formConfig, 
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
						
		//Verificamos  que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que el formulario recibido es de tipo AFConfig
		if ((isAdmin(request)) 
			&& (formConfig instanceof AFConfig))
		{
			try
			{
				// Realizamos un Cast del formulario.
				AFConfig AFConfig = (AFConfig) formConfig;
				
				// Validamos los datos del formulario
				ActionErrors errors = AFConfig.validate();
				
				// Comprobamos si hay errores
				if (errors.size() > 0)
				{
					// Grabamos los errores de validaci&oacute;n simples.
					addErrors(request, errors);
					
					// Vista Actual
					view_act = VIEW_ADMIN_CONFIG_MODIF;
				}
				else
				{
					// Instanciamos IBConfigManager
					IBConfigManager ibConfigManager = createIBConfigManager();
					
					TOConfig toConfig = null;
					
					// Invocamos al m&eacute;todo que actualiza los datos
					if(AFConfig.getType().equals(TypeParam.EMAIL.toString())){
						toConfig = ibConfigManager.modifyConfigEmail(AFConfig.getName(), AFConfig.getValue());
					}

					if(AFConfig.getType().equals(TypeParam.USER.toString())){
						toConfig = ibConfigManager.modifyConfigUser(AFConfig.getName(), AFConfig.getValue());
					}

					if(AFConfig.getType().equals(TypeParam.PROJECT.toString())){
						toConfig = ibConfigManager.modifyConfigProject(AFConfig.getName(), AFConfig.getValue());
					}
					
					// Guardamos la informaci&oacute;n del usuario en la request.
					request.setAttribute(CONFIG, toConfig);
					
					// Indicamos que la operaci&oacute;n ha sido realizada con &eacute;xito.
					request.setAttribute(SUCESS, true);
					
					// Vista Actual
					view_act = VIEW_ADMIN_CONFIG_MODIF;
				}
			
			}
			catch (ExceptionControl ec)
			{
				System.out.println("Indicamos que hay un error controlado");
				
				// Indicamos que la operaci&oacute;n no ha sido realizada con &eacute;xito.
				request.setAttribute(FAIL, ec.getMessage());
				
				// Vista Actual
				view_act = VIEW_ADMIN_CONFIG_MODIF;
			}
			catch (Exception ex)
			{
				// Se ha producido cualquier otro tipo de excepci&oacute;n.
				System.out.println("createConfig error no controlado ="+ ex);
				
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAConfig");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_GET_CONFIG);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();

				// Vista Actual.
				view_act = VIEW_GLOBAL_ERROR;		
			}
		}
		
	 // Obtenemos la vista por defecto.
		ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
	  //Siguiente Vista
		System.out.println("Pr&oacute;xima P&aacute;gina ="+ next.getPath() + view_act);
			
	 // Retornamos la siguiente vista a mostrar al usuario.
		return (new ActionForward(next.getPath() + view_act));
	}
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar todos los usuarios
	 * registrados en el sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formConfig <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward listConfig(ActionMapping mapping, ActionForm form, 
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
		
		
		System.out.println("Acci&oacute;n listConfig");
		
		
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		if (isAdmin(request))
		{
			
			System.out.println("Usuario Administrador");
			
			try
			{
				
				System.out.println("Instanciamos IBConfigManager");
				// Obtenemos una instancia de IBConfigManager.
				IBConfigManager ibConfigManager = createIBConfigManager();
				
				System.out.println("invocamos metodo listConfigEmail");
				// Recuperamos la lista de Par&aacute;metros de Email
				List<TOConfig> configEmails   = ibConfigManager.listConfigEmail();
				System.out.println("Registros recuperados =" + configEmails.size());
				
				System.out.println("invocamos metodo listConfigUser");
				// Recuperamos la lista de Par&aacute;metros de Usuario
				List<TOConfig> configUsers    = ibConfigManager.listConfigUser();
				System.out.println("Registros recuperados =" + configUsers.size());
				
				System.out.println("invocamos metodo listConfigManager");
				// Recuperamos la lista de Par&aacute;metros de Proyecto
				List<TOConfig> configProjects = ibConfigManager.listConfigProject();
				System.out.println("Registros recuperados =" + configProjects.size());
	
				System.out.println("Guardamos lista en par&aacute;metro " + LIST_CONFIG_EMAIL + ',' + LIST_CONFIG_PROY + ',' + LIST_CONFIG_USER);
				// Guardamos la informaci&oacute;n en la request.
				request.setAttribute(LIST_CONFIG_EMAIL, configEmails);
				request.setAttribute(LIST_CONFIG_PROY, configProjects);
				request.setAttribute(LIST_CONFIG_USER, configUsers);
				
				// Indicamos cual es la siguiente vista a mostrar.
				view_act = VIEW_ADMIN_LIST_CONFIG;
			}
			catch (Exception ex)
			{
				System.out.println("listConfig error no controlado ="+ ex);
				
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAConfig");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_LIST_CONFIG);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();
				
				view_act = VIEW_GLOBAL_ERROR;			
			}
		}else{
			
			//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
			System.out.println("NO ES ADMINISTRADOR, LO MANDAMOS A LA PANTALLA PRINCIPAL");
			
		}
		
	 // Obtenemos la vista por defecto.
		ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
		
	  //Siguiente Vista
		System.out.println("Pr&oacute;xima P&aacute;gina ="+ next.getPath() + view_act);
		
	 // Retornamos la siguiente vista a mostrar al usuario.
		return (new ActionForward(next.getPath() + view_act));
	}
	
	
	
}
