package edu.uoc.integra.struts.actions;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;

import edu.uoc.integra.business.interfaces.IBInfoManager;
import edu.uoc.integra.business.interfaces.IBProjectManager;
import edu.uoc.integra.business.objects.transfers.TOInform;
import edu.uoc.integra.business.objects.transfers.TOInformR;
import edu.uoc.integra.business.objects.transfers.TOProject;
import edu.uoc.integra.lib.utils.Validations;
import edu.uoc.integra.struts.forms.AFInform;


/**
 * <p>Esta clase es la encargada de manejar las acciones relacionadas con la <i>Generaci&oacute;n de informes</i> de la aplicaci&oacute;n.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class DAInfo extends DACommom {
	
	//Vistas
	  /** <p>Mostrar Informes Predefinidos.</p> */
	  public static final String VIEW_ADVAN_LIST_INFORM = "?opt=advan&page=InformList";
	  /** <p>Mostrar Informe Generado Resumen.</p> */
	  public static final String VIEW_ADVAN_INFORM_RESU = "?opt=advan&page=InformResu";
	  /** <p>Mostrar Informe Generado Completo.</p> */
	  public static final String VIEW_ADVAN_INFORM_COMP = "?opt=advan&page=InformComp";
	  /** <p>Mostrar Informe Generado Evoluci&oacute;n.</p> */
	  public static final String VIEW_ADVAN_INFORM_EVOL = "?opt=advan&page=InformEvol";
	  /** <p>Mostrar Formulario para generaci&oacuten; de Informe.</p> */
	  public static final String VIEW_ADVAN_INFORM_INFO = "?opt=advan&page=InformInfo";
	  
	  /** <p>Acceder usuario al sistema.</p> */
      public static final String VIEW_AUTH_SIGNIN  = "?page=SignIn";
	  
	//Acciones
	  public static final String ACTION_GENE_INFORM      = "genInform";
	  public static final String ACTION_LIST_INFORM      = "listInform";
	  public static final String ACTION_GET_INFORM       = "getInform";
	  
	//Objetos
	  public static final String SUCESS 	  = "sucess";
	  public static final String FAIL 	      = "fail";
	  public static final String LIST_INFORM  = "listInform";
	  public static final String LIST_PROJECT = "listProject";
	  public static final String PROJECT	  = "project";
	  public static final String ROLS		  = "listRol";
	  public static final String STATES		  = "listState";
	  public static final String WORKFLOWS	  = "listWorkFlow";
	  public static final String USERS		  = "listUserRol";
	  
	  
	//Tipos de Informes Predefinidos  
	  public static final String INFORM_RESU = "INFPROJ01";
	  public static final String INFORM_COMP = "INFPROJ02";
	  public static final String INFORM_EVOL = "INFPROJ03";
	  
	  
	  /**
		 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar los informes
		 * definidos en el sistema.</p> 
		 *   
		 * @param mapping <code>ActionMapping</code> mapeos de Struts.
		 * @param formInform <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
		 * @param request <code>HttpServletRequest</code> petici&oacute;n.
		 * @param response <code>HttpServletResponse</code> respuesta.
		 * 
		 * @return <code>ActionForward</code> siguiente vista. 
		 */
		public ActionForward listInform(ActionMapping mapping, ActionForm formInform, 
				HttpServletRequest request, HttpServletResponse response)
		{
			//Vista actual
			String view_act = " ";
			
			//Verificamos que el usuario que inicia la acci&oacute;n es un usuario avanzado 
			if (isAvanzado(request))
			{
				
				List<TOInform> informs = null;
				
				try
				{
					
					// Obtenemos una instancia de IBInfoManager.
					IBInfoManager ibInfoManager = createIBInfoManager();
					
					//Obtenemos la lista de los informes definidos
					informs = ibInfoManager.listInform();
											
					// Guardamos la informaci&oacute;n en la request.
					request.setAttribute(LIST_INFORM, informs);
					
					// Indicamos cual es la siguiente vista a mostrar.
					view_act = VIEW_ADVAN_LIST_INFORM;
				}
				catch (Exception ex)
				{
					// Nombre de la Clase
					request.setAttribute("infoClass", "DAInfo");
					// Nombre de la excepci&oacute;n
					request.setAttribute("type", ex.getClass().getName());
					// Descripci&oacute;n de la excepci&oacute;n
					request.setAttribute("message", ex.getMessage());
					// Nombre de la Transacci&oacute;n
					request.setAttribute("action", ACTION_LIST_INFORM);
					// Escribimos por la salida est&aacute;ndar la Traza.
					ex.printStackTrace();
					
					view_act = VIEW_GLOBAL_ERROR;			
				}
			}else{
				
				//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
				view_act = VIEW_AUTH_SIGNIN;
				
				
			}
			
		 // Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
		 // Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));
		}
		
		/**
		 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar los datos de un informe
		 * registrado en el sistema.</p> 
		 *   
		 * @param mapping <code>ActionMapping</code> mapeos de Struts.
		 * @param formInform <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
		 * @param request <code>HttpServletRequest</code> petici&oacute;n.
		 * @param response <code>HttpServletResponse</code> respuesta.
		 * 
		 * @return <code>ActionForward</code> siguiente vista. 
		 */
		public ActionForward getInform(ActionMapping mapping, ActionForm formInform,
				HttpServletRequest request, HttpServletResponse response)
		{
			//Vista actual
			String view_act = " ";
			
			//Verificamos que el usuario que inicia la acci&oacute;n es un usuario avanzado 
			//Verificamos que existe el par&aacute;metro "id" y  es num&eacute;rico.
			// Verificamos que el formulario recibido es de tipo AFInform
			if (isAvanzado(request) 
				&& Validations.isInteger(request.getParameter("id"))
				&& (formInform instanceof AFInform)){
				
				try
				{
					// Convertimos el identificador a integer
					int idInform = Integer.parseInt(request.getParameter("id"));
					
					// Obtenemos una instancia de IBInfoManager.
					IBInfoManager ibInfoManager = createIBInfoManager();
					
					//Obtenemos la informaci&oacute;n del Informe
					TOInform inform = ibInfoManager.getInform(idInform);
					
					// Obtenemos una instancia de IBprojectManager.
					IBProjectManager ibProjectManager = createIBProjectManager();
					
					//En principio todos los informes definidos trabajan sobre los proyectos
					//por lo que el formulario siempre necesitar&aaccute; la lista de los
					//proyectos
					List<TOProject> projects = ibProjectManager.listProject(); 
			
					//Realizamos el Cast del formulario al tipo AFInform
					AFInform afInform = (AFInform) formInform;
					
					// Copiamos la informaci&oacute;n del informe en el formulario.
					afInform.copyProperties(inform);
					
					// Informamos los projectos 
					request.setAttribute(LIST_PROJECT, projects);
					
					view_act = VIEW_ADVAN_INFORM_INFO;
					
				}
				catch (Exception ex)
				{
					// Nombre de la Clase
					request.setAttribute("infoClass", "DAInfo");
					// Nombre de la excepci&oacute;n
					request.setAttribute("type", ex.getClass().getName());
					// Descripci&oacute;n de la excepci&oacute;n
					request.setAttribute("message", ex.getMessage());
					// Nombre de la Transacci&oacute;n
					request.setAttribute("action", ACTION_GET_INFORM);
					// Escribimos por la salida est&aacute;ndar la Traza.
					ex.printStackTrace();
					
					view_act = VIEW_GLOBAL_ERROR;			

				}
			}else{
				//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
				view_act = VIEW_AUTH_SIGNIN;
				
			}
			
			
			 // Obtenemos la vista por defecto.
				ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
				
			 // Retornamos la siguiente vista a mostrar al usuario.
				return (new ActionForward(next.getPath() + view_act));	
		}
		
		
		/**
		 * <p>Este M&eacute;todo es llamado cada vez que se quiere generar un informe en concreto</p> 
		 *   
		 * @param mapping <code>ActionMapping</code> mapeos de Struts.
		 * @param formInform <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
		 * @param request <code>HttpServletRequest</code> petici&oacute;n.
		 * @param response <code>HttpServletResponse</code> respuesta.
		 * 
		 * @return <code>ActionForward</code> siguiente vista. 
		 */
		public ActionForward genInform(ActionMapping mapping, ActionForm formInform,
				HttpServletRequest request, HttpServletResponse response)
		{
			//Vista actual
			String view_act = " ";
					
			//Verificamos que el usuario que inicia la acci&oacute;n es un usuario avanzado 
			// Verificamos que el formulario recibido es de tipo AFInform
			if (isAvanzado(request) 
				&& (formInform instanceof AFInform)){
				
				// Realizamos un Cast del formulario.
				AFInform afInform = (AFInform) formInform;
				
				// Validamos los datos del formulario
				ActionErrors errors = afInform.validateInform();
				
				// Comprobamos si hay errores
				if (errors.size() > 0)
				{
					
					// Obtenemos una instancia de IBprojectManager.
					IBProjectManager ibProjectManager;
					try {
						
						ibProjectManager = createIBProjectManager();
						
						//En principio todos los informes definidos trabajan sobre los proyectos
						List<TOProject> projects = ibProjectManager.listProject(); 
						
						// Ha habido errores en los datos, los grabamos
						addErrors(request, errors);
						
						// Informamos los projectos 
						request.setAttribute(LIST_PROJECT, projects);
						
						// Vista Actual
						view_act = VIEW_ADVAN_INFORM_INFO;
						
					} catch (Exception ex) {
						
						// Nombre de la Clase
						request.setAttribute("infoClass", "DAInfo");
						// Nombre de la excepci&oacute;n
						request.setAttribute("type", ex.getClass().getName());
						// Descripci&oacute;n de la excepci&oacute;n
						request.setAttribute("message", ex.getMessage());
						// Nombre de la Transacci&oacute;n
						request.setAttribute("action", ACTION_GENE_INFORM);
						// Escribimos por la salida est&aacute;ndar la Traza.
						ex.printStackTrace();
						
						view_act = VIEW_GLOBAL_ERROR;	
					}

				}else{
				
					try
					{
						// Obtenemos una instancia de IBInfoManager.
						IBInfoManager ibInfoManager = createIBInfoManager();
						
						//Obtenemos la informaci&oacute;n del Informe
						TOInform inform = ibInfoManager.getInform(Integer.parseInt(afInform.getId()));
						
						// Obtenemos una instancia de IBProjectManager.
						IBProjectManager  ibProjectManager = createIBProjectManager();
						
						//Obtenemos la informaci&oacute;n del Proyecto
						TOProject project = ibProjectManager.getProject(Integer.parseInt(afInform.getIdproject()));
						
						TOInformR toInformR = null;
						
						if(inform.getName().equals(INFORM_RESU)){
							
							toInformR = ibInfoManager.informResu(project);
							
							//Generamos los objetos necesarios para el informe
							request.setAttribute(PROJECT, toInformR.getProject());
							request.setAttribute(ROLS, toInformR.getRols());
							request.setAttribute(STATES, toInformR.getStates());
							request.setAttribute(WORKFLOWS, toInformR.getWorkFlows());
							request.setAttribute(USERS, toInformR.getUsers());
							
							view_act = VIEW_ADVAN_INFORM_RESU;
						}else{
							
							//Obtenemos los informes
							List<TOInform> informs = ibInfoManager.listInform();
							
							// Guardamos la informaci&oacute;n en la request.
							request.setAttribute(LIST_INFORM, informs);
							
							request.setAttribute(FAIL, "error.inform.no.permit");
							
							// Indicamos cual es la siguiente vista a mostrar.
							view_act = VIEW_ADVAN_LIST_INFORM;
							
						}
					}
					catch (Exception ex)
					{
						// Nombre de la Clase
						request.setAttribute("infoClass", "DAInfo");
						// Nombre de la excepci&oacute;n
						request.setAttribute("type", ex.getClass().getName());
						// Descripci&oacute;n de la excepci&oacute;n
						request.setAttribute("message", ex.getMessage());
						// Nombre de la Transacci&oacute;n
						request.setAttribute("action", ACTION_GENE_INFORM);
						// Escribimos por la salida est&aacute;ndar la Traza.
						ex.printStackTrace();
						
						view_act = VIEW_GLOBAL_ERROR;			

					}
				}
				
			}else{
				//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
				view_act = VIEW_AUTH_SIGNIN;
				
			}
			
			
			// Obtenemos la vista por defecto.
				ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
				
			 // Retornamos la siguiente vista a mostrar al usuario.
				return (new ActionForward(next.getPath() + view_act));	
		}		
}
