package edu.uoc.integra.struts.actions;

import java.util.List;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionForward;
import org.apache.struts.action.ActionMapping;
import edu.uoc.integra.business.exceptions.ExceptionControl;
import edu.uoc.integra.business.interfaces.IBUserManager;
import edu.uoc.integra.business.objects.transfers.TOUser;
import edu.uoc.integra.lib.utils.Validations;
import edu.uoc.integra.struts.forms.AFUser;

/**
 * Esta clase es la encargada de manejar las acciones relacionadas con la gesti&oacute;n de los usuarios de la aplicaci&oacute;n.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class DAUser extends DACommom 
{
	
	//Vistas
	public static final String VIEW_ADMIN_CREATE_USER  = "?opt=admin&page=UserNew";
	public static final String VIEW_ADMIN_LIST_USER    = "?opt=admin&page=UserList";
	public static final String VIEW_ADMIN_USER_INFO    = "?opt=admin&page=UserInfo";
	public static final String VIEW_ADMIN_USER_MODIF   = "?opt=admin&page=UserModif";
	public static final String VIEW_ADMIN_USER_DELETE  = "?opt=admin&page=UserDelete";
	
	
	//Acciones
	public static final String ACTION_CREATE_USER      = "createUser";
	public static final String ACTION_UNLOCK_USER      = "unlockUser";
	public static final String ACTION_DELETE_USER      = "deleteUser";
	public static final String ACTION_GET_USER         = "getUser";
	public static final String ACTION_LIST_USER        = "listUser";
	public static final String ACTION_EMAIL_USER       = "emailDatUser";
	
	//Objetos
	public static final String SUCESS 	 = "sucess";
	public static final String FAIL 	 = "fail";
	public static final String USER 	 = "user";
	public static final String LIST_USER = "listUser";
	
	
	/**
	  * <p>Este M&eacute;todo es llamadado cada vez que se quiera dar de alta a un usuario en el sistema.</p>
	 * 
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formUser <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward createUser(ActionMapping mapping, ActionForm formUser, 
			HttpServletRequest request, HttpServletResponse response)
	{
		
		//Vista actual
		String view_act = " ";
		
		// Verificamos que el usuario que inicia la acci&oacute;n es un administrador
		// Verificamos que el formulario recibido es el de Usuario
		if (isAdmin(request) 
			&& (formUser instanceof AFUser))
		{
			
			// Realizamos un Cast del formulario.
			AFUser afUser = (AFUser) formUser;
			
			// Validamos los datos del formulario
			ActionErrors errors = afUser.validateCreateUser();
			
			// Comprobamos si hay errores
			if (errors.size() > 0)
			{
				// Ha habido errores en los datos, los grabamos
				addErrors(request, errors);
				
				// Vista Actual
				view_act = VIEW_ADMIN_CREATE_USER;

			}
			else 
			{
				// Convertimos el campo de bloqueo del formulario a tipo boolean
				boolean isLocked = Boolean.parseBoolean(afUser.getLocked());
				
				//Volcamos la informaci&oacute;n del formulario a un objeto de tipo TOUser
				TOUser toUser = new TOUser(afUser.getLogin()
						, afUser.getPassword()
						, afUser.getName()
						, afUser.getCompany()
						, afUser.getEmail()
						, 0
						,isLocked
						, afUser.getType());
				 
				try 
				{
					// Obtenemos una instancia de IBUserManager.
					IBUserManager ibUserManager = createIBUserManager();
					
					// Llamamos al m&eacute;todo que permite crear la cuenta del usuario.
					toUser = ibUserManager.createUser(toUser);
					
					// Guardamos la informaci&oacute;n del usuario en la request.
					request.setAttribute(USER, toUser);
					
					// Indicamos que la operaci&oacute;n ha sido realizada con &eacute;xito.
					request.setAttribute(SUCESS, true);
					
					// Vista Actual
					view_act = VIEW_ADMIN_CREATE_USER;
				}
				catch (ExceptionControl ec)
				{
					// Login o Email existen
					// Indicamos que la operaci&oacute;n no ha sido realizada con &eacute;xito.
					request.setAttribute(FAIL, ec.getMessage());
					
					// Vista Actual
					view_act = VIEW_ADMIN_CREATE_USER;
				}
				catch (Exception ex)
				{
					
					// Nombre de la Clase
					request.setAttribute("infoClass", "DAUser");
					// Nombre de la excepci&oacute;n
					request.setAttribute("type", ex.getClass().getName());
					// Descripci&oacute;n de la excepci&oacute;n
					request.setAttribute("message", ex.getMessage());
					// Nombre de la Transacci&oacute;n
					request.setAttribute("action", ACTION_CREATE_USER);
					// Escribimos por la salida est&aacute;ndar la Traza.
					ex.printStackTrace();

					// Vista Actual.
					view_act = VIEW_GLOBAL_ERROR;		
				}
			}
		}
				
	 // Obtenemos la vista por defecto.
		ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
	 // Retornamos la siguiente vista a mostrar al usuario.
		return (new ActionForward(next.getPath() + view_act));
	}
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar los datos de un usuario
	 * registrado en el sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formUser <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward getUser(ActionMapping mapping, ActionForm formUser,
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
				
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que existe el par&aacute;metro "id" y  es num&eacute;rico.
		// Verificamos que el formulario recibido es de tipo AFUser
		if (isAdmin(request) 
			&& Validations.isInteger(request.getParameter("id"))
			&& (formUser instanceof AFUser)){
			
			try
			{
				// Convertimos el identificador a integer
				int idUser = Integer.parseInt(request.getParameter("id"));
				
				// Obtenemos una instancia de IBUserManager.
				IBUserManager ibUserManager = createIBUserManager();
				
				// Invocamos al m&eacute;todo para obtener los datos del Formulario
				TOUser toUser = ibUserManager.getUser(idUser);
				
				//Realizamos el Cast del formulario al tipo AFUser
				AFUser afUser = (AFUser) formUser;
				
				// Copiamos la informaci&oacute;n del usuario en el formulario.
				afUser.copyProperties(toUser);
				
				view_act = VIEW_ADMIN_USER_INFO;
				
			}
			catch (Exception ex)
			{
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAUser");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_GET_USER);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();
				
				view_act = VIEW_GLOBAL_ERROR;			

			}
		}else{
			
			//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
			
		}
		
		 // Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
		 // Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));	
	}
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar los datos de un usuario
	 * registrado en el sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formUser <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward getUserModif(ActionMapping mapping, ActionForm formUser,
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
				
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que existe el par&aacute;metro "id" y  es num&eacute;rico.
		// Verificamos que el formulario recibido es de tipo AFUser
		if (isAdmin(request) 
			&& Validations.isInteger(request.getParameter("id"))
			&& (formUser instanceof AFUser)){
			
			try
			{
				// Convertimos el identificador a integer
				int idUser = Integer.parseInt(request.getParameter("id"));
				
				// Obtenemos una instancia de IBUserManager.
				IBUserManager ibUserManager = createIBUserManager();
				
				// Invocamos al m&eacute;todo para obtener los datos del Formulario
				TOUser toUser = ibUserManager.getUser(idUser);
				
				//Realizamos el Cast del formulario al tipo AFUser
				AFUser afUser = (AFUser) formUser;
				
				// Copiamos la informaci&oacute;n del usuario en el formulario.
				afUser.copyProperties(toUser);
				
				view_act = VIEW_ADMIN_USER_MODIF;
				
			}
			catch (Exception ex)
			{
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAUser");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_GET_USER);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();
				
				view_act = VIEW_GLOBAL_ERROR;			

			}
		}else{
			
			//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
			
		}
		
		 // Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
		 // Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));	
	}
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar los datos de un usuario
	 * registrado en el sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formUser <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward getUserDelete(ActionMapping mapping, ActionForm formUser,
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
				
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que existe el par&aacute;metro "id" y  es num&eacute;rico.
		// Verificamos que el formulario recibido es de tipo AFUser
		if (isAdmin(request) 
			&& Validations.isInteger(request.getParameter("id"))
			&& (formUser instanceof AFUser)){
			
			try
			{
				// Convertimos el identificador a integer
				int idUser = Integer.parseInt(request.getParameter("id"));
				
				// Obtenemos una instancia de IBUserManager.
				IBUserManager ibUserManager = createIBUserManager();
				
				// Invocamos al m&eacute;todo para obtener los datos del Formulario
				TOUser toUser = ibUserManager.getUser(idUser);
				
				//Realizamos el Cast del formulario al tipo AFUser
				AFUser afUser = (AFUser) formUser;
				
				// Copiamos la informaci&oacute;n del usuario en el formulario.
				afUser.copyProperties(toUser);
				
				view_act = VIEW_ADMIN_USER_DELETE;
				
			}
			catch (Exception ex)
			{
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAUser");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_GET_USER);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();
				
				view_act = VIEW_GLOBAL_ERROR;			

			}
		}else{
			
			//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
			
		}
		
		 // Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
		 // Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));	
	}

	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere modificar los datos de un usuario
	 * registrado en el sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formUser <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward modifyUser(ActionMapping mapping, ActionForm formUser, 
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
						
		//Verificamos  que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que el formulario recibido es de tipo AFUser
		if ((isAdmin(request)) 
			&& (formUser instanceof AFUser))
		{
			try
			{
				// Realizamos un Cast del formulario.
				AFUser afUser = (AFUser) formUser;
				
				// Validamos los datos del formulario
				ActionErrors errors = afUser.validateModifyUser();
				
				// Comprobamos si hay errores
				if (errors.size() > 0)
				{
					// Grabamos los errores de validaci&oacute;n simples.
					addErrors(request, errors);
					
					// Vista Actual
					view_act = VIEW_ADMIN_USER_INFO;
				}
				else
				{
					// Convertimos el identificador a integer
					int idUser = Integer.parseInt(afUser.getId());
					
					// Convertimos el campo de bloqueo del formulario a tipo boolean
					boolean isLocked = Boolean.parseBoolean(afUser.getLocked());
					
					// Instanciamos IBUserManager
					IBUserManager ibUserManager = createIBUserManager();
					
					// Invocamos al m&eacute;todo que actualiza los datos
					TOUser toUser = ibUserManager.modifyUser(idUser, 
							afUser.getLogin(), 
							afUser.getPassword(), 
							afUser.getName(), 
							afUser.getCompany(), 
							afUser.getEmail(), 
							afUser.getType(), isLocked);
					
					// Guardamos la informaci&oacute;n del usuario en la request.
					request.setAttribute(USER, toUser);
					
					// Indicamos que la operaci&oacute;n ha sido realizada con &eacute;xito.
					request.setAttribute(SUCESS, true);
					
					// Vista Actual
					view_act = VIEW_ADMIN_USER_MODIF;
				}
			
			}
			catch (ExceptionControl ec)
			{
				// Indicamos que la operaci&oacute;n no ha sido realizada con &eacute;xito.
				request.setAttribute(FAIL, ec.getMessage());
				
				// Vista Actual
				view_act = VIEW_ADMIN_USER_MODIF;
			}
			catch (Exception ex)
			{
				
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAUser");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_GET_USER);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();

				// Vista Actual.
				view_act = VIEW_GLOBAL_ERROR;		
			}
		}
		
	 // Obtenemos la vista por defecto.
		ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
	 // Retornamos la siguiente vista a mostrar al usuario.
		return (new ActionForward(next.getPath() + view_act));
	}

	
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere bloquear/desbloquear a un usuario
	 * del sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formUser <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward unlockUser(ActionMapping mapping, ActionForm form, 
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
		
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que existe el par&aacute;metro "id" y  es num&eacute;rico.
		if (isAdmin(request) 
				&& Validations.isInteger(request.getParameter("id")))
		{
			try
			{
				// Convertimos el identificador a integer
				int idUser = Integer.parseInt(request.getParameter("id"));
				
				// Obtenemos una instancia de IBUserManager.
				IBUserManager ibUserManager = createIBUserManager();
				
				// Llamamos al m&eacute;todo que permite bloquear/desbloquear la cuenta del usuario.
				ibUserManager.unlockUser(idUser);
				
				// Recuperamos de nuevo la informaci&oacute;n de los usuarios actualizados
				List<TOUser> users  = ibUserManager.listUser();
				
				// Guardamos la informaci&oacute;n en la request.
				request.setAttribute(LIST_USER, users);
				
				// Indicamos que la operaci&oacute;n ha sido realizada con &eacute;xito.
				request.setAttribute(SUCESS, ACTION_UNLOCK_USER);

				// Vista Actual.
				view_act = VIEW_ADMIN_LIST_USER;
			}
			catch (ExceptionControl ec)
			{
				// Indicamos que la operaci&oacute;n no ha sido realizada con &eacute;xito.
				request.setAttribute(FAIL, ec.getMessage());

				// Refrescamos la lista de usuarios
				try
				{
					// Obtenemos una instancia de IBUserManager.
					IBUserManager ibUserManager = createIBUserManager();
					
					// Recuperamos la lista de Usuarios Registrados
					List<TOUser> users  = ibUserManager.listUser();
					
					// Guardamos la informaci&oacute;n en la request.
					request.setAttribute(LIST_USER, users);
					
					// Indicamos cual es la siguiente vista a mostrar.
					view_act = VIEW_ADMIN_LIST_USER;	
					
				}
				catch (Exception ex)
				{
					// Nombre de la Clase
					request.setAttribute("infoClass", "DAUser");
					// Nombre de la excepci&oacute;n
					request.setAttribute("type", ex.getClass().getName());
					// Descripci&oacute;n de la excepci&oacute;n
					request.setAttribute("message", ex.getMessage());
					// Nombre de la Transacci&oacute;n
					request.setAttribute("action", ACTION_UNLOCK_USER);
					// Escribimos por la salida est&aacute;ndar la Traza.
					ex.printStackTrace();

					// Vista Actual.
					view_act = VIEW_GLOBAL_ERROR;		
				}
				
			}
			catch (Exception ex)
			{
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAUser");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_UNLOCK_USER);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();

				// Vista Actual.
				view_act = VIEW_GLOBAL_ERROR;				}
		}
				
		 // Obtenemos la vista por defecto.
			ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
				
		 // Retornamos la siguiente vista a mostrar al usuario.
			return (new ActionForward(next.getPath() + view_act));
	}
		
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere eliminar a un usuario
	 * del sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formUser <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward deleteUser(ActionMapping mapping, ActionForm form,
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
		
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que existe el par&aacute;metro "id" y  es num&eacute;rico.
		if (isAdmin(request) 
			&& Validations.isInteger(request.getParameter("id")))
		{
			try
			{
				
				// Convertimos el identificador a integer
				int idUser = Integer.parseInt(request.getParameter("id"));
						
				// Obtenemos una instancia de IBUserManager.
				IBUserManager ibUserManager = createIBUserManager();
						
				// Llamamos al m&eacute;todo que permite eliminar a un usuario del sistema.
				ibUserManager.deleteUser(idUser);
				
				// Recuperamos de nuevo la informaci&oacute;n de los usuarios actualizados
				List<TOUser> users  = ibUserManager.listUser();
					
				// Guardamos la informaci&oacute;n en la request.
				request.setAttribute(LIST_USER, users);
				
				// Indicamos que la operaci&oacute;n ha sido realizada con &eacute;xito.
				request.setAttribute(SUCESS, ACTION_DELETE_USER);

				// Vista Actual.
				view_act = VIEW_ADMIN_LIST_USER;
			}
			catch (ExceptionControl ec)
			{
				// Indicamos que la operaci&oacute;n no ha sido realizada con &eacute;xito.
				request.setAttribute(FAIL, ec.getMessage());

				// Refrescamos la lista de usuarios
				try
				{
					// Obtenemos una instancia de IBUserManager.
					IBUserManager ibUserManager = createIBUserManager();
					
					// Recuperamos la lista de Usuarios Registrados
					List<TOUser> users  = ibUserManager.listUser();
					
					// Guardamos la informaci&oacute;n en la request.
					request.setAttribute(LIST_USER, users);
					
					// Indicamos cual es la siguiente vista a mostrar.
					view_act = VIEW_ADMIN_LIST_USER;	
					
				}
				catch (Exception ex)
				{
					// Nombre de la Clase
					request.setAttribute("infoClass", "DAUser");
					// Nombre de la excepci&oacute;n
					request.setAttribute("type", ex.getClass().getName());
					// Descripci&oacute;n de la excepci&oacute;n
					request.setAttribute("message", ex.getMessage());
					// Nombre de la Transacci&oacute;n
					request.setAttribute("action", ACTION_DELETE_USER);
					// Escribimos por la salida est&aacute;ndar la Traza.
					ex.printStackTrace();

					// Vista Actual.
					view_act = VIEW_GLOBAL_ERROR;		
				}
						
			}
			catch (Exception ex)
			{
				
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAUser");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_DELETE_USER);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();

				// Vista Actual.
				view_act = VIEW_GLOBAL_ERROR;		
				
			}
		}
						
	 // Obtenemos la vista por defecto.
		ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
			
	 // Retornamos la siguiente vista a mostrar al usuario.
		return (new ActionForward(next.getPath() + view_act));
	}
	
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere consultar todos los usuarios
	 * registrados en el sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formUser <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward listUser(ActionMapping mapping, ActionForm formUser, 
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
		
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		if (isAdmin(request))
		{
			
			List<TOUser> users = null;
			
			try
			{
				if (formUser instanceof AFUser)
				{
					// Realizamos un Cast del formulario.
					AFUser afUser = (AFUser) formUser;
				
					// Obtenemos una instancia de IBUserManager.
					IBUserManager ibUserManager = createIBUserManager();
					
					if (!Validations.isEmpty(request.getParameter("filter"))){
						if(afUser.getFiltroLogin() != null 	|| afUser.getFiltroName() != null 
								|| afUser.getFiltroCompany() != null || afUser.getFiltroEmail() != null  
								|| afUser.getFiltroType() != null){
							
							if(afUser.getFiltroType() == null ) afUser.setFiltroType("");
							
							
							// Recuperamos la lista de Usuarios Registrados
							users  = ibUserManager.listUser(afUser.getFiltroLogin(), afUser.getFiltroCompany(), afUser.getFiltroEmail(), afUser.getFiltroType());
							
							// Ponemos los datos del filtro en session
							request.getSession().setAttribute(SESSION_FILTER_USER,afUser);
							
						}else{
							
							// Eliminamos los datos del filtro en session
							request.getSession().removeAttribute(SESSION_FILTER_USER);
							
							// Recuperamos la lista de Usuarios Registrados
							users  = ibUserManager.listUser();
						}
					}else{
						
						Object objAFUser = request.getSession().getAttribute(SESSION_FILTER_USER);
						
						//Existe filtro
						if(objAFUser != null && objAFUser instanceof AFUser){
							
							//Casteamos el filtro
							afUser = (AFUser) objAFUser;
							
							if(afUser.getFiltroType() == null ) afUser.setFiltroType("");
							
							// Recuperamos la lista de Usuarios Registrados
							users  = ibUserManager.listUser(afUser.getFiltroLogin(), afUser.getFiltroCompany(), afUser.getFiltroEmail(), afUser.getFiltroType());
							
							
						}else{
							
							// Recuperamos la lista de Usuarios Registrados
							users  = ibUserManager.listUser();
						}
						
						
					}
					
						
				}else{

					// Obtenemos una instancia de IBUserManager.
					IBUserManager ibUserManager = createIBUserManager();

					// Recuperamos la lista de Usuarios Registrados
					users  = ibUserManager.listUser();
				}
					
				// Guardamos la informaci&oacute;n en la request.
				request.setAttribute(LIST_USER, users);
				
				// Indicamos cual es la siguiente vista a mostrar.
				view_act = VIEW_ADMIN_LIST_USER;
			}
			catch (Exception ex)
			{
				// Nombre de la Clase
				request.setAttribute("infoClass", "DAUser");
				// Nombre de la excepci&oacute;n
				request.setAttribute("type", ex.getClass().getName());
				// Descripci&oacute;n de la excepci&oacute;n
				request.setAttribute("message", ex.getMessage());
				// Nombre de la Transacci&oacute;n
				request.setAttribute("action", ACTION_LIST_USER);
				// Escribimos por la salida est&aacute;ndar la Traza.
				ex.printStackTrace();
				
				view_act = VIEW_GLOBAL_ERROR;			
			}
		}else{
			
			//NO EJECUTAMOS ACCION AL NO ESTAR AUTORIZADO
			
		}
		
	 // Obtenemos la vista por defecto.
		ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
		
	  // Retornamos la siguiente vista a mostrar al usuario.
		return (new ActionForward(next.getPath() + view_act));
	}
	
	
	/**
	 * <p>Este M&eacute;todo es llamado cada vez que se quiere enviar los datos de registro a un usuario
	 * registrado en el sistema.</p> 
	 *   
	 * @param mapping <code>ActionMapping</code> mapeos de Struts.
	 * @param formUser <code>ActionForm</code> formulario asociado a esta acci&oacute;n. 
	 * @param request <code>HttpServletRequest</code> petici&oacute;n.
	 * @param response <code>HttpServletResponse</code> respuesta.
	 * 
	 * @return <code>ActionForward</code> siguiente vista. 
	 */
	public ActionForward emailDatUser(ActionMapping mapping, ActionForm form, 
			HttpServletRequest request, HttpServletResponse response)
	{
		//Vista actual
		String view_act = " ";
		
		//Verificamos que el usuario que inicia la acci&oacute;n es un administrador 
		//Verificamos que existe el par&aacute;metro "id" y  es num&eacute;rico.
		if (isAdmin(request) 
			&& Validations.isInteger(request.getParameter("id")))
			{
				try
				{
					// Convertimos el identificador a integer
					int idUser = Integer.parseInt(request.getParameter("id"));
								
					// Obtenemos una instancia de IBUserManager.
					IBUserManager ibUserManager = createIBUserManager();
								
					// Llamamos al m&eacute;todo que permite enviar un email a un usuario del sistema.
					ibUserManager.emailDatosUser(idUser);
						
					// Recuperamos de nuevo la informaci&oacute;n de los usuarios actualizados
					List<TOUser> users  = ibUserManager.listUser();
							
					// Guardamos la informaci&oacute;n en la request.
					request.setAttribute(LIST_USER, users);
						
					// Indicamos que la operaci&oacute;n ha sido realizada con &eacute;xito.
					request.setAttribute(SUCESS, ACTION_EMAIL_USER);

					// Vista Actual.
					view_act = VIEW_ADMIN_LIST_USER;
				}
				catch (ExceptionControl ec)
				{
					// Indicamos que la operaci&oacute;n no ha sido realizada con &eacute;xito.
					request.setAttribute(FAIL, ec.getMessage());

					// Refrescamos la lista de usuarios
					try
					{
						// Obtenemos una instancia de IBUserManager.
						IBUserManager ibUserManager = createIBUserManager();
							
						// Recuperamos la lista de Usuarios Registrados
						List<TOUser> users  = ibUserManager.listUser();
							
						// Guardamos la informaci&oacute;n en la request.
						request.setAttribute(LIST_USER, users);
							
						// Indicamos cual es la siguiente vista a mostrar.
						view_act = VIEW_ADMIN_LIST_USER;	
							
					}
					catch (Exception ex)
					{
						// Nombre de la Clase
						request.setAttribute("infoClass", "DAUser");
						// Nombre de la excepci&oacute;n
						request.setAttribute("type", ex.getClass().getName());
						// Descripci&oacute;n de la excepci&oacute;n
						request.setAttribute("message", ex.getMessage());
						// Nombre de la Transacci&oacute;n
						request.setAttribute("action", ACTION_EMAIL_USER);
						// Escribimos por la salida est&aacute;ndar la Traza.
						ex.printStackTrace();

						// Vista Actual.
						view_act = VIEW_GLOBAL_ERROR;		
					}
								
				}
				catch (Exception ex)
				{
					// Nombre de la Clase
					request.setAttribute("infoClass", "DAUser");
					// Nombre de la excepci&oacute;n
					request.setAttribute("type", ex.getClass().getName());
					// Descripci&oacute;n de la excepci&oacute;n
					request.setAttribute("message", ex.getMessage());
						// Nombre de la Transacci&oacute;n
						request.setAttribute("action", ACTION_EMAIL_USER);
						// Escribimos por la salida est&aacute;ndar la Traza.
						ex.printStackTrace();

						// Vista Actual.
						view_act = VIEW_GLOBAL_ERROR;		
						
					}
				}
								
			 // Obtenemos la vista por defecto.
				ActionForward next = mapping.findForward(VIEW_GLOBAL_INDEX);
					
			 // Retornamos la siguiente vista a mostrar al usuario.
				return (new ActionForward(next.getPath() + view_act));
			}
	
}