package edu.uoc.integra.struts.forms;

import org.apache.struts.action.ActionErrors;
import edu.uoc.integra.lib.utils.Validations;

/**
 * <p>Clase que ser&aacute; invocada por las transacciones de Gesti&oacute;n de Autorizaci&oacute;n de la Aplicaci&oacute;n</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class AFAuth extends AFCommon {
	
	/** <p>N&uacute;mero de serie por defecto</p> */
	private static final long serialVersionUID = 1L;
	
	/** <p>Nombre de usuario (login).</p> */
	private String login;
	/** <p>Contrase&ntilde;a de acceso.</p> */
	private String password;
	/** <p>Correo electr&oacute;nico.</p> */
	private String email;
	/** <p>Confirmaci&oacute;n de Correo Electr&oacute;nico.</p> */
	private String confirmEmail;
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de acceso al sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateSignin()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "login".
		validateLogin();
		
		// Validamos el campo "password".
		validatePassword();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de solicitud de recordatorio de contrase&ntilde;a.</p>
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateForgotPassword()
	{
		// Borramos los errores de validaci&oacute;n simples que pudiese haber.
		clearErrors();
		
		// Validamos el campo "email".
		validateEmail();

		// Validamos el campo "confirmEmail".
		validateConfirmEmail();
		
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}	
	
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de solicitud de recordatorio de contrase&ntilde;a.</p>
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors generarError(String campo, String error)
	{
		// Borramos los errores de validaci&oacute;n simples que pudiese haber.
		clearErrors();
		
		// Generamos  el error 
		ErrorField(campo, error);
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}

	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>login</i>.</p>
	 */
	private void validateLogin() {
		
		// Vemos si el campo est&aacute; vac&iacute;o.
		   if (Validations.isEmpty(this.login))
			{
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("Login", "Nombre de Usuario");
			}
		   
	}


	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>password</i>.</p>
	 */

	private void validatePassword() {
		
		// Vemos si el campo est&aacute; vac&iacute;o.
		   if (Validations.isEmpty(this.password))
			{
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("Password", "Contrase&ntilde;a");
			}
	}
		
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>email</i>.</p>
	 */
	private void validateEmail() {
		
		// Vemos si el campo est&aacute; vac&iacute;o.
		   if (Validations.isEmpty(this.email))
			{
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("Email", "Correo Electr&oacute;nico");
				
			}
		 		
	}
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>confirmEmail</i>.</p>
	 */

	private void validateConfirmEmail() {
		
		// Vemos si el campo est&aacute; vac&iacute;o.
		   if (Validations.isEmpty(this.confirmEmail))
			{
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("ConfirmEmail", "Confirmaci&oacute;n de Correo Electr&oacute;nico");
				
			}
		   
		 //Vemos si son diferentes  
		   if(!this.confirmEmail.equals(this.email)){
			 // Generamos  el error "campo inv&aacute;lido".
			   ErrorFieldInvalid("ConfirmEmail", "Confirmaci&oacute;n de Correo Electr&oacute;nico");
		   }
		   
	}
	
	
	// -------- GETTERS & SETTERS.
	public String getLogin()
	{
		return login;
	}
	public void setLogin(String login)
	{
		this.login = login;
	}

	public String getPassword()
	{
		return password;
	}
	public void setPassword(String password)
	{
		this.password = password;
	}

	public String getEmail()
	{
		return email;
	}
	public void setEmail(String email)
	{
		this.email = email;
	}

	public String getConfirmEmail() {
		return confirmEmail;
	}

	public void setConfirmEmail(String confirmEmail) {
		this.confirmEmail = confirmEmail;
	}
	
}
