package edu.uoc.integra.struts.forms;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionForm;
import org.apache.struts.action.ActionMessage;

import edu.uoc.integra.lib.utils.Validations;


/**
 * Clase abstracta de la cual heredar&aacute;n todos los <code>ActionForm</code> que son utilizados por las transacciones de 
 * la aplicaci&oacute;n.</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public abstract class AFCommon extends ActionForm 
{

	// -------- CONSTANTES.
	/** <p>N&uacute;mero de serie por defecto.</p> */
	private static final long serialVersionUID = 1L;
	
	
	// -------- ERRORES.
	// Claves definidas en el fichero "Common.properties" 
	public static final String ERRORS_FIELD_EMPTY      = "errors.field.empty";
	public static final String ERRORS_FIELD_INVALID    = "errors.field.invalid";
	public static final String ERRORS_FIELD_OUT_RANGE  = "errors.field.out.range";
	
	// -------- ATRIBUTOS PROTEGIDOS.
	/** <p>Acci&oacute;n que deber&aacute; ejecutarse. */
	protected String cmd;
	/** <p> Recoge los errores de validaciones.</p> */
	protected ActionErrors errors;
	
	// --------- M&Eacute;TODOS PROTEGIDOS.
	/**
	 * <p>Borra todos los errores del objeto <code>errors</code></p>.
	 */
	protected void clearErrors()
	{
		// Comprobamos si est&aacute; definido.
		if (this.errors == null)
		{
			// No est&aacute; definido, lo creamos
			this.errors = new ActionErrors();
		}
		else
		{
			// Est&aacute; definido , lo limpiamos.
			this.errors.clear();
		}
	}
		
	/**
	 * <p>Almacena el error "campo vac&iacute;o" dentro del objeto <code>ActionErrors</code>
	 * definido en el atributo <i>errors</i> refiri&eacute;ndose al campo que se recibe como
	 * par&aacute;metro.</p>
	 * 
	 * @param field <code>String</code> campo al que corresponde el error.
	 */
	protected void ErrorFieldEmpty(String field)
	{
		// Validamos que el campo recibido no sea vac&iacute;o.
		if (!Validations.isEmpty(field))
		{
			// Generamos el error.
			this.errors.add(field, new ActionMessage(ERRORS_FIELD_EMPTY, field));
		}
	}
	
	/**
	 * <p>Almacena el error "campo vac&iacute;o" dentro del objeto <code>ActionErrors</code>
	 * definido en el atributo <i>errors</i> refiri&eacute;ndose al campo que se recibe como
	 * par&aacute;metro. El nombre del campo que ser&aacute; mostrado en la p&aacute;gina
	 * web ser&aacute; el que se recoge en el par&aacute;metro <i>fieldWeb</i>.</p>
	 * 
	 * @param field <code>String</code> campo al que corresponde el error.
	 * @param fieldWeb <code>String</code> nombre del campo que ser&aacute; mostrado en la web.
	 */
	protected void ErrorFieldEmpty(String field, String fieldWeb)
	{
		// Validamos que ambos campos recibidos no sean nulos.
		if ((!Validations.isEmpty(field)) && (!Validations.isEmpty(fieldWeb)))
		{
			//Generamos el error.
			this.errors.add(field, new ActionMessage(ERRORS_FIELD_EMPTY, fieldWeb));
		}
		else
		{
			// Llamamos al m&eacute;todo sobreescrito
			ErrorFieldEmpty(field);
		}
	}
	
	/**
	 * <p>Almacena el error "campo invalido" dentro del objeto <code>ActionErrors</code>
	 * definido en el atributo <i>errors</i> refiri&eacute;ndose al campo que se recibe como
	 * par&aacute;metro.</p>
	 * 
	 * @param field <code>String</code> campo al que corresponde el error.
	 */
	protected void ErrorFieldInvalid(String field)
	{
		// Validamos que el campo recibido no sea vac&iacute;o.
		if (!Validations.isEmpty(field))
		{
			// Generamos el error.
			this.errors.add(field, new ActionMessage(ERRORS_FIELD_INVALID, field));
		}
	}
	
	/**
	 * <p>Almacena el error "campo invalido" dentro del objeto <code>ActionErrors</code>
	 * definido en el atributo <i>errors</i> refiri&eacute;ndose al campo que se recibe como
	 * par&aacute;metro. El nombre del campo que ser&aacute; mostrado en la p&aacute;gina
	 * web ser&aacute; el que se recoge en el par&aacute;metro <i>fieldWeb</i>.</p>
	 * 
	 * @param field <code>String</code> campo al que corresponde el error.
	 * @param fieldWeb <code>String</code> nombre del campo que ser&aacute; mostrado en la web.
	 */
	protected void ErrorFieldInvalid(String field, String fieldWeb)
	{
		// Validamos que ambos campos recibidos no sean nulos.
		if ((!Validations.isEmpty(field)) && (!Validations.isEmpty(fieldWeb)))
		{
			//Generamos el error.
			this.errors.add(field, new ActionMessage(ERRORS_FIELD_INVALID, fieldWeb));
		}
		else
		{
			// Llamamos al m&eacute;todo sobreescrito
			ErrorFieldEmpty(field);
		}
	}
		
	/**
	 * <p>Almacena el error "campo fuera de rango" dentro del objeto <code>ActionErrors</code>
	 * definido en el atributo <i>errors</i> refiri&eacute;ndose al campo que se recibe como
	 * par&aacute;metro.</p>
	 * 
	 * @param field <code>String</code> campo al que corresponde el error.
	 * @param minLength <code>int</code> valor minimo.
	 * @param maxLength <code>int</code> valor maximo. 
	 */
	protected void ErrorFieldOutRange(String field, int minLength, int maxLength) {
		
		// Validamos que el campo recibido no sea vac&iacute;o.
			if (!Validations.isEmpty(field))
			{
				// Generamos el error.
				this.errors.add(field, new ActionMessage(ERRORS_FIELD_OUT_RANGE, field,minLength,maxLength));
			}
			
	}
	
	/**
	 * <p>Almacena el error "campo fuera de rango" dentro del objeto <code>ActionErrors</code>
	 * definido en el atributo <i>errors</i> refiri&eacute;ndose al campo que se recibe como
	 * par&aacute;metro. El nombre del campo que ser&aacute; mostrado en la p&aacute;gina web ser&aacute; el que se recoge en el par&aacute;metro 
	 * <i>fieldWeb</i>.</p>
	 * 
	 * @param field     <code>String</code> campo al que corresponde el error.
	 * @param fieldWeb  <code>String</code> nombre del campo que ser&aacute; mostrado en la web.
	 * @param minLength <code>int</code>    valor minimo.
	 * @param maxLength <code>int</code>    valor maximo. 
	 */
	protected void ErrorFieldOutRange(String field, String fieldWeb, int minLength, int maxLength) {
		
		// Validamos que ambos campos recibidos no sean nulos.
			if ((!Validations.isEmpty(field)) && (!Validations.isEmpty(fieldWeb)))
			{
				// Generamos el error.
				this.errors.add(field, new ActionMessage(ERRORS_FIELD_OUT_RANGE, fieldWeb,minLength,maxLength));
			}
			else
			{
				// Llamamos al m&eacute;todo sobreescrito
				ErrorFieldOutRange(field,minLength,maxLength);
			}
	}
	
	/**
	 * <p>Almacena el error que recibimos dentro del objeto <code>ActionErrors</code>
	 * definido en el atributo <i>errors</i> refiri&eacute;ndose al campo que se recibe como
	 * par&aacute;metro.</p>
	 * 
	 * @param field <code>String</code> campo al que corresponde el error.
	 * @param error <code>String</code> error.
	 */
	protected void ErrorField(String field, String error)
	{
		// Generamos el error.
		   this.errors.add(field, new ActionMessage(error, field));
	}
	
	// -------- GETTERS & SETTERS.
	public String getCmd() 
	{
		return cmd;
	}

	public void setCmd(String cmd) 
	{
		this.cmd = cmd;
	}

}
