package edu.uoc.integra.struts.forms;

import org.apache.struts.action.ActionErrors;

import edu.uoc.integra.business.functions.IBCommonManagerImpl.TypeParam;
import edu.uoc.integra.business.objects.transfers.TOConfig;
import edu.uoc.integra.lib.utils.Validations;
import edu.uoc.integra.struts.forms.AFCommon;


/**
 * <p>Clase que ser&aacute; invocada por las transacciones de Gesti&oacute;n de Configuraci&oacute;n de la Aplicaci&oacute;n</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class AFConfig extends AFCommon
{

	/** <p>N&uacute;mero de serie por defecto</p> */
	private static final long serialVersionUID = 1L;
	
	/** <p>Identificador del par&aacute;metro en el sistema.</p> */
	private String id;
	/** <p>Nombre del par&aacute;metro.</p> */
	private String name;
	/** <p>Valor  del par&aacute;metro.</p> */
	private String value;
	/** <p>Tipo   de  par&aacute;metro.</p> */
	private String type;
	
	
	// -------- M&Eacute;TODOS P&Uacute;BLICOS.
	/**
	 * <p>Validaciones simples sobre los datos del formulario</p>
	 * 
	 * @return <code>ActionErrors</code> con los errores de validaci&oacute;n simples en los datos
	 * del formulario.
	 */
	public ActionErrors validate()
	{
		// Borramos los errores anteriores
		clearErrors();
		
		// Validamos el campo "name"
		validateName();
		
		// Validamos el campo "value"
		validateValue();
		
		// Validamos el campo "type"
		validateType();
		
		// Retornamos los errores de validaci&oacute;n.
		return this.errors;
	}
	

	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>name</i>.</p>
	 */
	private void validateName() {
		
		// Vemos si el campo est&aacute; vac&iacute;o.
		   if (Validations.isEmpty(this.name))
			{
			    System.out.println("name vac&iacute;o");
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("name", "Nombre del Par&aacute;metro");
			}
	}


	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>value</i>.</p>
	 */

	private void validateValue() {
		
		// Vemos si el campo est&aacute; vac&iacute;o.
		   if (Validations.isEmpty(this.value))
			{
			    System.out.println("value vac&iacute;o");
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("value", "Valor del Par&aacute;metro");
			}
	}
		
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>type</i>.</p>
	 */
	private void validateType() {
		// Vemos si el campo est&aacute; vac&iacute;o.
		   if (Validations.isEmpty(this.type))
			{
			    System.out.println("type vac&iacute;o");
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("type", "Tipo de Par&aacute;metro");
				
			}
		   // Vemos si el valor es invalido
		   else if(!this.type.equals(TypeParam.EMAIL.toString())
					&& !this.type.equals(TypeParam.PROJECT.toString())
					&& !this.type.equals(TypeParam.USER.toString())){
			   
			    System.out.println("Tipo de Par&aacute;metro err&oacute;neo");
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldInvalid("type", "Tipo de Par&aacute;metro");
				
			}		
	}
	
	/**
	 * <p>Copia los valores de las propiedades del objeto <code>TOConfig</code> a los atributos correspondientes 
	 * del formulario.</p>
	 * 
	 * @param config <code>TOConfig</code> con la informaci&oacute;n del par&aacute;metro.
	 */
	public void copyProperties(TOConfig config)
	{
		// Comprobamos que el par&aacute;metro no sea nulo.
		if (config != null)
		{
			// Identificador del par&aacute;metro.
			this.setId(Integer.toString(config.getId()));
			// Nombre del par&aacute;metro
			this.name = config.getName();
			// Valor  del par&aacute;metro 
			this.value = config.getValue();
			// Tipo del Par&aacute;metro
			this.type = config.getType();
		}
	}
	
	// -------- GETTERS & SETTERS.
	public String getId() {
		return id;
	}
	public void setId(String id) {
		this.id = id;
	}

	public String getName()
	{
		return name;
	}
	public void setName(String name)
	{
		this.name = name;
	}

	public String getValue()
	{
		return value;
	}
	public void setValue(String value)
	{
		this.value = value;
	}

	public String getType()
	{
		return type;
	}
	public void setType(String type)
	{
		this.type = type;
	}
	
}
