package edu.uoc.integra.struts.forms;

import org.apache.struts.action.ActionErrors;

import edu.uoc.integra.business.objects.transfers.TOInform;
import edu.uoc.integra.lib.utils.Validations;

/**
 * <p>Clase que ser&aacute; invocada por las transacciones de Generaci&oacute;n de Informes de la Aplicaci&oacute;n</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class AFInform extends AFCommon {
	
	/** <p>N&uacute;mero de serie por defecto</p> */
	private static final long serialVersionUID = 1L;
	
	/** <p>Identificador del Informe.</p> */
	private String id;
	/** <p>Nombre del Informe.</p> */
	private String name;
	/** <p>Descripci&oacute;n del Informe.</p> */
	private String descript;
	
	/** <p>Identificador del Proyecto.</p> */
	private String idproject;
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de acceso al sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateInform()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "idproject".
		validateIdproject();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>idproject</i>.</p>
	 */
	private void validateIdproject() {
		
		// Vemos si el campo est&aacute; vac&iacute;o.
		   if (Validations.isEmpty(this.idproject))
			{
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("idproject", "Identificador de Proyecto");
				
			}else if(this.idproject.equals("_nil_")){
				
				// Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("idproject", "Identificador de Proyecto");
			}
	}
	
	
	/**
	 * <p>Copia los valores de las propiedades del objeto <code>TOInform</code> a los atributos correspondientes 
	 * del formulario.</p>
	 * 
	 * @param inform <code>TOInform</code> con la informaci&oacute;n del informe.
	 */
	public void copyProperties(TOInform inform)
	{
		// Comprobamos que el par&aacute;metro no sea nulo.
		if (inform != null)
		{
			// Identificador del informe.
			this.id = Integer.toString(inform.getId());
			// Nombre del informe
			this.name = inform.getName();
			// Descripci&oacute;n del informe
			this.descript = inform.getDescript();
		}
	}
	
	// -------- GETTERS & SETTERS.
	public String getId() {
		return id;
	}
	public void setId(String id) {
		this.id = id;
	}

	public String getIdproject() {
		return idproject;
	}
	public void setIdproject(String idproject) {
		this.idproject = idproject;
	}
	
	public String getName() {
		return name;
	}
	public void setName(String name) {
		this.name = name;
	}

	public String getDescript() {
		return descript;
	}
	public void setDescript(String descript) {
		this.descript = descript;
	}

	
}
