package edu.uoc.integra.struts.forms;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Locale;

import org.apache.struts.action.ActionErrors;
import org.apache.struts.action.ActionMessage;

import edu.uoc.integra.business.objects.transfers.TOProject;
import edu.uoc.integra.lib.utils.Texts;
import edu.uoc.integra.lib.utils.Validations;

/**
 * <p>Clase que ser&aacute; invocada por las transacciones de Gesti&oacute;n de Proyectos de la Aplicaci&oacute;n</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class AFProject extends AFCommon 
{
	
	/** <p>N&uacute;mero de serie por defecto</p> */
	private static final long serialVersionUID = 1L;
	
	/** <p>N&uacute;mero m&iacute;nimo de caracteres para el campo <i>prefix_code</i>.</p> */
	public static final int PREFIX_CODE_MIN_LENGTH = 3;
	/** <p>N&uacute;mero m&aacute;ximo de caracteres para el campo <i>prefix_code</i>.</p> */
	public static final int PREFIX_CODE_MAX_LENGTH = 10;

	/** <p>N&uacute;mero m&iacute;nimo de caracteres para el campo <i>name</i>.</p> */
	public static final int NAME_MIN_LENGTH = 5;
	/** <p>N&uacute;mero m&aacute;ximo de caracteres para el campo <i>name</i>.</p> */
	public static final int NAME_MAX_LENGTH = 50;
	
	/** <p>Identificador del proyecto en el sistema.</p> */
	private String id;
	/** <p>C&oacute;digo del Proyecto.</p> */
	private String prefix_code;
	/** <p>Nombre del Proyecto.</p> */
	private String name;
	/** <p>Descripci&oacute;n del Proyecto.</p> */
	private String descript;
	/** <p>Comienzo Estimado  del Proyecto (dia)</p> */
	private String fecopenday;
	/** <p>Comienzo Estimado  del Proyecto ( mes)</p> */
	private String fecopenmonth;
	/** <p>Comienzo Estimado  del Proyecto (anyo)</p> */
	private String fecopenyear;
	/** <p>Finalizaci&oacute;n Estimada del Proyecto (dia)</p> */
	private String feccloseday;	
	/** <p>Finalizaci&oacute;n Estimada del Proyecto (mes)</p> */
	private String fecclosemonth;
	/** <p>Finalizaci&oacuten Estimada del Proyecto (anyo)</p> */
	private String feccloseyear;
	
	/** <p>Identificador del Proyecto del que heredamos las caracter&iacuote;sticas.</p> */
	private String idP;
	
	
	//Criterios de Filtro
	/** <p>C&oacute;digo del Proyecto.</p> */
	private String filtroPrefix_code;
	/** <p>Nombre del Proyecto.</p> */
	private String filtroName;
	
	
	
	// -------- M&Eacute;TODOS P&Uacute;BLICOS.
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de registro de proyecto en el sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateCreateProyect()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "prefix_code".
		validatePrefixCode();
		
		// Validamos el campo "name".
		validateName();
		
		// Validamos el campo "fecopen".
		validateFecopen();
		
		// Validamos el campo "fecclose".
		validateFecclose();
		
		//Validamos fechas
		validateFechas();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de modificaci&oacute;n de informaci&oacute;n de un proyecto registrado en el sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateModifyProject()
	{
		// Borramos los errores anteriores 
		clearErrors();
				
		// Validamos el campo "prefix_code".
		validatePrefixCode();
				
		// Validamos el campo "name".
		validateName();
				
		// Validamos el campo "fecopen".
		validateFecopen();
				
		// Validamos el campo "fecclose".
		validateFecclose();
		
		//Validamos fechas
		validateFechas();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	/**
	 * <p>Copia los valores de las propiedades del objeto <code>TOProject</code> a los atributos correspondientes 
	 * del formulario.</p>
	 * 
	 * @param project <code>TOProject</code> con la informaci&oacute;n del proyecto.
	 */
	public void copyProperties(TOProject project)
	{
		// Comprobamos que el par&aacute;metro no sea nulo.
		if (project != null)
		{
			// Identificador del projecto.
			this.id = Integer.toString(project.getId());
			// C&oacute;digo del proyecto
			this.prefix_code = project.getPrefix_code();
			// Nombre del proyecto
			this.name = project.getName();
			// Descripci&oacute;n del proyecto.
			this.descript  = project.getDescript();
			
			// Fecha de inicio estimada del proyecto
			String fecha = project.getFecopen().toString();
			System.out.println("Fecha inicio=" + fecha);
			this.fecopenday   = fecha.substring(8, 10);
			this.fecopenmonth = fecha.substring(5, 7);
			if(this.fecopenmonth.substring(0,1).equals("0")) this.fecopenmonth = this.fecopenmonth.substring(1); 
			this.fecopenyear  = fecha.substring(0, 4);
			
			// Fecha de finalizaci&oacute;n estimada del proyecto
			fecha = project.getFecclose().toString();
			System.out.println("Fecha fin=" + fecha);
			this.feccloseday   = fecha.substring(8, 10);
			this.fecclosemonth = fecha.substring(5, 7);
			if(this.fecclosemonth.substring(0,1).equals("0")) this.fecclosemonth = this.fecclosemonth.substring(1);
			this.feccloseyear  = fecha.substring(0, 4);
		}
	}
	
	
	/**
	 * <p>Formatea campo Descrip a la longitud indicada.</p>
	 * 
	 * @param lenText <code>int</code> Longitud del texto
	 */
	public void formDescript(int lenDescript)
	{
		
		this.descript = Texts.fromtext(this.descript, lenDescript);
		
	}
	
	/**
	 * <p>Retorna un objeto <code>Date</code> a partir de la fecha de inicio estimada de un Proyecto.</p>
	 * 
	 * @return <code>Date</code> representando la fecha de inicio estimada de un Proyecto.
	 */
	public Date getFecopenDate()
	{
		Date fecha=null;
		
		try {
			
			// Comprobamos que los atributos forman una fecha v&acute;lida.
			if (Validations.isValidDate(this.fecopenday,this.fecopenmonth,this.fecopenyear))
			{
				SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy", Locale.getDefault());
				
				// Establecemos bisiestos.
				sdf.setLenient(false);
				
				// Interpretamos la fecha fecopen.
			    fecha = sdf.parse(this.fecopenday + "/" + this.fecopenmonth + "/" + this.fecopenyear);
			}
			
		} catch (ParseException e) {
			
		}
		
		return fecha;	
	}
	
	/**
	 * <p>Retorna un objeto <code>Date</code> a partir de la fecha de finalizaci&oacute;n estimada de un Proyecto.</p>
	 * 
	 * @return <code>Date</code> representando la fecha de finalizaci&oacute;n estimada de un Proyecto.
	 */
	public Date getFeccloseDate()
	{
		Date fecha=null;
		
		try {
			
			// Comprobamos que los atributos forman una fecha v&acute;lida.
			if (Validations.isValidDate(this.feccloseday, this.fecclosemonth, this.feccloseyear))
			{
				SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy", Locale.getDefault());
				
				// Establecemos bisiestos.
				sdf.setLenient(false);
				
				// Interpretamos la fecha fecopen.
			    fecha = sdf.parse(this.feccloseday + "/" + this.fecclosemonth + "/" + this.feccloseyear);
			}
			
		} catch (ParseException e) {
			
		}
		
		return fecha;	
	}
	
			
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>prefix_code</i>.</p>
	 */
	private void validatePrefixCode()
	{
	 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.prefix_code))
		{
			 // Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("prefix_code", "C&oacute;digo");
		}
		else if (!Validations.isInRange(this.prefix_code, PREFIX_CODE_MIN_LENGTH, PREFIX_CODE_MAX_LENGTH))
		{
			// El campo "prefix_code" no tiene un n&uacute;mero de caracteres v&aacute;lido.
			ErrorFieldOutRange("prefix_code", "C&oacute;digo", PREFIX_CODE_MIN_LENGTH, PREFIX_CODE_MAX_LENGTH);
		}
	}
			
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>name</i>.</p>
	 */
	private void validateName()
	{
	 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.name))
		{
			 // Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("name", "Nombre");
		}
		else if (!Validations.isInRange(this.name, NAME_MIN_LENGTH, NAME_MAX_LENGTH))
		{
			// El campo "name" no tiene un n&uacute;mero de caracteres v&aacute;lido.
			ErrorFieldOutRange("name", "Nombre", NAME_MIN_LENGTH, NAME_MAX_LENGTH);
		}
	}
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>fecopen</i>.</p>
	 */
	private void validateFecopen()
	{
		
		System.out.println("Fecha recibida=" +  this.fecopenday + '.' + this.fecopenmonth + '.' + this.fecopenyear);
		
		
		// Validamos que "fecopen" es una fecha valida
		if (!Validations.isValidDate(this.fecopenday, this.fecopenmonth, this.fecopenyear))
		{
			// Fecha inv&acute;lida. Grabamos un error.
			ErrorFieldInvalid("fecopen", "Fecha de Comienzo");
		}
	}
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>fecclose</i>.</p>
	 */
	private void validateFecclose()
	{
		
		System.out.println("Fecha recibida=" +  this.feccloseday + '.' + this.fecclosemonth + '.' + this.feccloseyear);
		
		
		// Validamos que "fecopen" es una fecha valida
		if (!Validations.isValidDate(this.feccloseday, this.fecclosemonth, this.feccloseyear))
		{
			// Fecha inv&acute;lida. Grabamos un error.
			ErrorFieldInvalid("fecclose", "Fecha de Finalizacion");
		}
	}
	
	/**
	 * <p>Verificamos que  <i>fecopen</i> es menor o igual a . <i>fecclose</i></p>
	 */
	private void validateFechas()
	{
		
		try {
			
			SimpleDateFormat sdf = new SimpleDateFormat("dd/MM/yyyy", Locale.getDefault());
			
			// Establecemos bisiestos.
			sdf.setLenient(false);
						
			// Interpretamos la fecha "fecopen"
			Date fecopenDate  = sdf.parse(this.fecopenday + "/" + this.fecopenmonth + "/" + this.fecopenyear);
			// Interpretamos la fecha "fecclose"
			Date feccloseDate = sdf.parse(this.feccloseday + "/" + this.fecclosemonth + "/" + this.feccloseyear);
						
			// Comparamos fechas
			if (fecopenDate.getTime() > feccloseDate.getTime())
			{
				//Generamos error 
				this.errors.add("fecclose", new ActionMessage("errors.field.date.invalid", 
									"Fecha de Inicio", "fecha menor o igual", "Fecha de Finalizacion"));
			}
		
		} catch (ParseException e) {
			
		}

				
	}
	
	
	
	
	
	
	
	
	
	
	
	
	
	
	// -------- GETTERS & SETTERS
	public String getId()
	{
		return id;
	}
	public void setId(String id)
	{
		this.id = id;
	}
	public String getPrefix_code() 
	{
		return prefix_code;
	}
	public void setPrefix_code(String prefix_code) 
	{
		this.prefix_code = prefix_code;
	}
	public String getName() 
	{
		return name;
	}
	public void setName(String name) 
	{
		this.name = name;
	}
	public String getDescript() 
	{
		return descript;
	}
	public void setDescript(String descript) 
	{
		this.descript = descript;
	}

	public String getIdP() {
		return idP;
	}

	public void setIdP(String idP) {
		this.idP = idP;
	}

	public String getFiltroPrefix_code() {
		return filtroPrefix_code;
	}

	public void setFiltroPrefix_code(String filtroPrefix_code) {
		this.filtroPrefix_code = filtroPrefix_code;
	}

	public String getFiltroName() {
		return filtroName;
	}

	public void setFiltroName(String filtroName) {
		this.filtroName = filtroName;
	}

	public String getFecopenday() {
		return fecopenday;
	}

	public void setFecopenday(String fecopenday) {
		this.fecopenday = fecopenday;
	}

	public String getFecopenmonth() {
		return fecopenmonth;
	}

	public void setFecopenmonth(String fecopenmonth) {
		this.fecopenmonth = fecopenmonth;
	}

	public String getFecopenyear() {
		return fecopenyear;
	}

	public void setFecopenyear(String fecopenyear) {
		this.fecopenyear = fecopenyear;
	}

	public String getFeccloseday() {
		return feccloseday;
	}

	public void setFeccloseday(String feccloseday) {
		this.feccloseday = feccloseday;
	}

	public String getFecclosemonth() {
		return fecclosemonth;
	}

	public void setFecclosemonth(String fecclosemonth) {
		this.fecclosemonth = fecclosemonth;
	}

	public String getFeccloseyear() {
		return feccloseyear;
	}

	public void setFeccloseyear(String feccloseyear) {
		this.feccloseyear = feccloseyear;
	}


}
