package edu.uoc.integra.struts.forms;

import org.apache.struts.action.ActionErrors;

import edu.uoc.integra.business.objects.transfers.TORol;
import edu.uoc.integra.lib.utils.Validations;

/**
 * <p>Clase que ser&aacute; invocada por las transacciones de Gesti&oacute;n de Roles de un Proyecto de la Aplicaci&oacute;n</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class AFProjectRol extends AFCommon 
{
	
	/** <p>N&uacute;mero de serie por defecto</p> */
	private static final long serialVersionUID = 1L;
	
	/** <p>N&uacute;mero m&iacute;nimo de caracteres para el campo <i>name</i>.</p> */
	public static final int NAME_MIN_LENGTH = 5;
	/** <p>N&uacute;mero m&aacute;ximo de caracteres para el campo <i>name</i>.</p> */
	public static final int NAME_MAX_LENGTH = 50;
	
	/** <p>Identificador del proyecto en el sistema.</p> */
	private String idproject;
	
	/** <p>C&oacute;digo del Proyecto.</p> */
	private String prefix_code;
	
	/** <p>Nombre del proyecto en el sistema.</p> */
	private String nameP;

	/** <p>Identificador del rol en el proyecto.</p> */
	private String id;
	
	/** <p>Nombre del Rol.</p> */
	private String name;
	
	
	// -------- M&Eacute;TODOS P&Uacute;BLICOS.
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de registro de rol en un proyecto en el sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateCreateRol()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "name".
		validateName();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de modificaci&oacute;n de informaci&oacute;n de un rol definido en
	 * un proyecto registrado en el sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateModifyRol()
	{
		// Borramos los errores anteriores 
		clearErrors();
				
		// Validamos el campo "name".
		validateName();
				
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	/**
	 * <p>Copia los valores de las propiedades del objeto <code>TORol</code> a los atributos correspondientes 
	 * del formulario.</p>
	 * 
	 * @param rol <code>TORol</code> con la informaci&oacute;n del rol.
	 */
	public void copyProperties(TORol rol)
	{
		// Comprobamos que el par&aacute;metro no sea nulo.
		if (rol != null)
		{
			// Identificador del rol.
			this.id = Integer.toString(rol.getId());
			
			// Identificador del proyecto.
			this.idproject = Integer.toString(rol.getIdproject());
			
			//C&oacute;digo del proyecto.
			this.prefix_code = rol.getCodeProject();

			// Nombre del proyecto
			this.nameP = rol.getNameProject();
			
			// Nombre del rol
			this.name = rol.getName();
		}
	}
			
			
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>name</i>.</p>
	 */
	private void validateName()
	{
	 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.name))
		{
			 // Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("name", "Nombre del Rol");
		}
		else if (!Validations.isInRange(this.name, NAME_MIN_LENGTH, NAME_MAX_LENGTH))
		{
			// El campo "name" no tiene un n&uacute;mero de caracteres v&aacute;lido.
			ErrorFieldOutRange("name", "Nombre", NAME_MIN_LENGTH, NAME_MAX_LENGTH);
		}
	}
	
	// -------- GETTERS & SETTERS
	
	public String getIdproject() {
		return idproject;
	}

	public void setIdproject(String idproject) {
		this.idproject = idproject;
	}

	public String getId()
	{
		return id;
	}
	public void setId(String id)
	{
		this.id = id;
	}
	public String getName() 
	{
		return name;
	}
	public void setName(String name) 
	{
		this.name = name;
	}

	public String getNameP() {
		return nameP;
	}

	public void setNameP(String nameP) {
		this.nameP = nameP;
	}

	public String getPrefix_code() {
		return prefix_code;
	}

	public void setPrefix_code(String prefix_code) {
		this.prefix_code = prefix_code;
	}

}
