package edu.uoc.integra.struts.forms;

import org.apache.struts.action.ActionErrors;

import edu.uoc.integra.business.objects.transfers.TOUserRol;
import edu.uoc.integra.lib.utils.Validations;

/**
 * <p>Clase que ser&aacute; invocada por las transacciones de Gesti&oacute;n de Proyectos de la Aplicaci&oacute;n</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class AFProjectUserRol extends AFCommon 
{
	
	/** <p>N&uacute;mero de serie por defecto</p> */
	private static final long serialVersionUID = 1L;
	
	/** <p>Identificador del proyecto en el sistema.</p> */
	private String idproject;
	
	/** <p>C&oacute;digo del Proyecto.</p> */
	private String prefix_code;
	
	/** <p>Nombre del proyecto en el sistema.</p> */
	private String nameP;

	/** <p>Identificador del user-rol en el proyecto.</p> */
	private String id;

	/** <p>Identificador del usuario  en el proyecto.</p> */
	private String idUser;

	/** <p>Nombre del usuario    en el proyecto.</p> */
	private String nameUser;

	/** <p>Identificador del rol  en el proyecto.</p> */
	private String idRol;

	/** <p>Nombre del rol    en el proyecto.</p> */
	private String nameRol;

	
	
	// -------- M&Eacute;TODOS P&Uacute;BLICOS.
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de registro de un user-rol en un proyecto en el sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateCreateUserRol()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "idUser".
		validateIdUser();
		
		// Validamos el campo "idRol".
		validateIdRol();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de modificaci&oacute;n de un user-rol en un proyecto en el sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateModifyUserRol()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "idUser".
		validateIdUser();
		
		// Validamos el campo "idRol".
		validateIdRol();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	
	/**
	 * <p>Copia los valores de las propiedades del objeto <code>TOUserRol</code> a los atributos correspondientes 
	 * del formulario.</p>
	 * 
	 * @param userrol <code>TOUserRol</code> con la informaci&oacute;n del proyecto.
	 */
	public void copyProperties(TOUserRol userrol)
	{
		// Comprobamos que el par&aacute;metro no sea nulo.
		if (userrol != null)
		{
			//Identificador del UserRol
			this.id = Integer.toString(userrol.getId());
			
			// Identificador del projecto.
			this.idproject = Integer.toString(userrol.getIdproject());
			
			// C&oacute;digo del proyecto
			this.prefix_code = userrol.getCodeProject();
			
			// Nombre del proyecto
			this.nameP = userrol.getNameProject();

			// Identificador del usuario
			this.idUser = Integer.toString(userrol.getIduser());

			// Nombre del usuario
			this.nameUser = userrol.getNameUser();
			
			// Identificador del rol
			this.idRol = Integer.toString(userrol.getIdrol());
			
			// Nombre del rol
			this.nameRol  = userrol.getNameRol();
		}
	}
	
			
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>idRol</i>.</p>
	 */
	private void validateIdRol()
	{
	 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.idRol))
		{
			 // Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("idRol", "C&oacute;digo Rol");
		}
		
	}
			
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>idUser</i>.</p>
	 */
	private void validateIdUser()
	{
	 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.idUser))
		{
			 // Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("idUser", "C&oacute;digo de Usuario");
		}
		
	}
	
	// -------- GETTERS & SETTERS
	public String getId()
	{
		return id;
	}
	public void setId(String id)
	{
		this.id = id;
	}

	public String getIdproject() {
		return idproject;
	}

	public void setIdproject(String idproject) {
		this.idproject = idproject;
	}

	public String getPrefix_code() 
	{
		return prefix_code;
	}
	public void setPrefix_code(String prefix_code) 
	{
		this.prefix_code = prefix_code;
	}
	
	public String getNameP() {
		return nameP;
	}

	public void setNameP(String nameP) {
		this.nameP = nameP;
	}

	public String getIdRol() {
		return idRol;
	}

	public void setIdRol(String idRol) {
		this.idRol = idRol;
	}

	public String getNameRol() {
		return nameRol;
	}

	public void setNameRol(String nameRol) {
		this.nameRol = nameRol;
	}

	public String getIdUser() {
		return idUser;
	}

	public void setIdUser(String idUser) {
		this.idUser = idUser;
	}

	public String getNameUser() {
		return nameUser;
	}

	public void setNameUser(String nameUser) {
		this.nameUser = nameUser;
	}
	

}
