package edu.uoc.integra.struts.forms;

import org.apache.struts.action.ActionErrors;

import edu.uoc.integra.business.objects.transfers.TOWorkFlow;
import edu.uoc.integra.lib.utils.Validations;

/**
 * <p>Clase que ser&aacute; invocada por las transacciones de Gesti&oacute;n de Proyectos de la Aplicaci&oacute;n</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class AFProjectWorkFlow extends AFCommon 
{
	
	/** <p>N&uacute;mero de serie por defecto</p> */
	private static final long serialVersionUID = 1L;
	
	/** <p>Identificador del proyecto en el sistema.</p> */
	private String idproject;
	
	/** <p>C&oacute;digo del Proyecto.</p> */
	private String prefix_code;
	
	/** <p>Nombre del proyecto en el sistema.</p> */
	private String nameP;

	/** <p>Identificador del workspace en el proyecto.</p> */
	private String id;

	/** <p>Identificador del rol    en el proyecto.</p> */
	private String idRol;

	/** <p>Nombre del rol    en el proyecto.</p> */
	private String nameRol;
	
	/** <p>Identificador del estado en el proyecto.</p> */
	private String idState;
	
	/** <p>Nombre del Estado    en el proyecto.</p> */
	private String nameState;
	
	/** <p>Identificador del pr&oacute;ximo estado en el proyecto.</p> */
	private String idStateNext;
	
	/** <p>Nombre  del pr&oacute;ximo estado en el proyecto.</p> */
	private String nameStateNext;

	
	// -------- M&Eacute;TODOS P&Uacute;BLICOS.
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de registro de un workspace en un proyecto en el sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateCreateWorkFlow()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "idRol".
		validateIdRol();
		
		// Validamos el campo "idState".
		validateIdState();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de registro de un estado en un workspace en un proyecto en el sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateCreateWorkFlowState()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "idRol".
		validateIdRol();
		
		// Validamos el campo "idState".
		validateIdState();
		
		// Validamos el campo "idStateNext".
		validateIdStateNext();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de modificaci&oacute;n de un workspace en un proyecto en el sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateModifyWorkFlow()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "idRol".
		validateIdRol();
		
		// Validamos el campo "idState".
		validateIdState();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	
	/**
	 * <p>Copia los valores de las propiedades del objeto <code>TOWorkFlow</code> a los atributos correspondientes 
	 * del formulario.</p>
	 * 
	 * @param workflow <code>TOWorkFlow</code> con la informaci&oacute;n del proyecto.
	 */
	public void copyProperties(TOWorkFlow workflow)
	{
		// Comprobamos que el par&aacute;metro no sea nulo.
		if (workflow != null)
		{
			//Identificador del WorkSpace
			this.id = Integer.toString(workflow.getId());
			
			// Identificador del projecto.
			this.idproject = Integer.toString(workflow.getIdproject());
			
			// C&oacute;digo del proyecto
			this.prefix_code = workflow.getCodeProject();
			
			// Nombre del proyecto
			this.nameP = workflow.getNameProject();

			// Identificador del rol
			this.idRol = Integer.toString(workflow.getIdrol());
			
			// Nombre del rol
			this.nameRol  = workflow.getNameRol();
			
			// Identificador del estado
			this.idState = Integer.toString(workflow.getIdstate());

			// Nombre del estado
			this.nameState = workflow.getNameState();

		}
	}
	
			
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>idRol</i>.</p>
	 */
	private void validateIdRol()
	{
	 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.idRol))
		{
			 // Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("idRol", "C&oacute;digo Rol");
		}
		
	}
			
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>idState</i>.</p>
	 */
	private void validateIdState()
	{
	 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.idState))
		{
			 // Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("idState", "C&oacute;digo Estado");
		}
		
	}
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>idStateNext</i>.</p>
	 */
	private void validateIdStateNext()
	{
	 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.idStateNext))
		{
			 // Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("idStateNext", "Siguiente Estado");
		}else if(this.idState == this.idStateNext){
			
			ErrorFieldInvalid("idStateNext", "Siguiente Estado");
		}
	}
	
	
	// -------- GETTERS & SETTERS
	public String getId()
	{
		return id;
	}
	public void setId(String id)
	{
		this.id = id;
	}

	public String getIdproject() {
		return idproject;
	}

	public void setIdproject(String idproject) {
		this.idproject = idproject;
	}

	public String getPrefix_code() 
	{
		return prefix_code;
	}
	public void setPrefix_code(String prefix_code) 
	{
		this.prefix_code = prefix_code;
	}
	
	public String getNameP() {
		return nameP;
	}

	public void setNameP(String nameP) {
		this.nameP = nameP;
	}

	public String getIdRol() {
		return idRol;
	}

	public void setIdRol(String idRol) {
		this.idRol = idRol;
	}

	public String getIdState() {
		return idState;
	}

	public void setIdState(String idState) {
		this.idState = idState;
	}

	public String getIdStateNext() {
		return idStateNext;
	}

	public void setIdStateNext(String idStateNext) {
		this.idStateNext = idStateNext;
	}

	public String getNameRol() {
		return nameRol;
	}

	public void setNameRol(String nameRol) {
		this.nameRol = nameRol;
	}

	public String getNameState() {
		return nameState;
	}

	public void setNameState(String nameState) {
		this.nameState = nameState;
	}

	public String getNameStateNext() {
		return nameStateNext;
	}

	public void setNameStateNext(String nameStateNext) {
		this.nameStateNext = nameStateNext;
	}
	

}
