package edu.uoc.integra.struts.forms;

import org.apache.struts.action.ActionErrors;

import edu.uoc.integra.business.objects.transfers.TOUser;
import edu.uoc.integra.lib.utils.Validations;

/**
 * <p>Clase que ser&aacute; invocada por las transacciones de Gesti&oacute;n de Usuarios de la Aplicaci&oacute;n</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 */
public class AFUser extends AFCommon 
{
	
	/** <p>N&uacute;mero de serie por defecto</p> */
	private static final long serialVersionUID = 1L;
	
	/** <p>N&uacute;mero m&iacute;nimo de caracteres para el campo <i>login</i>.</p> */
	public static final int LOGIN_MIN_LENGTH = 5;
	/** <p>N&uacute;mero m&aacute;ximo de caracteres para el campo <i>login</i>.</p> */
	public static final int LOGIN_MAX_LENGTH = 20;
	
	/** <p>N&uacute;mero m&iacute;nimo de caracteres para el campo <i>password</i>.</p> */
	public static final int PASSWORD_MIN_LENGTH = 5;
	/** <p>N&uacute;mero m&aacute;ximo de caracteres para el campo <i>password</i>.</p> */
	public static final int PASSWORD_MAX_LENGTH = 20;
	
	
	/** <p>Identificador del usuario en el sistema.</p> */
	private String id;
	/** <p>Nombre de usuario (login).</p> */
	private String login;
	/** <p>Contrase&ntilde;a de acceso.</p> */
	private String password;
	/** <p>Nombre real del usuario.</p> */
	private String name;
	/** <p>Empresa del usuario.</p> */
	private String company;
	/** <p>Correo electr&oacute;nico.</p> */
	private String email;
	/** <p>Intentos.</p> */
	private String intentos;
	/** <p>Usuario bloqueado.</p> */
	private String locked;
	/** <p>Tipo de usuario</p> */
	private String type;
	/** <p>Ultimo Acceso</p> */
	private String last_login;
	
	//Criterios de Filtro
	/** <p>Nombre de usuario (login).</p> */
	private String filtroLogin;
	/** <p>Nombre real del usuario.</p> */
	private String filtroName;
	/** <p>Empresa del usuario.</p> */
	private String filtroCompany;
	/** <p>Correo electr&oacute;nico.</p> */
	private String filtroEmail;
	/** <p>Tipo de usuario</p> */
	private String filtroType;
	

	
	// -------- M&Eacute;TODOS P&Uacute;BLICOS.
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de registro de usuario al sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateCreateUser()
	{
		// Borramos los errores anteriores 
		clearErrors();
		
		// Validamos el campo "login".
		validateLogin();
		
		// Validamos el campo "password".
		validatePassword();

		// Validamos el campo "name"
		validateName();

		// Validamos el campo "email"
		validateEmail();
		
		// Validamos el campo  "type".
		validateType();
		
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	/**
	 * <p>M&eacute;todo que ser&aacute; llamado para realizar las validaciones simples sobre los 
	 * datos del formulario en una transacci&oacute;n de modificaci&oacute;n de informaci&oacute;n de un usuario del sistema.</p> 
	 * 
	 * @return <code>ActionErrors</code> contendr&aacute; los errores de validaciones simples sobre los datos del formulario. 
	 */
	public ActionErrors validateModifyUser()
	{
		// Borramos los errores anteriores 
		   clearErrors();
				
		// Validamos el campo "login".
			validateLogin();
				
		// Validamos el campo "password".
			validatePassword();

		// Validamos el campo "name"
			validateName();

		// Validamos el campo "email"
			validateEmail();
				
		// Validamos el tipo de usuario.
			validateType();
				
		// Retornamos el objeto ActionErrors.
		return this.errors;
	}
	
	/**
	 * <p>Copia los valores de las propiedades del objeto <code>TOUser</code> a los atributos correspondientes 
	 * del formulario.</p>
	 * 
	 * @param user <code>TOUser</code> con la informaci&oacute;n del usuario.
	 */
	public void copyProperties(TOUser user)
	{
		// Comprobamos que el par&aacute;metro no sea nulo.
		if (user != null)
		{
			// Identificador del usuario.
			this.id = Integer.toString(user.getId());
			// Nombre de usuario
			this.login = user.getLogin();
			// Contrase&ntilde;a
			this.password = user.getPassword();
			// Nombre real.
			this.name = user.getName();
			// Empresa de usuario.
			this.company = user.getCompany();
			// Correo electr&oacute;nico.						
			this.email = user.getEmail();
			// Intentos Fallidos
			this.setIntentos(Integer.toString(user.getIntentos()));
			// Usuario bloqueado
			this.locked = Boolean.toString(user.getLocked());
			// Tipo de usuario
			this.type=user.getType();
			//Ultimo Acceso
			if(user.getLast_login()!= null)
				this.last_login = user.getLast_login().toString();
			else
				this.last_login = "01-01-0001 01:01:01";
			
			System.out.println("last_login=" + last_login);
		}
	}
			
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>login</i>.</p>
	 */
	private void validateLogin()
	{
	 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.login))
		{
			 // Generamos  el error "campo vac&iacute;o".
				ErrorFieldEmpty("login", "Login");
		}
		else if (!Validations.isInRange(this.login, LOGIN_MIN_LENGTH, LOGIN_MAX_LENGTH))
		{
			// El campo "login" no tiene un n&uacute;mero de caracteres v&aacute;lido.
			ErrorFieldOutRange("login", "Login", LOGIN_MIN_LENGTH, LOGIN_MAX_LENGTH);
		}
	}
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>password</i>.</p>
	 */
	private void validatePassword()
	{
		 // Vemos si el campo est&aacute; vac&iacute;o.
			if (Validations.isEmpty(this.password))
			{
				 // Generamos  el error "campo vac&iacute;o".
					ErrorFieldEmpty("password", "Password");
			}
			else if (!Validations.isInRange(this.password, PASSWORD_MIN_LENGTH, PASSWORD_MAX_LENGTH))
			{
				// El campo "login" no tiene un n&uacute;mero de caracteres v&aacute;lido.
				ErrorFieldOutRange("password", "Password", PASSWORD_MIN_LENGTH, PASSWORD_MAX_LENGTH);
			}
	}
		
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>name</i>.</p>
	 */
	private void validateName()
	{
		// Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.name))
		{
			 // Generamos  el error "campo vac&iacute;o".
			ErrorFieldEmpty("name", "Nombre");
		}
	}
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>email</i>.</p>
	 */
	private void validateEmail()
	{
		 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.email))
		{
			 // Generamos  el error "campo vac&iacute;o".
			ErrorFieldEmpty("email", "Correo Electr&oacute;nico");
		}
		else if (!Validations.isEmail(this.email))
		{
			// No es un correo v&aacute;lido 
			ErrorFieldInvalid("email", "Correo Electr&oacute;nico");
		}
	}
	
	/**
	 * <p>Realiza las validaciones simples sobre el campo <i>type</i>.</p>
	 */
	private void validateType()
	{
		 // Vemos si el campo est&aacute; vac&iacute;o.
		if (Validations.isEmpty(this.type))
		{
		  // Generamos  el error "campo vac&iacute;o".
			ErrorFieldEmpty("type", "Tipo de usuario");		
		}else{
			if(this.type.trim().equals("Administrador")){
				ErrorFieldInvalid("type", "Tipo de Usuario");
			}
		}
	}
	
	// -------- GETTERS & SETTERS
	public String getId()
	{
		return id;
	}
	public void setId(String id)
	{
		this.id = id;
	}
	public String getLogin() 
	{
		return login;
	}
	public void setLogin(String login) 
	{
		this.login = login;
	}
	public String getPassword() 
	{
		return password;
	}
	public void setPassword(String password) 
	{
		this.password = password;
	}
	public String getName() 
	{
		return name;
	}
	public void setName(String name) 
	{
		this.name = name;
	}
	public String getCompany() 
	{
		return company;
	}
	public void setCompany(String company) 
	{
		this.company = company;
	}
	public String getEmail() 
	{
		return email;
	}
	public void setEmail(String email) 
	{
		this.email = email;
	}
	public String getIntentos() {
		return intentos;
	}
	public void setIntentos(String intentos) {
		this.intentos = intentos;
	}
	public String getLocked() 
	{
		return locked;
	}
	public void setLocked(String locked) 
	{
		this.locked = locked;
	}
	public String getType() 
	{
		return type;
	}
	public void setType(String type) 
	{
		this.type = type;
	}

	public String getLast_login() {
		return last_login;
	}

	public void setLast_login(String last_login) {
		this.last_login = last_login;
	}

	public String getFiltroLogin() {
		return filtroLogin;
	}

	public void setFiltroLogin(String filtroLogin) {
		this.filtroLogin = filtroLogin;
	}

	public String getFiltroCompany() {
		return filtroCompany;
	}

	public void setFiltroCompany(String filtroCompany) {
		this.filtroCompany = filtroCompany;
	}

	public String getFiltroEmail() {
		return filtroEmail;
	}

	public void setFiltroEmail(String filtroEmail) {
		this.filtroEmail = filtroEmail;
	}

	public String getFiltroType() {
		return filtroType;
	}

	public void setFiltroType(String filtroType) {
		this.filtroType = filtroType;
	}

	public String getFiltroName() {
		return filtroName;
	}

	public void setFiltroName(String filtroName) {
		this.filtroName = filtroName;
	}


}
