package edu.uoc.integra.struts.plugins;

import java.io.File;
import java.io.FileInputStream;
import java.util.Properties;
import java.util.StringTokenizer;

import javax.servlet.ServletException;

import org.apache.struts.action.ActionServlet;
import org.apache.struts.action.PlugIn;
import org.apache.struts.config.ModuleConfig;


/**
 * <p>Clase que implementa la interfaz <code>PlugIn</code> de <i>Struts</i>.
 * 
 * <p>Se utiliza para cargar en el &aacute;mbito de la aplicaci&oacute;n la informaci&oacute;n 
 * de las clases que implementan a las interfaces que la capa de negocio 
 * ofrece a la capa de presentaci&oacute;n</p>
 * 
 * @author Miguel Angel Pineda Cruz
 * @version 1.0
 *
 */
public class PIntegra implements PlugIn {
	
	// -------- CONSTANTES.
	/** <p>Ruta por defecto para el archivo <code>business-factories.properties</code> que contiene las factor&iacute;as
	 * de la aplicaci&oacute;n. Este archivo se cargar&aacute; en caso de que no se haya definido otro en el archivo de configuraci&oacute;n
	 * de struct, <code>structs-config.xml</code> mediante el par&aacute;metro property="factories"</p> */
	public static final String DEFAULT_PATH = "/WEB-INF/config/business-factories.properties";
	
	
	// -------- ATRIBUTOS.
	/** <p>Atributo para el par&aacute;metro del PlugIn <i>properties-file</i>.</p> */
	protected String factories;
	
	// -------- GETTERS & SETTERS.
	public String getFactories() 
	{
		return factories;
	}
	public void setFactories(String factories) 
	{
		this.factories = factories;
	}
	
	// -------- M&Eacute;TODOS P&Uacute;BLICOS.
	@Override
	public void destroy() 
	{
	}

	@Override
	public void init(ActionServlet servlet, ModuleConfig config)
			throws ServletException 
	{
		//No existe par&aacute;metro property="factories" definido en el archivo  structs-config.xml
		if (this.factories == null)
		{
			// Asignamos el valor por defecto.
			this.factories = DEFAULT_PATH;
			
		}
		
		try {
			
			// Accedemos al fichero que contiene la definici&oacute;n de las factor&iacute;as en el servidor
			File file = new File(servlet.getServletContext().getRealPath("/") + this.factories);
			
			// Comprobamos si es accesible el fichero
			if (file.exists() && file.canRead())
			{
				// Definimos un nuevo objeto Properties.
				Properties properties = new Properties();
				
				//Cargamos el fichero dentro del objeto properties 
				properties.load(new FileInputStream(file));
				
				// Comprobamos si existe interfaces definidas
				if (properties.containsKey("interfaces")){
					
					// Leemos la lista de interfaces
					StringTokenizer st = new StringTokenizer(properties.getProperty("interfaces"), ",");
					
					// Recorremos la lista de interfaces.
					while (st.hasMoreTokens())
					{
						// Interfaz a buscar.
						String interfaceName = st.nextToken().trim();
							
						// Buscamos si existe su implementaci&oacute;n con la clave factory.interfaceName
						String propertyImpl = "factory." + interfaceName;
						
						// Vemos si existe la clave definida en el fichero property
						if (properties.containsKey(propertyImpl)){

						  // Obtenemos la clase que la implementa.
							 String interfaceImplClass = properties.getProperty(propertyImpl);

							try{
								// Comprobamos si la Clase existe
								   Class.forName(interfaceImplClass);
								   
								 // Almacenamos la clase en el &aacute;mbito de aplicaci&oacute;n, para que pueda ser utilizada por todas
								 // las action.
								   servlet.getServletContext().setAttribute(interfaceName, interfaceImplClass);
								
							}catch (ClassNotFoundException cnfe)
							{
								// No se ha encontrado la clase que implementa a la interfaz 
								throw new ServletException("Error: No se puede encontrar la clase: " + interfaceImplClass);
							}
							   
						}
						else 
						{
								// Falta la clave que define la implementaci&oacute;n de una clase
								throw new ServletException("Error: No existe la clave: " +	propertyImpl + 
										",en el fichero: " + this.factories);
						}
					}
						
				}else{
						// No existe la clave "interfaces" 
						throw new ServletException("Error: No existe la clave 'interfaces'" +
								"en el fichero: " + this.factories);
					}
			}
			else 
			{
				// El fichero no es accesible.
				throw new ServletException("Error: No se puede acceder al fichero: " + this.factories);
			}
		
		} catch (Exception ex) {
			// Propagamos la excepci&oacute;n
			throw new ServletException(ex.getMessage());
		}

	}
	
}
